<?php
/*
Class Name: VI_WOO_BOPO_BUNDLE_Admin
Author: Andy Ha (support@villatheme.com)
Author URI: http://villatheme.com
Copyright 2015 villatheme.com. All rights reserved.
*/
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class VI_WOO_BOPO_BUNDLE_Admin {
	protected $settings;
	protected $language;
	protected $languages;
	protected $default_language;
	protected $languages_data;
	protected $languages_count;

	function __construct() {
//		register_activation_hook( __FILE__, array( $this, 'install' ) );
		$this->settings         = VI_WOO_BOPO_BUNDLE_DATA::get_instance();
		$this->languages        = array();
		$this->languages_count  = 0;
		$this->languages_data   = array();
		$this->default_language = '';
		add_filter(
			'plugin_action_links_bopo-woocommerce-product-bundle-builder/bopo-woocommerce-product-bundle-builder.php', array(
				$this,
				'settings_link'
			)
		);
		add_action( 'init', array( $this, 'init' ) );
		add_action( 'admin_menu', array( $this, 'add_menu' ) );
		add_action( 'admin_init', array( $this, 'check_update' ) );
		add_action( 'admin_init', array( $this, 'save_settings' ), 99 );

//		add_action( 'wp_print_scripts', array( $this, 'custom_script' ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_script' ), 99 );

	}

	function init() {
		bopobb_register_product_type();
		load_plugin_textdomain( 'bopo-woocommerce-product-bundle-builder' );
		$this->load_plugin_textDomain();

		if ( class_exists( 'VillaTheme_Support_Pro' ) ) {
			new VillaTheme_Support_Pro(
				array(
					'support'   => 'https://villatheme.com/supports/forum/plugins/bopo',
					'docs'      => 'https://docs.villatheme.com/?item=bopo',
					'review'    => 'https://codecanyon.net/downloads',
					'css'       => VI_WOO_BOPO_BUNDLE_CSS,
					'image'     => VI_WOO_BOPO_BUNDLE_IMAGES,
					'slug'      => 'bopo-woocommerce-product-bundle-builder',
					'menu_slug' => 'bopo-woocommerce-product-bundle-builder',
					'version'   => VI_WOO_BOPO_BUNDLE_VERSION
				)
			);
		}
	}

	/**
	 * When active plugin Function will be call
	 */
	public function install() {
		global $wp_version;
		If ( version_compare( $wp_version, "2.9", "<" ) ) {
			deactivate_plugins( basename( __FILE__ ) ); // Deactivate our plugin
			wp_die( "This plugin requires WordPress version 2.9 or higher." );
		}
	}

	function add_menu() {
		add_menu_page(
			esc_html__( 'Bopo - WooCommerce Product Bundle Builder Premium', 'bopo-woocommerce-product-bundle-builder' ),
			esc_html__( 'Bopo Bundle', 'bopo-woocommerce-product-bundle-builder' ),
			'manage_options',
			'bopo-woocommerce-product-bundle-builder',
			array(
				$this,
				'settings_page'
			), VI_WOO_BOPO_BUNDLE_IMAGES . 'icon_bopo.svg', 2
		);
		add_submenu_page(
			'bopo-woocommerce-product-bundle-builder',
			esc_html__( 'Bopo - WooCommerce Product Bundle Builder - Build Your Own Box', 'bopo-woocommerce-product-bundle-builder' ),
			esc_html__( 'Settings', 'bopo-woocommerce-product-bundle-builder' ),
			'manage_options',
			'bopo-woocommerce-product-bundle-builder'
		);
	}

	public function custom_script() {
		$script = 'var bopobb_ajax_url = "' . esc_url( admin_url( 'admin-ajax.php' ) ) . '"'; ?>
        <script type="text/javascript" data-cfasync="false">
			<?php echo( $script );// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
        </script>
	<?php }

	function bopobb_wp_get_page_url_by_template_slug( $template_slug ) {
		$url      = null;
		$template = 'page-' . $template_slug . '.php';

		$pages = get_posts( array(
			'post_type'  => 'page',
			'meta_query' => array(// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_query
				array(
					'key'     => '_wp_page_template',
					'value'   => $template,
					'compare' => '=',
				)
			)
		) );

		if ( isset( $pages[0] ) ) {
			$url = get_permalink( $pages[0]->ID );
		}

		return $url;
	}

	public function check_update() {
		if ( class_exists( 'VillaTheme_Plugin_Check_Update' ) ) {
			$key         = $this->settings->get_params( 'bopobb_update_key' );
			$setting_url = admin_url( 'admin.php?page=bopo-woocommerce-product-bundle-builder' );
			new VillaTheme_Plugin_Check_Update(
				VI_WOO_BOPO_BUNDLE_VERSION,                    // current version
				'https://villatheme.com/wp-json/downloads/v3',  // update path
				'bopo-woocommerce-product-bundle-builder/bopo-woocommerce-product-bundle-builder.php',                  // plugin file slug
				'bopo-woocommerce-product-bundle-builder', '102285', $key, $setting_url
			);
			new VillaTheme_Plugin_Updater( 'bopo-woocommerce-product-bundle-builder/bopo-woocommerce-product-bundle-builder.php', 'bopo-woocommerce-product-bundle-builder', $setting_url );

		}
	}

	/**
	 * Save data.
	 */
	public function save_settings() {
		global $bopobb_settings;
		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}
		/*wpml*/
		if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
			global $sitepress;
			$default_lang           = $sitepress->get_default_language();
			$this->default_language = $default_lang;
			$languages              = icl_get_languages( 'skip_missing=N&orderby=KEY&order=DIR&link_empty_to=str' );
			$this->languages_data   = $languages;
			if ( count( $languages ) ) {
				foreach ( $languages as $key => $language ) {
					if ( $key != $default_lang ) {
						$this->languages[] = $key;
					}
				}
			}
		} elseif ( class_exists( 'Polylang' ) && function_exists( 'pll_languages_list' ) ) {
			/*Polylang*/
			$languages    = pll_languages_list();
			$default_lang = pll_default_language( 'slug' );
			foreach ( $languages as $language ) {
				if ( $language == $default_lang ) {
					continue;
				}
				$this->languages[] = $language;
			}
		}
		$this->languages_count = count( $this->languages );

		if ( ! isset( $_POST['bopobb_nonce_field'] ) || ! wp_verify_nonce( wc_clean( wp_unslash( $_POST['bopobb_nonce_field'] ) ), 'bopobb_settings_page_save' ) ) {
			return;
		}
		$args = array(
			//General
			'bopobb_single_pos'            => 6,
			'bopobb_bundle_quantity'       => 1,
			'bopobb_view_stock'            => 0,
			'bopobb_view_ratting'          => 0,
			'bopobb_view_description'      => 0,
			'bopobb_view_full_description' => 0,
			'bopobb_short_des_position'    => 0,
			'bopobb_des_position'          => 0,
			'bopobb_link_individual'       => 0,
			'bopobb_single_template'       => 1,
			'bopobb_item_column'           => 4,
			'bopobb_image_border'          => 0,
			'bopobb_image_size'            => 'woocommerce_thumbnail',
			'bopobb_popup_image_size'      => 'woocommerce_thumbnail',
			'bopobb_alert_position'        => 'bottom',
			'bopobb_hide_price'            => 1,
			'bopobb_single_note'           => 0,
			'bopobb_title_note'            => 'Bundle note',
			'bopobb_social_share'          => array(),
//			'bopobb_export_pdf'            => 0,
			'bopobb_print_bundle'          => 0,
			'bopobb_shop_button'           => '',
			'bopobb_out_stock'             => 0,
			'bopobb_remove_ready_cart'     => 0,
			'bopobb_edit_cart'             => 0,
			'bopobb_edit_checkout'         => 0,
			'bopobb_order_item_price'      => 0,
			'bopobb_item_price_single'     => 'hide',
			'bopobb_item_price_total'      => 'hide',
			'bopobb_calculate_price'       => 'current',
			'bopobb_meta_field_range'      => 0,
			'bopobb_conditional_tag'       => '',

			//swap button
			'bopobb_swap_text'             => 'Change',
			'bopobb_swap_pos'              => 1,
			'bopobb_swap_background'       => '',
			'bopobb_swap_color'            => '',

			//popup
			'bopobb_popup_filter'          => 0,
			'bopobb_popup_search'          => 0,
			'bopobb_popup_link'            => 0,
			'bopobb_duplicate_select'      => 0,
			'bopobb_popup_title'           => 'Please select your product',
			'bopobb_popup_background'      => '',
			'bopobb_popup_color'           => '',
			'bopobb_popup_variations'      => 'list',
			'bopobb_popup_load_init'       => 'product',
			'bopobb_popup_fontsize'        => '',
			'bopobb_popup_page_items'      => 32,

			'bopobb_custom_css' => '',

			'bopobb_alert_products'  => 'Please select products for all items of the bundle.',
			'bopobb_alert_available' => 'Please select product available.',
			'bopobb_alert_duplicate' => 'The product is already in the bundle, please select the other.',
			'bopobb_alert_change'    => 'No product available to change.',
			'bopobb_alert_max'       => 'This item quantity must be less than',
			'bopobb_alert_min'       => 'This item quantity must be greater than',
			'bopobb_alert_stock'     => 'This item is out of stock',

			//update key
			'bopobb_update_key'      => isset( $_POST['bopobb_update_key'] ) ? sanitize_text_field( wp_unslash( $_POST['bopobb_update_key'] ) ) : '',
		);
		if ( $this->languages_count ) {
			foreach ( $this->languages as $key => $value ) {
				$args[ 'bopobb_popup_title_' . $value ]     = isset( $_POST[ 'bopobb_popup_title_' . $value ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'bopobb_popup_title_' . $value ] ) ) : 'Please select your product';
				$args[ 'bopobb_alert_products_' . $value ]  = isset( $_POST[ 'bopobb_alert_products_' . $value ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'bopobb_alert_products_' . $value ] ) ) : 'Please select products for all items of the bundle.';
				$args[ 'bopobb_alert_available_' . $value ] = isset( $_POST[ 'bopobb_alert_available_' . $value ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'bopobb_alert_available_' . $value ] ) ) : 'Please select product available.';
				$args[ 'bopobb_alert_duplicate_' . $value ] = isset( $_POST[ 'bopobb_alert_duplicate_' . $value ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'bopobb_alert_duplicate_' . $value ] ) ) : 'The product is already in the bundle, please select the other.';
				$args[ 'bopobb_alert_change_' . $value ]    = isset( $_POST[ 'bopobb_alert_change_' . $value ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'bopobb_alert_change_' . $value ] ) ) : 'No product available to change.';
				$args[ 'bopobb_alert_max_' . $value ]       = isset( $_POST[ 'bopobb_alert_max_' . $value ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'bopobb_alert_max_' . $value ] ) ) : 'This item quantity must be less than';
				$args[ 'bopobb_alert_min_' . $value ]       = isset( $_POST[ 'bopobb_alert_min_' . $value ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'bopobb_alert_min_' . $value ] ) ) : 'This item quantity must be greater than';
				$args[ 'bopobb_alert_stock_' . $value ]     = isset( $_POST[ 'bopobb_alert_stock_' . $value ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'bopobb_alert_stock_' . $value ] ) ) : 'This item is out of stock';
				$args[ 'bopobb_shop_button_' . $value ]     = isset( $_POST[ 'bopobb_shop_button_' . $value ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'bopobb_shop_button_' . $value ] ) ) : '';
			}
		}
		foreach ( $args as $key => $arg ) {
			if ( 'bopobb_social_share' == $key ) {
				$args[ $key ] = isset( $_POST[ $key ] ) ? wc_clean( wp_unslash( $_POST[ $key ] ) ) : array();
			} else {
				$args[ $key ] = isset( $_POST[ $key ] ) ? sanitize_text_field( wp_unslash( $_POST[ $key ] ) ) : '';
			}
		}
		$run_check_update = false;
		if ( isset( $_POST['bopobb_save_data'] ) || isset( $_POST['bopobb_save_check'] ) ) {
			$args = wp_parse_args( $args, get_option( 'woo_bopo_bundle_params', $bopobb_settings ) );
			update_option( 'woo_bopo_bundle_params', $args );
			$bopobb_settings = $args;
			$this->settings  = VI_WOO_BOPO_BUNDLE_DATA::get_instance( true );

			if ( isset( $_POST['bopobb_save_check'] ) ) {
				$run_check_update = true;
				delete_transient( 'update_plugins' );
				delete_transient( 'villatheme_item_102285' );
				delete_option( 'bopo-woocommerce-product-bundle-builder_messages' );
				do_action( 'villatheme_save_and_check_key_bopo-woocommerce-product-bundle-builder', $args['bopobb_update_key'] );
			}

			add_action( 'admin_notices', function () {
				?>
                <div class="updated">
                    <p><?php esc_html_e( 'Your settings have been saved!', 'bopo-woocommerce-product-bundle-builder' ) ?></p>
                </div>
				<?php
			} );
		}
		if ( isset( $_POST['bopobb_save_check'] ) && ! $run_check_update ) {
			delete_transient( 'update_plugins' );
			delete_transient( 'villatheme_item_102285' );
			delete_option( 'bopo-woocommerce-product-bundle-builder_messages' );
			do_action( 'villatheme_save_and_check_key_bopo-woocommerce-product-bundle-builder', $args['bopobb_update_key'] );
		}
	}

	public function settings_page() {
		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}
		?>
        <div class="wrap">
            <h2><?php esc_html_e( 'Bopo - WooCommerce Product Bundle Builder - Build Your Own Box', 'bopo-woocommerce-product-bundle-builder' ); ?></h2>
            <div class="vi-ui raised">
                <form class="vi-ui form bopobb-general-settings" method="post" action="">
					<?php
					wp_nonce_field( 'bopobb_settings_page_save', 'bopobb_nonce_field' );
					?>
                    <div class="vi-ui top attached tabular menu">
                        <div class="item active"
                             data-tab="general"><?php esc_html_e( 'General', 'bopo-woocommerce-product-bundle-builder' ); ?></div>
                        <div class="item"
                             data-tab="layout"><?php esc_html_e( 'Layout', 'bopo-woocommerce-product-bundle-builder' ); ?></div>
                        <div class="item"
                             data-tab="update"><?php esc_html_e( 'Update', 'bopo-woocommerce-product-bundle-builder' ); ?></div>
                    </div>
                    <div class="vi-ui bottom attached active tab segment" data-tab="general">
                        <table class="vi-ui bottom attached form-table">
                            <tbody>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_out_stock">
										<?php esc_html_e( 'Show out of stock product', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_out_stock" <?php checked( $this->settings->get_params( 'bopobb_out_stock' ), 1 ) ?>
                                               name="bopobb_out_stock" value="1">
                                        <label></label>
                                    </div>
                                    <p class="description"><?php esc_html_e( 'Toggles to enable or disable out-of-stock products in the bundle', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_remove_ready_cart">
										<?php esc_html_e( 'Remove duplicate product outside bundle', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_remove_ready_cart" <?php checked( $this->settings->get_params( 'bopobb_remove_ready_cart' ), 1 ) ?>
                                               name="bopobb_remove_ready_cart" value="1">
                                        <label></label>
                                    </div>
                                    <p class="description"><?php esc_html_e( 'When adding a bundle, if the cart has the same product in the bundle, this product will be removed', 'bopo-woocommerce-product-bundle-builder' ) ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_edit_cart">
										<?php esc_html_e( 'Edit bundle item on cart', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_edit_cart" <?php checked( $this->settings->get_params( 'bopobb_edit_cart' ), 1 ) ?>
                                               name="bopobb_edit_cart" value="1">
                                        <label></label>
                                    </div>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_edit_checkout">
										<?php esc_html_e( 'Edit bundle item on checkout', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_edit_checkout" <?php checked( $this->settings->get_params( 'bopobb_edit_checkout' ), 1 ) ?>
                                               name="bopobb_edit_checkout" value="1">
                                        <label></label>
                                    </div>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_order_item_price">
										<?php esc_html_e( 'Show item price on admin order', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_order_item_price" <?php checked( $this->settings->get_params( 'bopobb_order_item_price' ), 1 ) ?>
                                               name="bopobb_order_item_price" value="1">
                                        <label></label>
                                    </div>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_item_price_single">
										<?php esc_html_e( 'Item price on cart', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_item_price_single" tabindex="5"
                                            name="bopobb_item_price_single">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_item_price_single' ), 'hide' ) ?>
                                                value="hide"><?php esc_html_e( 'Hide', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_item_price_single' ), 'price' ) ?>
                                                value="price"><?php esc_html_e( 'Item price', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_item_price_single' ), 'price_discount' ) ?>
                                                value="price_discount"><?php esc_html_e( 'Price and bundle discount', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                    </select>
                                    <p class="description"><?php esc_html_e( 'Choose type of item price display on cart page.', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_item_price_total">
										<?php esc_html_e( 'Item subtotal on cart/checkout', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_item_price_total" tabindex="5"
                                            name="bopobb_item_price_total">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_item_price_total' ), 'hide' ) ?>
                                                value="hide"><?php esc_html_e( 'Hide', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_item_price_total' ), 'price' ) ?>
                                                value="price"><?php esc_html_e( 'Item price', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_item_price_total' ), 'price_discount' ) ?>
                                                value="price_discount"><?php esc_html_e( 'Price and bundle discount', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                    </select>
                                    <p class="description"><?php esc_html_e( 'Choose type of item subtotal display on cart and checkout page.', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_calculate_price">
										<?php esc_html_e( 'Calculate price with', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_calculate_price" tabindex="5"
                                            name="bopobb_calculate_price">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_calculate_price' ), 'current' ) ?>
                                                value="current"><?php esc_html_e( 'Current price', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_calculate_price' ), 'regular' ) ?>
                                                value="regular"><?php esc_html_e( 'Regular price', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_calculate_price' ), 'sale' ) ?>
                                                value="sale"><?php esc_html_e( 'Sale price', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                    </select>
                                    <p class="description"><?php esc_html_e( 'When you set discounts for the bundle item, the value will be calculated based on this price of the item you put, it can be current price, regular price or sale price of the item.', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_meta_field_range">
										<?php esc_html_e( 'Range price by meta field', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_meta_field_range" <?php checked( $this->settings->get_params( 'bopobb_meta_field_range' ), 1 ) ?>
                                               name="bopobb_meta_field_range" value="1">
                                        <label></label>
                                    </div>
                                    <p class="description"><?php esc_html_e( 'Save bundle min/max price as meta field', 'bopo-woocommerce-product-bundle-builder' ) ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_meta_field_range">
										<?php esc_html_e( 'Update bundles range price', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <div class="bopobb-update-range-price vi-ui primary button"><?php
											esc_html_e( 'Update', 'bopo-woocommerce-product-bundle-builder' ) ?></div>
                                        <span class="bopobb-notice bopobb-notice-complete bopobb-hidden"><?php
											esc_html_e( 'Update complete', 'bopo-woocommerce-product-bundle-builder' ) ?></span>
                                        <span class="bopobb-notice bopobb-notice-error bopobb-hidden"><?php
											esc_html_e( 'Something went wrong, please try again later', 'bopo-woocommerce-product-bundle-builder' ) ?></span>
                                    </div>
                                    <p class="description"><?php esc_html_e( 'Update min/max price meta field for all bundle', 'bopo-woocommerce-product-bundle-builder' ) ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_conditional_tag">
										<?php esc_html_e( 'Conditional tags', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_conditional_tag" id="bopobb_conditional_tag"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_conditional_tag' ) ) ?>"
                                           placeholder="<?php echo esc_html( 'Ex: !is_page(array(123,41,20))' ) ?>"/>
                                    <p class="description"><?php esc_html_e( 'Lets you control which pages are running scripts ', 'bopo-woocommerce-product-bundle-builder' ) ?>
                                        <a href="http://codex.wordpress.org/Conditional_Tags"
                                           target="_blank"><?php esc_html_e( 'WP\'s conditional tags', 'bopo-woocommerce-product-bundle-builder' ) ?></a>
										<?php esc_html_e( ' (always run in cart and checkout page).', 'bopo-woocommerce-product-bundle-builder' ) ?>
                                    </p>
                                </td>
                            </tr>

                            </tbody>
                        </table>
                    </div>
                    <div class="vi-ui bottom attached tab segment" data-tab="layout">
                        <p class="description"><?php esc_html_e( 'Layout settings determine how the Bopo bundle appears on the front end', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                        <table class="vi-ui bottom attached form-table">
                            <tbody>
                            <tr valign="top">
                                <th scope="row">
                                    <h4 class="vi-ui blue header"><?php esc_html_e( 'Bundle view', 'bopo-woocommerce-product-bundle-builder' ); ?></h4>
                                </th>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_single_pos">
										<?php esc_html_e( 'Position', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_single_pos" tabindex="5"
                                            name="bopobb_single_pos">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_single_pos' ), 6 ) ?>
                                                value="6"><?php esc_html_e( 'Under title', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_single_pos' ), 11 ) ?>
                                                value="11"><?php esc_html_e( 'Under price & rating', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_single_pos' ), 29 ) ?>
                                                value="29"><?php esc_html_e( 'Above add to cart', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_single_pos' ), 31 ) ?>
                                                value="31"><?php esc_html_e( 'Under add to cart', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_single_pos' ), 99 ) ?>
                                                value="99"><?php esc_html_e( 'Product tab', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                    </select>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_bundle_quantity">
										<?php esc_html_e( 'Bundle show quantity', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                    </label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_bundle_quantity" <?php checked( $this->settings->get_params( 'bopobb_bundle_quantity' ), 1 ) ?>
                                               name="bopobb_bundle_quantity" value="1">
                                        <label></label>
                                    </div>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_view_stock">
										<?php esc_html_e( 'Product detail', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                    </label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_view_stock" <?php checked( $this->settings->get_params( 'bopobb_view_stock' ), 1 ) ?>
                                               name="bopobb_view_stock" value="1">
                                        <label><?php esc_html_e( 'Show stock', 'bopo-woocommerce-product-bundle-builder' ); ?></label>
                                    </div>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_view_ratting">
                                    </label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_view_ratting" <?php checked( $this->settings->get_params( 'bopobb_view_ratting' ), 1 ) ?>
                                               name="bopobb_view_ratting" value="1">
                                        <label><?php esc_html_e( 'Show rating', 'bopo-woocommerce-product-bundle-builder' ); ?></label>
                                    </div>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_view_description">
                                    </label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_view_description" <?php checked( $this->settings->get_params( 'bopobb_view_description' ), 1 ) ?>
                                               name="bopobb_view_description" value="1">
                                        <label><?php esc_html_e( 'Show short description', 'bopo-woocommerce-product-bundle-builder' ); ?></label>
                                    </div>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_view_full_description">
                                    </label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_view_full_description" <?php checked( $this->settings->get_params( 'bopobb_view_full_description' ), 1 ) ?>
                                               name="bopobb_view_full_description" value="1">
                                        <label><?php esc_html_e( 'Show description', 'bopo-woocommerce-product-bundle-builder' ); ?></label>
                                    </div>
                                </td>
                            </tr>
                            <tr id="bopobb_short_des_position_wrap" valign="top">
                                <th scope="row">
                                    <label for="bopobb_short_des_position">
										<?php esc_html_e( 'Short description position', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_short_des_position" tabindex="5"
                                            name="bopobb_short_des_position">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_short_des_position' ), 0 ) ?>
                                                value="0"><?php esc_html_e( 'On hover', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_short_des_position' ), 1 ) ?>
                                                value="1"><?php esc_html_e( 'After product detail', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                    </select>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr id="bopobb_des_position_wrap" valign="top">
                                <th scope="row">
                                    <label for="bopobb_des_position">
										<?php esc_html_e( 'Description position', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_des_position" tabindex="5"
                                            name="bopobb_des_position">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_des_position' ), 0 ) ?>
                                                value="0"><?php esc_html_e( 'On hover', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_des_position' ), 1 ) ?>
                                                value="1"><?php esc_html_e( 'After product detail', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                    </select>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_link_individual">
										<?php esc_html_e( 'Link to individual product', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_link_individual" tabindex="5"
                                            name="bopobb_link_individual">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_link_individual' ), 0 ) ?>
                                                value="0"><?php esc_html_e( 'No link', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_link_individual' ), 1 ) ?>
                                                value="1"><?php esc_html_e( 'New tab', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_link_individual' ), 2 ) ?>
                                                value="2"><?php esc_html_e( 'Bundle change product popup', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                    </select>
                                    <p class="description"><?php esc_html_e( 'Action after click on title product of bundle', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_single_template">
										<?php esc_html_e( 'Template', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_single_template" tabindex="5"
                                            name="bopobb_single_template">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_single_template' ), 1 ) ?>
                                                value="1"><?php esc_html_e( 'Vertical bundle template', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_single_template' ), 2 ) ?>
                                                value="2"><?php esc_html_e( 'Horizontal bundle template', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_single_template' ), 3 ) ?>
                                                value="3"><?php esc_html_e( 'Image Block bundle template', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
                                    </select>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_item_column">
										<?php esc_html_e( 'Item column', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_item_column" tabindex="5"
                                            name="bopobb_item_column">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_item_column' ), 2 ) ?>
                                                value="2">2
                                        </option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_item_column' ), 3 ) ?>
                                                value="3">3
                                        </option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_item_column' ), 4 ) ?>
                                                value="4">4
                                        </option>
                                    </select>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_image_border">
										<?php esc_html_e( 'Image border (%)', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="number" name="bopobb_image_border" id="bopobb_image_border"
                                           tabindex="5" type="text" class="bopobb-image-border"
                                           step="1" min="0" max="50"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_image_border' ) ); ?>"/>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_image_size">
										<?php esc_html_e( 'Image size', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
									<?php
									global $_wp_additional_image_sizes;
									?>
                                    <select class="vi-ui fluid dropdown" id="bopobb_image_size" tabindex="5"
                                            name="bopobb_image_size">
										<?php
										$size_options = wp_get_additional_image_sizes();
										foreach ( $size_options as $key => $args ) {
											$height = $args['height'] ? $args['height'] : 'auto';
											$width  = $args['width'] ? $args['width'] : 'auto';
											$r      = "{$key} ({$width}x{$height})";
											?>
                                            <option <?php selected( $this->settings->get_params( 'bopobb_image_size' ), $key ) ?>
                                                    value="<?php echo esc_attr( $key ) ?>"><?php echo esc_html( $r ) ?></option>
											<?php
										}
										?>
                                    </select>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_alert_position">
										<?php esc_html_e( 'Alert text position', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_alert_position" tabindex="5"
                                            name="bopobb_alert_position">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_alert_position' ), 'bottom' ) ?>
                                                value="bottom"><?php esc_html_e( 'After bundle item', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                        </option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_alert_position' ), 'top' ) ?>
                                                value="top"><?php esc_html_e( 'Before bundle item', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                        </option>
                                    </select>
                                    <p class="description"><?php esc_html_e( 'Choose where you want to place an alert about bundle.', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_hide_price">
										<?php esc_html_e( 'Display bundle price', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <!--                                    <div class="vi-ui toggle checkbox">-->
                                    <!--                                        <input type="checkbox" tabindex="5"-->
                                    <!--                                               id="bopobb_hide_price" --><?php //checked( $this->settings->get_params( 'bopobb_hide_price' ), 1 ) ?>
                                    <!--                                               name="bopobb_hide_price" value="1">-->
                                    <!--                                        <label></label>-->
                                    <!--                                    </div>-->
                                    <select class="vi-ui fluid dropdown" id="bopobb_hide_price" tabindex="5"
                                            name="bopobb_hide_price">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_hide_price' ), '0' ) ?>
                                                value="0"><?php esc_html_e( 'Always show', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                        </option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_hide_price' ), '2' ) ?>
                                                value="2"><?php esc_html_e( 'When one item selected', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                        </option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_hide_price' ), '1' ) ?>
                                                value="1"><?php esc_html_e( 'When all item selected', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                        </option>
                                    </select>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_single_note">
										<?php esc_html_e( 'Enable note', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_single_note" <?php checked( $this->settings->get_params( 'bopobb_single_note' ), 1 ) ?>
                                               name="bopobb_single_note" value="1">
                                        <label><?php esc_html_e( 'Add note for the bundle', 'bopo-woocommerce-product-bundle-builder' ); ?></label>
                                    </div>
                                </td>
                            </tr>
                            <tr id="bopobb_title_note_wrap" valign="top">
                                <th scope="row">
                                    <label for="bopobb_title_note">
										<?php esc_html_e( 'Bundle note title', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_title_note" id="bopobb_title_note"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_title_note' ) ) ?>"
                                           placeholder="<?php esc_attr_e( 'Bundle note', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_title_note_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   name="<?php echo esc_attr( 'bopobb_title_note_' . $value ) ?>"
                                                   id="<?php echo esc_attr( 'bopobb_title_note_' . $value ) ?>"
                                                   tabindex="5" type="text" class="bopobb-popup-column"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_title_note_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'Please select products for all items of the bundle.', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_social_share">
										<?php esc_html_e( 'Share bundle', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_social_share" tabindex="5" multiple
                                            name="bopobb_social_share[]">
                                        <option value=""><?php esc_html_e( 'None', 'bopo-woocommerce-product-bundle-builder' ); ?></option>
										<?php
										$social_setting = $this->settings->get_params( 'bopobb_social_share' );
										if ( ! is_array( $social_setting ) ) {
											$social_setting = array( $social_setting );
										}
										$social_share = array(
											'facebook'  => esc_html__( 'Facebook', 'bopo-woocommerce-product-bundle-builder' ),
											'twitter'   => esc_html__( 'Twitter', 'bopo-woocommerce-product-bundle-builder' ),
											'email'     => esc_html__( 'Email', 'bopo-woocommerce-product-bundle-builder' ),
											'pinterest' => esc_html__( 'Pinterest', 'bopo-woocommerce-product-bundle-builder' ),
											'vkontakte' => esc_html__( 'VKontakte', 'bopo-woocommerce-product-bundle-builder' ),
											'tumblr'    => esc_html__( 'Tumblr', 'bopo-woocommerce-product-bundle-builder' ),
											'linkedin'  => esc_html__( 'LinkedIn', 'bopo-woocommerce-product-bundle-builder' ),
											'url'       => esc_html__( 'Url', 'bopo-woocommerce-product-bundle-builder' ),
										);
										foreach ( $social_share as $k => $v ) {
											printf( '<option value="%1s" %2s >%3s</option>', esc_attr( $k ), selected( in_array( $k, $social_setting ), true ), esc_html( $v ) );
										}
										?>
                                    </select>
                                    <p class="description"><?php esc_html_e( 'Choose where you want to share bundle. Leave empty to disable.', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                                </td>
                            </tr>
                            <!--                            <tr valign="top">-->
                            <!--                                <th scope="row">-->
                            <!--                                    <label for="bopobb_export_pdf">-->
                            <!--			                            -->
							<?php //esc_html_e( 'Export pdf', 'bopo-woocommerce-product-bundle-builder' ) ?><!--</label>-->
                            <!--                                </th>-->
                            <!--                                <td>-->
                            <!--                                    <div class="vi-ui toggle checkbox">-->
                            <!--                                        <input type="checkbox" tabindex="5"-->
                            <!--                                               id="bopobb_export_pdf" --><?php //checked( $this->settings->get_params( 'bopobb_export_pdf' ), 1 ) ?>
                            <!--                                               name="bopobb_export_pdf" value="1">-->
                            <!--                                        <label></label>-->
                            <!--                                    </div>-->
                            <!--                                </td>-->
                            <!--                            </tr>-->
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_print_bundle">
										<?php esc_html_e( 'Print bundle', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_print_bundle" <?php checked( $this->settings->get_params( 'bopobb_print_bundle' ), 1 ) ?>
                                               name="bopobb_print_bundle" value="1">
                                        <label></label>
                                    </div>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_shop_button">
										<?php esc_html_e( 'Shop Add to cart button title', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_shop_button" id="bopobb_shop_button"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_shop_button' ) ) ?>"
                                           placeholder="<?php esc_attr_e( 'Read more', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_shop_button_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   name="<?php echo esc_attr( 'bopobb_shop_button_' . $value ) ?>"
                                                   id="<?php echo esc_attr( 'bopobb_shop_button_' . $value ) ?>"
                                                   tabindex="5" type="text" class="bopobb-popup-column"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_shop_button_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'Read more', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <h4 class="vi-ui blue header"><?php esc_html_e( 'Popup change product', 'bopo-woocommerce-product-bundle-builder' ); ?></h4>
                                </th>
                                <td>
                                    <span class="description"><?php esc_html_e( 'Note: These settings help to customize and design the bundle popup', 'bopo-woocommerce-product-bundle-builder' ); ?></span>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_filter">
										<?php esc_html_e( 'Show filter category', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                    </label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_popup_filter" <?php checked( $this->settings->get_params( 'bopobb_popup_filter' ), 1 ) ?>
                                               name="bopobb_popup_filter" value="1">
                                        <label></label>
                                    </div>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_search">
										<?php esc_html_e( 'Show search box', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                    </label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_popup_search" <?php checked( $this->settings->get_params( 'bopobb_popup_search' ), 1 ) ?>
                                               name="bopobb_popup_search" value="1">
                                        <label></label>
                                    </div>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_link">
										<?php esc_html_e( 'Link item to product page', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                    </label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_popup_link" <?php checked( $this->settings->get_params( 'bopobb_popup_link' ), 1 ) ?>
                                               name="bopobb_popup_link" value="1">
                                        <label></label>
                                    </div>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_duplicate_select">
										<?php esc_html_e( 'Allow same product', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                    </label>
                                </th>
                                <td>
                                    <div class="vi-ui toggle checkbox">
                                        <input type="checkbox" tabindex="5"
                                               id="bopobb_duplicate_select" <?php checked( $this->settings->get_params( 'bopobb_duplicate_select' ), 1 ) ?>
                                               name="bopobb_duplicate_select" value="1">
                                        <label></label>
                                    </div>
                                    <p class="description"><?php esc_html_e( 'Allow customers to add the same product again in the bundle (On load, the product may be the same even if the setting is disallowed).', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_title">
										<?php esc_html_e( 'Title', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" id="bopobb_popup_title" tabindex="5" name="bopobb_popup_title"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_popup_title' ) ); ?>"
                                           placeholder="<?php esc_attr_e( 'Select product to bundle', 'bopo-woocommerce-product-bundle-builder' ) ?>">
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_popup_title_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   id="<?php echo esc_attr( 'bopobb_popup_title_' . $value ) ?>"
                                                   tabindex="5"
                                                   name="<?php echo esc_attr( 'bopobb_popup_title_' . $value ) ?>"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_popup_title_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'Please select your product', 'bopo-woocommerce-product-bundle-builder' ) ?>">
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_color">
										<?php esc_html_e( 'Color', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input name="bopobb_popup_color" id="bopobb_popup_color" tabindex="5" type="text"
                                           class="color-picker"
                                           value="<?php if ( $this->settings->get_params( 'bopobb_popup_color' ) ) {
										       echo esc_attr( $this->settings->get_params( 'bopobb_popup_color' ) );
									       } ?>"
                                           style="background: <?php if ( $this->settings->get_params( 'bopobb_popup_color' ) ) {
										       echo esc_attr( $this->settings->get_params( 'bopobb_popup_color' ) );
									       } ?>;"/>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_background">
										<?php esc_html_e( 'Background color', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input name="bopobb_popup_background" id="bopobb_popup_background" tabindex="5"
                                           type="text" class="color-picker"
                                           value="<?php if ( $this->settings->get_params( 'bopobb_popup_background' ) ) {
										       echo esc_attr( $this->settings->get_params( 'bopobb_popup_background' ) );
									       } ?>"
                                           style="background: <?php if ( $this->settings->get_params( 'bopobb_popup_background' ) ) {
										       echo esc_attr( $this->settings->get_params( 'bopobb_popup_background' ) );
									       } ?>;"/>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_page_items">

										<?php esc_html_e( 'Number product per page', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="number" name="bopobb_popup_page_items" id="bopobb_popup_page_items"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           step="1" min="1" max="100"
                                           value="<?php if ( $this->settings->get_params( 'bopobb_popup_page_items' ) ) {
										       echo esc_attr( $this->settings->get_params( 'bopobb_popup_page_items' ) );
									       } ?>"/>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_image_size">
										<?php esc_html_e( 'Image size', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
									<?php
									global $_wp_additional_image_sizes;
									?>
                                    <select class="vi-ui fluid dropdown" id="bopobb_popup_image_size" tabindex="5"
                                            name="bopobb_popup_image_size">
										<?php
										$size_options = wp_get_additional_image_sizes();
										foreach ( $size_options as $key => $args ) {
											$height = $args['height'] ? $args['height'] : 'auto';
											$width  = $args['width'] ? $args['width'] : 'auto';
											$r      = "{$key} ({$width}x{$height})";
											?>
                                            <option <?php selected( $this->settings->get_params( 'bopobb_popup_image_size' ), $key ) ?>
                                                    value="<?php echo esc_attr( $key ) ?>"><?php echo esc_html( $r ) ?></option>
											<?php
										}
										?>
                                    </select>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_variations">
										<?php esc_html_e( 'Select variations type', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_popup_variations" tabindex="5"
                                            name="bopobb_popup_variations">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_popup_variations' ), 'list' ) ?>
                                                value="list"><?php esc_html_e( 'List of variations', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                        </option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_popup_variations' ), 'select' ) ?>
                                                value="select"><?php esc_html_e( 'Select box', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                        </option>
                                    </select>
                                    <p class="description"></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_popup_load_init">
										<?php esc_html_e( 'Load popup product', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <select class="vi-ui fluid dropdown" id="bopobb_popup_load_init" tabindex="5"
                                            name="bopobb_popup_load_init">
                                        <option <?php selected( $this->settings->get_params( 'bopobb_popup_load_init' ), 'product' ) ?>
                                                value="product"><?php esc_html_e( 'Products', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                        </option>
                                        <option <?php selected( $this->settings->get_params( 'bopobb_popup_load_init' ), 'variation' ) ?>
                                                value="variation"><?php esc_html_e( 'Variations', 'bopo-woocommerce-product-bundle-builder' ); ?>
                                        </option>
                                    </select>
                                    <p class="description"><?php esc_html_e( 'Load variations product if current selector is a variation', 'bopo-woocommerce-product-bundle-builder' ); ?></p>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <h4 class="vi-ui blue header"><?php esc_html_e( 'Alert Title', 'bopo-woocommerce-product-bundle-builder' ); ?></h4>
                                </th>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_alert_products">
										<?php esc_html_e( 'Products require', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_alert_products" id="bopobb_alert_products"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_products' ) ) ?>"
                                           placeholder="<?php esc_attr_e( 'Please select products for all items of the bundle.', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_alert_products_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   name="<?php echo esc_attr( 'bopobb_alert_products_' . $value ) ?>"
                                                   id="<?php echo esc_attr( 'bopobb_alert_products_' . $value ) ?>"
                                                   tabindex="5" type="text" class="bopobb-popup-column"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_products_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'Please select products for all items of the bundle.', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_alert_available">
										<?php esc_html_e( 'Purchasable require', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_alert_available" id="bopobb_alert_available"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_available' ) ) ?>"
                                           placeholder="<?php esc_attr_e( 'Please select product available.', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_alert_available_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   name="<?php echo esc_attr( 'bopobb_alert_available_' . $value ) ?>"
                                                   id="<?php echo esc_attr( 'bopobb_alert_available_' . $value ) ?>"
                                                   tabindex="5" type="text" class="bopobb-popup-column"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_available_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'Please select product available.', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_alert_duplicate">
										<?php esc_html_e( 'Disallow same product', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_alert_duplicate" id="bopobb_alert_duplicate"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_duplicate' ) ) ?>"
                                           placeholder="<?php esc_attr_e( 'The product is already in the bundle, please select the other.', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_alert_duplicate_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   name="<?php echo esc_attr( 'bopobb_alert_duplicate_' . $value ) ?>"
                                                   id="<?php echo esc_attr( 'bopobb_alert_duplicate_' . $value ) ?>"
                                                   tabindex="5" type="text" class="bopobb-popup-column"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_duplicate_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'The product is already in the bundle, please select the other.', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_alert_change">
										<?php esc_html_e( "Can't change item", "bopo-woocommerce-product-bundle-builder" ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_alert_change" id="bopobb_alert_change"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_change' ) ) ?>"
                                           placeholder="<?php esc_attr_e( 'No product available to change.', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_alert_change_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   name="<?php echo esc_attr( 'bopobb_alert_change_' . $value ) ?>"
                                                   id="<?php echo esc_attr( 'bopobb_alert_change_' . $value ) ?>"
                                                   tabindex="5" type="text" class="bopobb-popup-column"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_change_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'No product available to change.', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_alert_max">
										<?php esc_html_e( 'Quantity max require', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_alert_max" id="bopobb_alert_max"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_max' ) ) ?>"
                                           placeholder="<?php esc_attr_e( 'This item quantity must be less than', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_alert_max_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   name="<?php echo esc_attr( 'bopobb_alert_max_' . $value ) ?>"
                                                   id="<?php echo esc_attr( 'bopobb_alert_max_' . $value ) ?>"
                                                   tabindex="5" type="text" class="bopobb-popup-column"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_max_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'This item quantity must be less than', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_alert_min">
										<?php esc_html_e( 'Quantity min require', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_alert_min" id="bopobb_alert_min"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_min' ) ) ?>"
                                           placeholder="<?php esc_attr_e( 'This item quantity must be greater than', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_alert_min_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   name="<?php echo esc_attr( 'bopobb_alert_min_' . $value ) ?>"
                                                   id="<?php echo esc_attr( 'bopobb_alert_min_' . $value ) ?>"
                                                   tabindex="5" type="text" class="bopobb-popup-column"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_min_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'This item quantity must be greater than', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_alert_stock">
										<?php esc_html_e( 'Product out of stock', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <input type="text" name="bopobb_alert_stock" id="bopobb_alert_stock"
                                           tabindex="5" type="text" class="bopobb-popup-column"
                                           value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_stock' ) ) ?>"
                                           placeholder="<?php esc_attr_e( 'This item is out of stock', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
									<?php
									if ( $this->languages_count ) {
										foreach ( $this->languages as $key => $value ) {
											?>
                                            <p>
                                                <label for="<?php echo 'bopobb_alert_stock_' . esc_html( $value ); ?>"><?php
													if ( isset( $this->languages_data[ $value ]['country_flag_url'] ) && $this->languages_data[ $value ]['country_flag_url'] ) {
														?>
                                                        <img src="<?php echo esc_url( $this->languages_data[ $value ]['country_flag_url'] ); ?>">
														<?php
													}
													echo esc_html( $value );
													if ( isset( $this->languages_data[ $value ]['translated_name'] ) ) {
														echo '(' . esc_html( $this->languages_data[ $value ]['translated_name'] ) . ')';
													}
													?>:</label>
                                            </p>
                                            <input type="text"
                                                   name="<?php echo esc_attr( 'bopobb_alert_stock_' . $value ) ?>"
                                                   id="<?php echo esc_attr( 'bopobb_alert_stock_' . $value ) ?>"
                                                   tabindex="5" type="text" class="bopobb-popup-column"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_alert_stock_' . $value ) ); ?>"
                                                   placeholder="<?php esc_attr_e( 'This item quantity must be greater than', 'bopo-woocommerce-product-bundle-builder' ) ?>"/>
											<?php
										}
									}
									?>
                                </td>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <h4 class="vi-ui blue header"><?php esc_html_e( 'Custom Script', 'bopo-woocommerce-product-bundle-builder' ); ?></h4>
                                </th>
                            </tr>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="bopobb_custom_css">
										<?php esc_html_e( 'Custom CSS', 'bopo-woocommerce-product-bundle-builder' ) ?></label>
                                </th>
                                <td>
                                    <textarea type="text" name="bopobb_custom_css" id="bopobb_custom_css"
                                              tabindex="5"
                                              class="bopobb-popup-column"><?php echo esc_html( $this->settings->get_params( 'bopobb_custom_css' ) ); ?></textarea>
                                </td>
                            </tr>
                            </tbody>
                        </table>
                    </div>
                    <div class="vi-ui bottom attached tab segment" data-tab="update">
                        <table class="form-table">
                            <tbody>
                            <tr valign="top">
                                <th scope="row">
                                    <label for="auto-update-key"></label><?php esc_html_e( 'Auto update key', 'bopo-woocommerce-product-bundle-builder' ) ?>
                                </th>
                                <td>
                                    <div class="fields">
                                        <div class="ten wide field">
                                            <input type="text" name="bopobb_update_key" id="auto-update-key"
                                                   class="villatheme-autoupdate-key-field"
                                                   value="<?php echo esc_attr( $this->settings->get_params( 'bopobb_update_key' ) ); ?>">
                                        </div>
                                        <div class="six wide field">
                                        <span class="vi-ui button green villatheme-get-key-button"
                                              data-href="https://api.envato.com/authorization?response_type=code&client_id=villatheme-download-keys-6wzzaeue&redirect_uri=https://villatheme.com/update-key"
                                              data-id="35677459"><?php echo esc_html__( 'Get Key', 'bopo-woocommerce-product-bundle-builder' ) ?></span>
                                        </div>
                                    </div>
									<?php do_action( 'bopo-woocommerce-product-bundle-builder_key' ) ?>
                                    <p class="description"><?php echo sprintf( '%s %s. %s %s.',
											esc_html__( 'Please fill your key what you get from ', 'bopo-woocommerce-product-bundle-builder' ),
											wp_kses_post( '<a target="_blank" href="https://villatheme.com/my-download">https://villatheme.com/my-download</a>' ),
											esc_html__( 'See', 'bopo-woocommerce-product-bundle-builder' ),
											wp_kses_post( '<a target="_blank" href="https://villatheme.com/knowledge-base/how-to-use-auto-update-feature/">' . esc_html__( 'guide', 'bopo-woocommerce-product-bundle-builder' ) . '</a>' ) ); ?>
                                    </p>
                                </td>
                            </tr>
                            </tbody>
                        </table>
                    </div>
                    <p>
                        <button class="vi-ui primary button labeled icon bopobb-submit" name="bopobb_save_data"><i
                                    class="icon save"></i><?php esc_html_e( 'Save', 'bopo-woocommerce-product-bundle-builder' ); ?>
                        </button>
                        <button type="submit" class="vi-ui button labeled icon"
                                name="bopobb_save_check"><i
                                    class="icon save"></i><?php esc_html_e( 'Save & Check Key', 'bopo-woocommerce-product-bundle-builder' ); ?>
                        </button>
                    </p>
                </form>
            </div>
        </div>
		<?php
		do_action( 'villatheme_support_bopo-woocommerce-product-bundle-builder' );
	}

	/**
	 * Link to Settings
	 *
	 * @param $links
	 *
	 * @return mixed
	 */
	public function settings_link( $links ) {
		$settings_link = '<a href="admin.php?page=bopo-woocommerce-product-bundle-builder" title="' . __( 'Bopo - WooCommerce Product Bundle Builder - Build Your Own Box', 'bopo-woocommerce-product-bundle-builder' ) . '">' . __( 'Settings', 'bopo-woocommerce-product-bundle-builder' ) . '</a>';
		array_unshift( $links, $settings_link );

		return $links;
	}

	/**
	 * load Language translate
	 */
	function load_plugin_textDomain() {
		$locale = apply_filters( 'plugin_locale', get_locale(), 'bopo-woocommerce-product-bundle-builder' );
		// Admin Locale
		if ( is_admin() ) {
			load_textdomain( 'bopo-woocommerce-product-bundle-builder', VI_WOO_BOPO_BUNDLE_LANGUAGES . "bopo-woocommerce-product-bundle-builder-$locale.mo" );
		}

		// Global + Frontend Locale
		load_textdomain( 'bopo-woocommerce-product-bundle-builder', VI_WOO_BOPO_BUNDLE_LANGUAGES . "bopo-woocommerce-product-bundle-builder-$locale.mo" );
		load_plugin_textdomain( 'bopo-woocommerce-product-bundle-builder', false, VI_WOO_BOPO_BUNDLE_LANGUAGES );
	}

	/**
	 *  Include style and script
	 */
	public function admin_enqueue_script() {
		$page = isset( $_REQUEST['page'] ) ? wp_unslash( sanitize_text_field( wp_unslash( $_REQUEST['page'] ) ) ) : '';// phpcs:ignore WordPress.Security.NonceVerification.Recommended
		if ( $page == 'bopo-woocommerce-product-bundle-builder' ) {
			/*Compatible with theme or plugin */
			wp_dequeue_style( 'tmpmela_tab' ); /*Theme Kinves*/
			wp_dequeue_style( 'base-admin-css' ); /*Plugin BoldGrid Inspirations*/
			// style
			wp_enqueue_style( 'woo-bopo-bundle-semantic-button-css', VI_WOO_BOPO_BUNDLE_CSS . 'button.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-table-css', VI_WOO_BOPO_BUNDLE_CSS . 'table.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-form-css', VI_WOO_BOPO_BUNDLE_CSS . 'form.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-dropdown-css', VI_WOO_BOPO_BUNDLE_CSS . 'dropdown.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-transition-css', VI_WOO_BOPO_BUNDLE_CSS . 'transition.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-checkbox-css', VI_WOO_BOPO_BUNDLE_CSS . 'checkbox.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-menu-css', VI_WOO_BOPO_BUNDLE_CSS . 'menu.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-header-css', VI_WOO_BOPO_BUNDLE_CSS . 'header.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-segment-css', VI_WOO_BOPO_BUNDLE_CSS . 'segment.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-icon-css', VI_WOO_BOPO_BUNDLE_CSS . 'icon.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
			wp_enqueue_style( 'woo-bopo-bundle-semantic-tab-css', VI_WOO_BOPO_BUNDLE_CSS . 'tab.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );

			//script
			wp_enqueue_script(
				'iris', admin_url( 'js/iris.min.js' ), array(
				'jquery-ui-draggable',
				'jquery-ui-slider',
				'jquery-touch-punch'
			), VI_WOO_BOPO_BUNDLE_VERSION, 1
			);
			if ( WP_DEBUG ) {
				wp_enqueue_style( 'woo-bopo-bundle-setting-css', VI_WOO_BOPO_BUNDLE_CSS . 'bopo-settings.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
				wp_enqueue_script( 'woo-bopo-bundle-setting', VI_WOO_BOPO_BUNDLE_JS . 'bopo-settings.js', array( 'jquery' ), VI_WOO_BOPO_BUNDLE_VERSION, false );
			} else {
				wp_enqueue_style( 'woo-bopo-bundle-setting-css', VI_WOO_BOPO_BUNDLE_CSS . 'bopo-settings.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
				wp_enqueue_script( 'woo-bopo-bundle-setting', VI_WOO_BOPO_BUNDLE_JS . 'bopo-settings.min.js', array( 'jquery' ), VI_WOO_BOPO_BUNDLE_VERSION, false );
			}
			wp_localize_script( 'woo-bopo-bundle-setting', 'bopobbSettingVars', array(
					'ajaxurl'      => admin_url( 'admin-ajax.php' ),
					'bopobb_nonce' => wp_create_nonce( 'bopobb_nonce' ),
				)
			);
			wp_enqueue_script( 'woo-bopo-bundle-semantic-tab-js', VI_WOO_BOPO_BUNDLE_JS . 'tab.js', array( 'jquery' ), VI_WOO_BOPO_BUNDLE_VERSION, false );
			wp_enqueue_script( 'woo-bopo-bundle-asual-address-js', VI_WOO_BOPO_BUNDLE_JS . 'address.min.js', array( 'jquery' ), VI_WOO_BOPO_BUNDLE_VERSION, false );
			wp_enqueue_script( 'woo-bopo-bundle-semantic-dropdown-js', VI_WOO_BOPO_BUNDLE_JS . 'dropdown.min.js', array( 'jquery' ), VI_WOO_BOPO_BUNDLE_VERSION, false );
			wp_enqueue_script( 'woo-bopo-bundle-semantic-transition-js', VI_WOO_BOPO_BUNDLE_JS . 'transition.min.js', array( 'jquery' ), VI_WOO_BOPO_BUNDLE_VERSION, false );
		}
	}
}