<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'VI_WOO_BOPO_BUNDLE_Helper' ) ) {
	class VI_WOO_BOPO_BUNDLE_Helper {
		public static function bopohp_get_price( $product, $min_or_max = 'min' ) {
			switch ( $min_or_max ) {
				case 'src':
					return wc_get_price_excluding_tax( $product );
					break;
				case 'regular':
					return $product->get_regular_price();
					break;
				case 'sale':
					return $product->get_sale_price();
				default:
					return $product->get_price();
					break;
			}
		}

		public static function bopohp_get_calc_price( $product, $calculate = 'current' ) {
			switch ( $calculate ) {
				case 'regular':
					return $product->get_regular_price();
					break;
				case 'sale':
					return $product->get_sale_price();
					break;
				default:
					return $product->get_price();
					break;
			}
		}

		public static function bopohp_build_items( $ids = null ) {
			$items = array();

			if ( ! $ids ) {
				return;
			}

			if ( $ids ) {
				$ids_arr = explode( '%&', $ids );

				if ( is_array( $ids_arr ) && count( $ids_arr ) > 0 ) {
					foreach ( $ids_arr as $ids_item ) {
						$data = explode( '%/', $ids_item );

						if ( $pid = absint( isset( $data[0] ) ? $data[0] : 0 ) ) {
							$items[] = array(
								'id'  => $pid,
								'qty' => (float) ( isset( $data[1] ) ? $data[1] : 1 )
							);
						}
					}
				}
			}

			return $items;
		}

		public static function bopohp_get_price_to_display( $product, $qty = 1, $min_or_max = 'min' ) {
			return (float) wc_get_price_to_display( $product, array(
				'price' => self::bopohp_get_price( $product, $min_or_max ),
				'qty'   => $qty
			) );
		}

		public static function bopohp_get_price_excluding_tax( $product, $calc_by = 'current' ) {
			switch ( $calc_by ) {
				case 'regular':
					return wc_get_price_excluding_tax( $product, array( 'price' => $product->get_regular_price() ) );
				case 'sale':
					return wc_get_price_excluding_tax( $product, array( 'price' => $product->get_sale_price() ) );
				default:
					return wc_get_price_excluding_tax( $product );
			}
		}

		public static function bopohp_get_original_price_total( $product, $qty = 1, $calc_by = 'min' ) {
			$product_params['product_id'] = $product->get_ID();
			switch ( $calc_by ) {
				case 'regular':
					$product_params['product_price'] = wc_get_price_excluding_tax( $product, array( 'price' => $product->get_regular_price() ) );
					break;
				case 'sale':
					$product_params['product_price'] = wc_get_price_excluding_tax( $product, array( 'price' => $product->get_sale_price() ) );
					break;
				default:
					$product_params['product_price'] = wc_get_price_excluding_tax( $product );
					break;
			}
//			$product_params['product_price'] = wc_get_price_excluding_tax( $product, array('price'=>$product->get_sale_price()) );
			$price_params = apply_filters( 'bopobb_get_original_price', $product_params );

			return (float) $price_params['product_price'] * $qty;
		}

		public static function bopohp_clean_ids( $ids, $bundle_id = '' ) {
			if ( empty( $bundle_id ) ) {
				return $ids;
			}
			$bundle_items      = explode( '%&', $ids );
			$bundle_product    = wc_get_product( $bundle_id );
			$bundle_meta_items = $bundle_product->get_meta( 'bopobb_count', true );
			if ( ! $bundle_meta_items || count( $bundle_items ) <= (int) $bundle_meta_items ) {
				return $ids;
			}
			$sliced_array = array_slice( $bundle_items, 0, (int) $bundle_meta_items );

			return implode( '%&', $sliced_array );
		}

		public static function bopohp_clean_share_ids( $ids ) {
			$items = array();

			if ( ! $ids ) {
				return $items;
			}

			if ( $ids ) {
				$ids_arr = explode( 'b0p0it', $ids );

				if ( is_array( $ids_arr ) && count( $ids_arr ) > 0 ) {
					foreach ( $ids_arr as $ids_item ) {
						$data = explode( 'b0p0dt', $ids_item );

						if ( $pid = absint( isset( $data[0] ) ? $data[0] : 0 ) ) {
							$item        = [];
							$item['id']  = $pid;
							$item['qty'] = (int) ( isset( $data[1] ) ? $data[1] : 1 );
							if ( isset( $data[2] ) ) {
								$item['variations'] = str_replace( 'b0p0at', '&', $data[2] );
							}
							$items[] = $item;
						} else {
							$items[] = array();
						}
					}
				}
			}

			return $items;
		}

		public static function bopohp_data_in_bundle( $id_data, $bundle_item ) {
			if ( ! is_array( $id_data ) || empty( $id_data ) || ! isset( $id_data['id'] ) || ! isset( $id_data['qty'] )
			     || ! is_array( $id_data ) || empty( $bundle_item ) ) {
				return false;
			}
			$get_item_product = wc_get_product( (int) $id_data['id'] );
			if ( ! $get_item_product ) {
				return false;
			}
			$get_item_variation_id = '';
			if ( 'variation' == $get_item_product->get_type() ) {
				$get_item_variation_id     = (int) $id_data['id'];
				$get_item_product_id       = $get_item_product->get_parent_id();
				$get_item_product_variable = wc_get_product( $get_item_product_id );
				if ( ! $get_item_product_variable ) {
					return false;
				}
				$product_categories = $get_item_product_variable->get_category_ids();
				$product_tags       = $get_item_product_variable->get_tag_ids();
			} else {
				$get_item_product_id = (int) $id_data['id'];
				$product_categories  = $get_item_product->get_category_ids();
				$product_tags        = $get_item_product->get_tag_ids();
			}

			if ( isset( $bundle_item['bopobb_pbi_category'] ) && ! empty( $bundle_item['bopobb_pbi_category'] ) &&
			     is_array( $bundle_item['bopobb_pbi_category'] ) ) {
				if ( empty( $product_categories ) || ! is_array( $product_categories ) ) {
					return false;
				}
				$include_cat = array_intersect( $product_categories, $bundle_item['bopobb_pbi_category'] );
				if ( empty( $include_cat ) ) {
					return false;
				}
			}
			if ( isset( $bundle_item['bopobb_pbi_category_exclude'] ) && ! empty( $bundle_item['bopobb_pbi_category_exclude'] ) &&
			     is_array( $bundle_item['bopobb_pbi_category_exclude'] ) ) {
				if ( ! empty( $product_categories ) && is_array( $product_categories ) ) {
					$exclude_cat = array_intersect( $product_categories, $bundle_item['bopobb_pbi_category_exclude'] );
					if ( ! empty( $exclude_cat ) ) {
						return false;
					}
				}

			}
			if ( isset( $bundle_item['bopobb_pbi_tag'] ) && ! empty( $bundle_item['bopobb_pbi_tag'] ) &&
			     is_array( $bundle_item['bopobb_pbi_tag'] ) ) {
				if ( empty( $product_tags ) || ! is_array( $product_tags ) ) {
					return false;
				}
				$include_tag = array_intersect( $product_tags, $bundle_item['bopobb_pbi_tag'] );
				if ( empty( $include_tag ) ) {
					return false;
				}
			}
			if ( isset( $bundle_item['bopobb_pbi_tag_exclude'] ) && ! empty( $bundle_item['bopobb_pbi_tag_exclude'] ) &&
			     is_array( $bundle_item['bopobb_pbi_tag_exclude'] ) ) {
				if ( ! empty( $product_tags ) && is_array( $product_tags ) ) {
					$exclude_tag = array_intersect( $product_tags, $bundle_item['bopobb_pbi_tag_exclude'] );
					if ( ! empty( $exclude_tag ) ) {
						return false;
					}
				}

			}

			if ( isset( $bundle_item['bopobb_pbi_title'] ) && ! empty( $bundle_item['bopobb_pbi_title'] ) &&
			     is_array( $bundle_item['bopobb_pbi_title'] ) ) {
				if ( ! in_array( $get_item_product_id, $bundle_item['bopobb_pbi_title'] ) ) {
					return false;
				}
			}
			if ( isset( $bundle_item['bopobb_pbi_title_exclude'] ) && ! empty( $bundle_item['bopobb_pbi_title_exclude'] ) &&
			     is_array( $bundle_item['bopobb_pbi_title_exclude'] ) ) {
				if ( in_array( $get_item_product_id, $bundle_item['bopobb_pbi_title_exclude'] ) ) {
					return false;
				}
			}
			if ( ! empty( $get_item_variation_id ) && isset( $bundle_item['bopobb_pbi_title_variation'] ) &&
			     ! empty( $bundle_item['bopobb_pbi_title_variation'] ) && is_array( $bundle_item['bopobb_pbi_title_variation'] ) ) {
				if ( ! in_array( $get_item_product_id, $bundle_item['bopobb_pbi_title_variation'] ) ) {
					return false;
				}
			}
			if ( ! empty( $get_item_variation_id ) && isset( $bundle_item['bopobb_pbi_title_variation_exclude'] ) &&
			     ! empty( $bundle_item['bopobb_pbi_title_variation_exclude'] ) && is_array( $bundle_item['bopobb_pbi_title_variation_exclude'] ) ) {
				if ( in_array( $get_item_product_id, $bundle_item['bopobb_pbi_title_variation_exclude'] ) ) {
					return false;
				}
			}

			return true;
		}

		public static function bopohp_minify_items( $items ) {
			$minify_items = array();

			foreach ( $items as $item ) {
				if ( empty( $minify_items ) ) {
					$minify_items[] = $item;
				} else {
					$has_item = false;

					foreach ( $minify_items as $key => $minify_item ) {
						if ( $minify_item['id'] === $item['id'] ) {
							if ( isset( $minify_item['variations'] ) && isset( $item['variations'] ) ) {
								if ( $minify_item['variations'] === $item['variations'] ) {
									$minify_items[ $key ]['qty'] += $item['qty'];
									$has_item                    = true;
									continue;
								}
							} else {
								$minify_items[ $key ]['qty'] += $item['qty'];
								$has_item                    = true;
								continue;
							}
						}
					}

					if ( ! $has_item ) {
						$minify_items[] = $item;
					}
				}
			}

			return $minify_items;
		}

		public static function bopobb_decode_variations( $vr_arr, $mode = 0 ) {
			$o                    = '';
			$attr_array           = explode( '&', $vr_arr );
			$attr_array_formatted = [];
			foreach ( $attr_array as $attr_array_v ) {
				$attr_str_arr                             = explode( '=', $attr_array_v );
				$attr_array_formatted[ $attr_str_arr[0] ] = isset( $attr_str_arr[1] ) ? $attr_str_arr[1] : '';
			}
			if ( ! $mode ) {
				return $attr_array_formatted;
			}
			foreach ( $attr_array_formatted as $attr_k => $attr_v ) {
				$cur_key  = substr( $attr_k, 10 );
				$cur_term = get_term_by( 'slug', $attr_v, $cur_key );

				if ( ! empty( $cur_term ) ) {
					$o .= ' - ' . $cur_term->name;
				}
			}

			return $o;
		}

		public static function bopobb_build_title( $vr_arr ) {
			$o = '';
			if ( is_array( $vr_arr ) || is_object( $vr_arr ) ) {
				foreach ( $vr_arr as $att_k => $att_v ) {
					$cur_key  = substr( $att_k, 10 );
					$cur_term = get_term_by( 'slug', $att_v, $cur_key );
					if ( ! empty( $cur_term ) ) {
						$o .= ' - ' . $cur_term->name;
					}
				}
			}

			return $o;
		}

		public static function bopobb_variation_merge( $vr_arr ) {
			$o = '';
			if ( is_array( $vr_arr ) || is_object( $vr_arr ) ) {
				foreach ( $vr_arr as $att_k => $att_v ) {
					if ( empty( $o ) ) {
						$o = $att_k . '=' . $att_v;
					} else {
						$o .= '&' . $att_k . '=' . $att_v;
					}
				}
			}

			return $o;
		}

		public static function bopobb_build_variations( $vr_arr ) {
			$o = '';
			if ( is_array( $vr_arr ) || is_object( $vr_arr ) ) {
				foreach ( $vr_arr as $vr_k => $vr_v ) {
					if ( empty( $o ) ) {
						$o = $vr_k . '=' . $vr_v;
					} else {
						$o .= '&' . $vr_k . '=' . $vr_v;
					}
				}
			}

			return $o;
		}

		// Check variation already belong to other variation
		public static function bopobb_is_variation_allow( $pr_prd, $vr_id, $vr_arr, $vr_cp ) {
			$vr_pre   = self::bopobb_get_any( $pr_prd, $vr_id, $vr_arr );
			$vr_ready = self::bopobb_get_simple_compare( $vr_cp );
			if ( ( $vr_ready ) && ( is_array( $vr_ready ) || is_object( $vr_ready ) ) ) {
				if ( is_array( $vr_pre ) || is_object( $vr_pre ) ) {
					if ( in_array( $vr_pre, $vr_ready ) ) {
						return false;
					}
				} else {
					if ( in_array( [ $vr_pre ], $vr_ready ) ) {
						return false;
					}
				}
			}

			return true;
		}

		public static function bopobb_get_variation_default( $pr_prd, $vr_id, $vr_arr ) {
			$vr_op  = [];
			$vr_pre = self::bopobb_get_any( $pr_prd, $vr_id, $vr_arr );
			$vr_op  = self::bopobb_any_default( $vr_pre );

			return $vr_op;
		}

		public static function bopobb_get_variations( $pr_prd, $vr_id, $vr_arr, $vr_cp ) {
			// get any array
			$vr_op    = [];
			$vr_pre   = self::bopobb_get_any( $pr_prd, $vr_id, $vr_arr );
			$vr_op    = self::bopobb_calc_any( $vr_pre );
			$vr_ready = self::bopobb_get_simple_compare( $vr_cp );
			// check with compare array
			if ( ! is_array( $vr_op ) || empty( $vr_op ) ) {

				return array();
			}
			foreach ( $vr_op as $ck_k => $ck_v ) {
				if ( ( $vr_ready ) && ( is_array( $vr_ready ) || is_object( $vr_ready ) ) ) {
					if ( is_array( $ck_v ) || is_object( $ck_v ) ) {
						if ( in_array( $ck_v, $vr_ready ) ) {
							unset( $vr_op[ $ck_k ] );
						}
					} else {

						if ( in_array( [ $ck_v ], $vr_ready ) ) {
							unset( $vr_op[ $ck_k ] );
						}
					}
				}
			}

			return array_values( $vr_op );
		}

		public static function bopobb_get_simple_compare( $vr_cp ) {
			if ( is_array( $vr_cp ) || is_object( $vr_cp ) ) {
				foreach ( $vr_cp as $vr_k2 => $vr_v2 ) {
					if ( isset( $vr_v2 ['id'] ) ) {
						unset( $vr_cp[ $vr_k2 ]['id'] );
						continue;
					}
				}

				return array_values( $vr_cp );
			} else {
				return false;
			}
		}

		public static function bopobb_set_array( $vr_cp, $vr_id ) {
			$vr_id = [ 'id' => $vr_id ];
			if ( is_array( $vr_cp ) || is_object( $vr_cp ) ) {
				foreach ( $vr_cp as $vr_k => $vr_v ) {
					if ( is_array( $vr_v ) || is_object( $vr_v ) ) {
						$vr_cp[ $vr_k ] = array_merge( $vr_id, $vr_cp[ $vr_k ] );
					} else {
						$vr_cp[ $vr_k ] = array_merge( $vr_id, [ $vr_cp[ $vr_k ] ] );
					}
				}
			}

			return $vr_cp;
		}

		public static function bopobb_get_any( $pr_prd, $vr_id, $vr_arr ) {
			$o = [];
			foreach ( $vr_arr as $attr_k => $attr_v ) {
				if ( empty( $attr_v ) ) {
					$cur_key  = substr( $attr_k, 10 );
					$get_atts = $pr_prd->get_variation_attributes();
					if ( isset( $get_atts[ $cur_key ] ) ) {
						$o[] = $get_atts[ $cur_key ];
					} elseif ( isset( $get_atts[ ucfirst( $cur_key ) ] ) ) {
						$o[] = $get_atts[ ucfirst( $cur_key ) ];
					}
				} else {
					$o[] = $attr_v;
				}
			}

			return $o;
		}

		public static function bopobb_any_default( $any_arr ) {
			if ( is_array( $any_arr ) || is_object( $any_arr ) ) {
				$o = [];
				foreach ( $any_arr as $att_arr ) {
					if ( is_array( $att_arr ) || is_object( $att_arr ) ) {
						$o[] = $att_arr[0];
					} else {
						$o[] = $att_arr;
					}
				}

				return $o;
			} else {
				return $any_arr;
			}
		}

		public static function bopobb_calc_any( $any_arr ) {
			$o           = [];
			$_i          = 0;
			$count_input = count( $any_arr );

			return self::bopobb_recursive_any( $o, $any_arr, $_i, intval( $count_input ) );
		}

		public static function bopobb_recursive_any( $arr_o, $arr_any, $index, $count ) {
			if ( $index >= $count - 1 ) {
				return $arr_any[ $index ];
			} else {
				return self::bopobb_map_array( $arr_any[ $index ], self::bopobb_recursive_any( $arr_o, $arr_any, $index + 1, $count ) );
			}
		}

		public static function bopobb_map_array( $arr_1, $arr_2 ) {
			$o = [];
			if ( is_array( $arr_1 ) || is_object( $arr_1 ) ) {
				foreach ( $arr_1 as $attr_v ) {
					if ( is_array( $arr_2 ) || is_object( $arr_2 ) ) {
						foreach ( $arr_2 as $attr_v2 ) {
							if ( is_array( $attr_v ) || is_object( $attr_v ) ) {
								if ( is_array( $attr_v2 ) || is_object( $attr_v2 ) ) {
									$o[] = array_merge( $attr_v, $attr_v2 );
								} else {
									$o[] = array_merge( $attr_v, [ $attr_v2 ] );
								}
							} else {
								if ( is_array( $attr_v2 ) || is_object( $attr_v2 ) ) {
									$o[] = array_merge( [ $attr_v ], $attr_v2 );
								} else {
									$o[] = array_merge( [ $attr_v ], [ $attr_v2 ] );
								}
							}
						}
					} else {
						if ( is_array( $attr_v ) || is_object( $attr_v ) ) {
							$o[] = array_merge( $attr_v, [ $arr_2 ] );
						} else {
							$o[] = array_merge( [ $attr_v ], [ $arr_2 ] );
						}
					}
				}
			} else {
				if ( is_array( $arr_2 ) || is_object( $arr_2 ) ) {
					foreach ( $arr_2 as $attr_v2 ) {
						if ( is_array( $attr_v2 ) || is_object( $attr_v2 ) ) {
							$o[] = array_merge( [ $arr_1 ], $attr_v2 );
						} else {
							$o[] = array_merge( [ $arr_1 ], [ $attr_v2 ] );
						}
					}
				} else {
					$o[] = array_merge( [ $arr_1 ], [ $arr_2 ] );
				}
			}

			return $o;
		}

		public static function bopobb_tax_rate( $product ) {
			$return_tax = 0;

			if ( $product->is_taxable() ) {
				if ( ! wc_prices_include_tax() ) {
					$tax_rates  = WC_Tax::get_rates( $product->get_tax_class() );
					$return_tax = self::bopobb_tax_from_class( $tax_rates );
				} else {
					$tax_rates      = WC_Tax::get_rates( $product->get_tax_class() );
					$base_tax_rates = WC_Tax::get_base_tax_rates( $product->get_tax_class( 'unfiltered' ) );
					$return_tax     = self::bopobb_tax_from_class( $base_tax_rates );
					/**
					 * If the customer is excempt from VAT, remove the taxes here.
					 * Either remove the base or the user taxes depending on woocommerce_adjust_non_base_location_prices setting.
					 */
					if ( ! empty( WC()->customer ) && WC()->customer->get_is_vat_exempt() ) { // @codingStandardsIgnoreLine.
						$return_tax = 0;
						/**
						 * The woocommerce_adjust_non_base_location_prices filter can stop base taxes being taken off when dealing with out of base locations.
						 * e.g. If a product costs 10 including tax, all users will pay 10 regardless of location and taxes.
						 * This feature is experimental @since 2.4.7 and may change in the future. Use at your risk.
						 */
					} elseif ( $tax_rates !== $base_tax_rates && apply_filters( 'woocommerce_adjust_non_base_location_prices', true ) ) {
						$return_tax = self::bopobb_tax_from_class( $tax_rates );
					}
				}
			}

			return $return_tax;
		}

		public static function bopobb_tax_from_class( $rates = array() ) {
			$taxes_rate = 0;
			if ( $rates ) {
				foreach ( $rates as $key => $rate ) {
					if ( $rate['rate'] ) {
						$taxes_rate = $rate['rate'];
					}
				}
			}

			return $taxes_rate;
		}

		public static function bopohp_price_scope( $product, $discount, $convert = false, $calc_by = 'current' ) {
//			$price = wc_get_price_excluding_tax( $product );
			$price = self::bopohp_get_price_excluding_tax( $product, $calc_by );

			if ( $product->is_type( 'variable' ) ) {
				if ( $product->has_child() ) {
					$min_price = 0;
					$max_price = 0;
					foreach ( $product->get_children() as $child_id ) {
						$child_product = wc_get_product( $child_id );
//						$child_price   = wc_get_price_excluding_tax( $child_product );
						$child_price = self::bopohp_get_price_excluding_tax( $child_product, $calc_by );
						if ( $child_price > $max_price ) {
							$max_price = (float) $child_price;
						}
						if ( $child_price < $min_price || $min_price == 0 ) {
							$min_price = (float) $child_price;
						}
					}
					$max_price_original = $max_price;
					$min_price_original = $min_price;
					if ( $discount[1] != 0 ) {
//						if ( $discount[0] == 0 ) {
//							$discount_min = floatval( $min_price / 100 * (float) $discount[1] );
//							$min_price    = $min_price - floatval( $discount_min );
//							$discount_max = floatval( $max_price / 100 * (float) $discount[1] );
//							$max_price    = $max_price - floatval( $discount_max );
//						} else {
//							if ( $convert ) {
//								$discount_number = (float) $discount[1];
//							} else {
//								$discount_number = apply_filters( 'bopobb_convert_currency_price', (float) $discount[1] );
//							}
//							$min_price = $min_price - floatval( $discount_number );
//							$max_price = $max_price - floatval( $discount_number );
//						}
						switch ( $discount[0] ) {
							case 1:
								if ( $convert ) {
									$discount_number = (float) $discount[1];
								} else {
									$discount_number = apply_filters( 'bopobb_convert_currency_price', (float) $discount[1] );
								}
								$min_price = $min_price - floatval( $discount_number );
								$max_price = $max_price - floatval( $discount_number );
								break;
							case 2:
								if ( $convert ) {
									$min_price = $max_price = (float) $discount[1];
								} else {
									$min_price = $max_price = apply_filters( 'bopobb_convert_currency_price', (float) $discount[1] );
								}
								break;
							case 0:
							default:
								$discount_min = floatval( $min_price / 100 * (float) $discount[1] );
								$min_price    = $min_price - floatval( $discount_min );
								$discount_max = floatval( $max_price / 100 * (float) $discount[1] );
								$max_price    = $max_price - floatval( $discount_max );
								break;
						}
					} elseif ( $discount[0] == 2 ) {
						if ( $convert ) {
							$min_price = $max_price = (float) $discount[1];
						} else {
							$min_price = $max_price = apply_filters( 'bopobb_convert_currency_price', (float) $discount[1] );
						}
					}
					$min_price = $min_price > 0 ? $min_price : 0;
					$max_price = $max_price > 0 ? $max_price : 0;
					if ( $min_price == $max_price ) {
						if ( $max_price_original == $min_price_original ) {
							$min_price          = self::bopobb_price_show( $product, $min_price );
							$min_price_original = self::bopobb_price_show( $product, $min_price_original );
							$show_price         = wc_format_sale_price( wc_price( $min_price_original ), wc_price( $min_price ) ) . $product->get_price_suffix();

							return array( $show_price, 0 );
						} else {
							$min_price = self::bopobb_price_show( $product, $min_price );

							return array( wc_price( $min_price ), 0 );
						}
					}
					$min_price = self::bopobb_price_show( $product, $min_price );
					$max_price = self::bopobb_price_show( $product, $max_price );

					return array(
						wc_price( $min_price ) . '<span class="bopobb-product-price-range-separator"> - </span>' . wc_price( $max_price ),
						0
					);
				}

				return array( $product->get_price_html(), 0 );
			}

			if ( $product->is_type( 'simple' ) || $product->is_type( 'variation' ) ) {
				if ( $discount[1] == 0 ) {
					$price = $discount[0] == 2 ? 0 : self::bopobb_price_show( $product, $price );

					return array( wc_price( $price ) . $product->get_price_suffix(), $price );
				} else {
//					if ( $discount[0] == 0 ) {
//						$discount_number = floatval( $price / 100 * (float) $discount[1] );
//						$price_sale      = $price - floatval( $discount_number );
//					} else {
//						if ( $convert ) {
//							$discount_number = (float) $discount[1];
//						} else {
//							$discount_number = apply_filters( 'bopobb_convert_currency_price', (float) $discount[1] );
//						}
//						$price_sale = $price - floatval( $discount_number );
//					}
					switch ( $discount[0] ) {
						case 1:
							if ( $convert ) {
								$discount_number = (float) $discount[1];
							} else {
								$discount_number = apply_filters( 'bopobb_convert_currency_price', (float) $discount[1] );
							}
							$price_sale = $price - floatval( $discount_number );
							break;
						case 2:
							$price_sale = (float) $discount[1];
							break;
						case 0:
						default:
							$discount_number = floatval( $price / 100 * (float) $discount[1] );
							$price_sale      = $price - floatval( $discount_number );
							break;
					}
					$price_sale = $price_sale > 0 ? $price_sale : 0;
					$price      = self::bopobb_price_show( $product, $price );
					$price_sale = self::bopobb_price_show( $product, $price_sale );

					return array(
						wc_format_sale_price( wc_price( $price ), wc_price( $price_sale ) ) . $product->get_price_suffix(),
						$price_sale
					);
				}

			}

			return array(
				wc_get_price_to_display( $product, [
					'price' => $price,
					'qty'   => 1
				] ),
				$price
			);
		}

		public static function bopobb_price_standard( $product, $line_price ) {
			$return_price = $line_price;
			if ( $product->is_taxable() && wc_prices_include_tax() ) {
				$base_tax_rates = WC_Tax::get_base_tax_rates( $product->get_tax_class( 'unfiltered' ) );
				$standard_tax   = WC_Tax::calc_tax( $line_price, $base_tax_rates, false );
				if ( 'yes' === get_option( 'woocommerce_tax_round_at_subtotal' ) ) {
					$standard_tax = array_sum( $standard_tax );
				} else {
					$standard_tax = array_sum( array_map( 'wc_round_tax_total', $standard_tax ) );
				}
				$return_price = $line_price + $standard_tax;
			}

			return $return_price;
		}

		public static function bopobb_price_item_cart( $product, $line_price = '' ) {
			$return_price = $product->get_price();

			if ( $product->is_taxable() && wc_prices_include_tax() ) {
				$base_tax_rates = WC_Tax::get_base_tax_rates( $product->get_tax_class( 'unfiltered' ) );
				$standard_tax   = WC_Tax::calc_tax( $line_price, $base_tax_rates, false );
				if ( 'yes' === get_option( 'woocommerce_tax_round_at_subtotal' ) ) {
					$standard_tax = array_sum( $standard_tax );
				} else {
					$standard_tax = array_sum( array_map( 'wc_round_tax_total', $standard_tax ) );
				}
				$return_price = $line_price + $standard_tax;
			}

			return $return_price;
		}

		public static function bopobb_price_show( $product, $line_price ) {
			$return_price = $line_price;
			$show_tax     = 'incl' === get_option( 'woocommerce_tax_display_shop' ) ? 1 : 0;
			if ( $product->is_taxable() && $show_tax ) {
				if ( ! wc_prices_include_tax() ) {
					$tax_rates = WC_Tax::get_rates( $product->get_tax_class() );
					$taxes     = WC_Tax::calc_tax( $line_price, $tax_rates, false );

					if ( 'yes' === get_option( 'woocommerce_tax_round_at_subtotal' ) ) {
						$taxes_total = array_sum( $taxes );
					} else {
						$taxes_total = array_sum( array_map( 'wc_round_tax_total', $taxes ) );
					}

					$return_price = $line_price + $taxes_total;
				} else {
					$tax_rates      = WC_Tax::get_rates( $product->get_tax_class() );
					$base_tax_rates = WC_Tax::get_base_tax_rates( $product->get_tax_class( 'unfiltered' ) );
					if ( ! empty( WC()->customer ) && WC()->customer->get_is_vat_exempt() ) {

						return $return_price;
					} else {
						if ( apply_filters( 'woocommerce_adjust_non_base_location_prices', true ) ) {
							$additional_tax = $tax_rates !== $base_tax_rates ?
								WC_Tax::calc_tax( $line_price, $tax_rates, false ) :
								WC_Tax::calc_tax( $line_price, $base_tax_rates, false );
						} else {
							$additional_tax = WC_Tax::calc_tax( $line_price, $base_tax_rates, false );
						}
						if ( 'yes' === get_option( 'woocommerce_tax_round_at_subtotal' ) ) {
							$additional_tax = array_sum( $additional_tax );
						} else {
							$additional_tax = array_sum( array_map( 'wc_round_tax_total', $additional_tax ) );
						}
						$return_price = $line_price + $additional_tax;
					}
				}
			}

			return $return_price;
		}

		static function bopobb_search_range_product( $arg_input = [], $settings = [] ) {
			$cat         = isset( $arg_input['bopobb_pbi_category'] ) ? $arg_input['bopobb_pbi_category'] : '';
			$ex_cat      = isset( $arg_input['bopobb_pbi_category_exclude'] ) ? $arg_input['bopobb_pbi_category_exclude'] : '';
			$tag         = isset( $arg_input['bopobb_pbi_tag'] ) ? $arg_input['bopobb_pbi_tag'] : '';
			$ex_tag      = isset( $arg_input['bopobb_pbi_tag_exclude'] ) ? $arg_input['bopobb_pbi_tag_exclude'] : '';
			$prod        = isset( $arg_input['bopobb_pbi_title'] ) ? $arg_input['bopobb_pbi_title'] : '';
			$ex_prod     = isset( $arg_input['bopobb_pbi_title_exclude'] ) ? $arg_input['bopobb_pbi_title_exclude'] : '';
			$sort        = isset( $arg_input['bopobb_bpi_sort'] ) ? $arg_input['bopobb_bpi_sort'] : '';
			$order       = isset( $arg_input['bopobb_bpi_order'] ) ? $arg_input['bopobb_bpi_order'] : '';
			$prod_var    = isset( $arg_input['bopobb_pbi_title_variation'] ) ? $arg_input['bopobb_pbi_title_variation'] : '';
			$ex_prod_var = isset( $arg_input['bopobb_pbi_title_variation_exclude'] ) ? $arg_input['bopobb_pbi_title_variation_exclude'] : '';
//			$key         = isset( $arg_input['key_word'] ) ? $arg_input['key_word'] : '';

			$optional_item   = isset( $arg_input['bopobb_bpi_optional_item'] ) ? $arg_input['bopobb_bpi_optional_item'] : '';
			$discount_item   = isset( $arg_input['bopobb_bpi_discount'] ) ? $arg_input['bopobb_bpi_discount'] : '';
			$discount_number = isset( $arg_input['bopobb_bpi_discount_number'] ) ? $arg_input['bopobb_bpi_discount_number'] : '';

			$arg     = array(
				'post_status'    => 'publish',
				'post_type'      => 'product',
				'posts_per_page' => - 1,
//				's'              => $key
			);
			$tax_arr = [];
			if ( ! empty( $cat ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_cat',
					'field'    => 'term_id',
					'terms'    => $cat,
				];
			}
			if ( ! empty( $ex_cat ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_cat',
					'field'    => 'term_id',
					'terms'    => $ex_cat,
					'operator' => 'NOT IN',
				];
			}
			if ( ! empty( $tag ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_tag',
					'field'    => 'term_id',
					'terms'    => $tag,
				];
			}
			if ( ! empty( $ex_tag ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_tag',
					'field'    => 'term_id',
					'terms'    => $ex_tag,
					'operator' => 'NOT IN',
				];
			}
			if ( ! empty( $tax_arr ) ) {
				$arg['tax_query'] = $tax_arr;// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_tax_query
			}
			if ( ! empty( $prod ) ) {
				$arg['post__in'] = $prod;
			}

			switch ( $sort ) {
				case 'ratting':
					$arg['orderby']  = 'meta_value_num';
					$arg['meta_key'] = '_wc_average_rating';// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_key
					$arg['order']    = $order;
					break;
				case 'price':
					$arg['orderby']  = 'meta_value_num';
					$arg['meta_key'] = '_price';// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_key
					$arg['order']    = $order;
					break;
				default:
					$arg['orderby'] = 'title';
					$arg['order']   = $order;
					break;
			}

			$the_query       = new WP_Query( $arg );
			$founded_count   = $the_query->found_posts;
			$calc_price_base = $settings['bopobb_calculate_price'];

			$found_products = array();
			if ( $the_query->have_posts() ) {
				$s_product_ids = $the_query->posts;
				foreach ( $s_product_ids as $s_index => $s_product_object ) {
					if ( ! is_object( $s_product_object ) || empty( $s_product_object ) || ! property_exists( $s_product_object, 'ID' ) ) {
						continue;
					}
					$s_product_id = $s_product_object->ID;
					if ( is_array( $s_product_id ) || is_object( $s_product_id ) || empty( $s_product_id ) ) {
						continue;
					}
					$prd = wc_get_product( $s_product_id );

					if ( ! $prd || ! $prd->is_purchasable() ) {
						continue;
					}
					if ( ! empty( $ex_prod ) ) {
						if ( in_array( strval( $s_product_id ), array_values( $ex_prod ), true ) ) {

							continue;
						}
					}
					if ( ! in_array( $prd->get_type(), $settings['bopobb_type_include'], true ) ) {
						continue;
					}

					// Get default
					if ( $prd->is_type( 'variable' ) ) {
						$product_children = $prd->get_children();
						// Check child valid for sale
						if ( count( $product_children ) ) {
							for ( $i = 0; $i < count( $product_children ); $i ++ ) {
								if ( ! empty( $prod_var ) ) {
									if ( ! in_array( $product_children[ $i ], $prod_var ) ) {
										continue;
									}
								}
								if ( ! empty( $ex_prod_var ) ) {
									if ( in_array( $product_children[ $i ], $ex_prod_var ) ) {
										continue;
									}
								}
								$valriation_prd = wc_get_product( $product_children[ $i ] );
								$out_stock      = $settings['bopobb_out_stock'];
								if ( $valriation_prd->is_purchasable() && $valriation_prd->get_price() &&
								     ( ( $valriation_prd->get_manage_stock() && $valriation_prd->get_stock_quantity() ) || ( ! $valriation_prd->get_manage_stock() ) || $out_stock ) ) {
									$the_product_price = self::bopohp_get_calc_price( $valriation_prd, $calc_price_base );
									$found_products[]  = array(
										'id'    => $product_children[ $i ],
										'price' => (float) $the_product_price
									);
								}
							}
							continue;
						} else {
							continue;
						}

					} else if ( $prd->is_purchasable() ) {
						// Simple
//						wp_reset_postdata();
						$the_product       = new WC_Product( $s_product_id );
						$the_product_price = self::bopohp_get_calc_price( $the_product, $calc_price_base );
						$found_products[]  = array( 'id' => $s_product_id, 'price' => (float) $the_product_price );
					} else {
						continue;
					}
				}
				if ( ! empty( $found_products ) ) {
					$max_product = $min_product = array();
					foreach ( $found_products as $found_product ) {
						if ( ! isset( $found_product['price'] ) || ! isset( $found_product['id'] ) ) {
							continue;
						}
						if ( empty( $max_product ) ) {
							$max_product = $found_product;
						} else {
							if ( $max_product['price'] < $found_product['price'] ) {
								$max_product = $found_product;
							}
						}
						if ( empty( $min_product ) ) {
							$min_product = $found_product;
						} else {
							if ( $min_product['price'] > $found_product['price'] ) {
								$min_product = $found_product;
							}
						}
					}
					$min_product['price'] = $optional_item ? 0 : self::calculate_discount_item( $min_product['price'], $discount_item, $discount_number );
					$max_product['price'] = self::calculate_discount_item( $max_product['price'], $discount_item, $discount_number );

					return array( 'max' => $max_product['price'], 'min' => $min_product['price'] );
				}

				return $found_products;
			}

//			wp_reset_postdata();

			return null;
		}

		static function calculate_discount_item( $price_item, $discount_item, $discount_number ) {
			if ( '' == $discount_item || '' == $discount_number ) {
				return $price_item;
			}
			switch ( $discount_item ) {
				case 0:
					if ( ! $price_item ) {
						return $price_item;
					}
					$return_price = ( floatval( $price_item ) / 100 ) * floatval( $discount_number );
					$return_price = floatval( $price_item ) - floatval( $return_price );
					if ( $return_price > $price_item ) {
						$return_price = $price_item;
					}
					if ( $return_price < 0 ) {
						$return_price = 0;
					}

					return $return_price;
				case 1:
					if ( ! $price_item ) {
						return $price_item;
					}
					$return_price = floatval( $price_item ) - floatval( $discount_number );
					if ( $return_price < 0 ) {
						$return_price = 0;
					}

					return $return_price;
				case 2:
				default:
					return floatval( $discount_number );
			}
		}

		static function set_bundle_meta_range( $product, $settings, $bundle_count, $meta_item ) {
			$available = 0;
			$price     = 0;
			$max_price = 0;
			for ( $i = 0; $i < absint( $bundle_count ); $i ++ ) {
//							if ( is_array( $item ) && isset( $item['bopobb_bpi_optional_item'] ) && $item['bopobb_bpi_optional_item'] ) {
//								$available ++;
//								continue;
//							}
				if ( ! isset( $meta_item[ $i ] ) || empty( $meta_item[ $i ] ) ) {
					continue;
				}
				$_product_array = VI_WOO_BOPO_BUNDLE_Helper::bopobb_search_range_product( $meta_item[ $i ], $settings );
				if ( ! empty( $_product_array ) && isset( $_product_array['max'] ) && isset( $_product_array['min'] ) ) {
					$max_price += (float) $_product_array['max'];
					$price     += (float) $_product_array['min'];
					$available ++;
				}
			}

			if ( $available != $bundle_count ) {
				return;
			}
			$price     = VI_WOO_BOPO_BUNDLE_Helper::bopobb_price_show( $product, $price );
			$max_price = VI_WOO_BOPO_BUNDLE_Helper::bopobb_price_show( $product, $max_price );

			if ( $max_price && $max_price != $price ) {
				$product->update_meta_data( 'bopobb_min_price', $price );
				$product->update_meta_data( 'bopobb_max_price', $max_price );
				$product->save_meta_data();

				return;
			}

			$product->update_meta_data( 'bopobb_min_price', $price );
			$product->update_meta_data( 'bopobb_max_price', $price );
			$product->save_meta_data();
		}
	}

	new VI_WOO_BOPO_BUNDLE_Helper();
}