<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'VI_WOO_BOPO_BUNDLE_Frontend' ) ) {
	class VI_WOO_BOPO_BUNDLE_Frontend {
		protected $settings;
		protected static $ajax_loading = false;
		protected static $_instance = null;
		protected $language;

		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}

		function __construct() {
			$this->settings = VI_WOO_BOPO_BUNDLE_DATA::get_instance();
			$this->language = '';
			// Shortcode
			add_shortcode( 'bopobb_bundle', array( $this, 'bopobb_shortcode_bundle' ) );

			// Elementor
			add_action( 'elementor/frontend/after_enqueue_scripts', array( $this, 'wp_enqueue_scripts_elementor' ) );

			// Enqueue frontend scripts
			$theme = wp_get_theme();
			if ( 'Cerato Child' == $theme->name || 'Cerato' == $theme->name ) {
				add_action( 'wp_enqueue_scripts', array( $this, 'bopobb_wp_enqueue_scripts' ), 100 );
			} else {
				add_action( 'wp_enqueue_scripts', array( $this, 'bopobb_wp_enqueue_scripts' ) );
			}

			// Register popup
			add_action( 'wp_footer', array( $this, 'bopobb_footer' ) );

			// Bundle in single product
			add_action( 'init', array( $this, 'bopobb_init_single_bundle' ) );
//			add_action( 'woocommerce_single_product_summary', array(
//				$this,
//				'bopobb_single_product_summary_bundled'
//			), 6 );

			// Add to cart form & button
			add_filter( 'woocommerce_is_purchasable', array( $this, 'bopobb_is_purchasable' ), 20, 2 );
			add_filter( 'woocommerce_quantity_input_min', array( $this, 'bopobb_add_to_cart_quantity' ), 99, 2 );
			add_filter( 'woocommerce_quantity_input_max', array( $this, 'bopobb_add_to_cart_quantity' ), 99, 2 );
			add_action( 'woocommerce_bopobb_add_to_cart', array( $this, 'bopobb_add_to_cart_form' ) );
			add_action( 'woocommerce_before_add_to_cart_button', array( $this, 'bopobb_add_to_cart_button' ) );

			// Check validation
			add_filter( 'woocommerce_add_to_cart_validation', array(
				$this,
				'bopobb_add_to_cart_validation'
			), 10, 2 );

			add_filter( 'woocommerce_add_cart_item_data', array( $this, 'bopobb_add_cart_item_data' ), 26, 2 );
			add_action( 'woocommerce_add_to_cart', array( $this, 'bopobb_add_to_cart' ), 10, 6 );
			add_filter( 'woocommerce_get_cart_item_from_session', array(
				$this,
				'bopobb_get_cart_item_from_session'
			), 10, 2 );

			// Cart item
			add_filter( 'woocommerce_cart_item_name', array( $this, 'bopobb_cart_item_name' ), 10, 2 );
			add_filter( 'woocommerce_cart_item_quantity', array( $this, 'bopobb_cart_item_quantity' ), 10, 3 );
			add_filter( 'woocommerce_cart_item_remove_link', array( $this, 'bopobb_cart_item_remove_link' ), 10, 2 );
			add_action( 'woocommerce_cart_item_removed', array( $this, 'bopobb_cart_item_removed' ), 10, 2 );
			add_filter( 'woocommerce_cart_item_price', array( $this, 'bopobb_cart_item_price' ), 10, 2 );
			add_filter( 'woocommerce_cart_item_subtotal', array( $this, 'bopobb_cart_item_subtotal' ), 10, 2 );
			add_filter( 'woocommerce_cart_contents_count', array( $this, 'bopobb_cart_contents_count' ) );

			add_filter( 'woocommerce_cart_item_class', array( $this, 'bopobb_item_class' ), 10, 2 );
			add_filter( 'woocommerce_mini_cart_item_class', array( $this, 'bopobb_item_class' ), 10, 2 );

			// Undo remove
			add_action( 'woocommerce_cart_item_restored', array( $this, 'bopobb_cart_item_restored' ), 10, 2 );

			// Order
			add_filter( 'woocommerce_order_formatted_line_subtotal', array(
				$this,
				'bopobb_order_formatted_line_subtotal'
			), 10, 2 );
			add_action( 'woocommerce_checkout_create_order_line_item', array(
				$this,
				'bopobb_checkout_create_order_line_item'
			), 10, 3 );
			add_filter( 'woocommerce_order_item_class', array( $this, 'bopobb_item_class' ), 10, 2 );
			add_filter( 'woocommerce_order_item_name', array( $this, 'bopobb_order_item_name' ), 99, 2 );
			add_filter( 'woocommerce_order_item_quantity_html', array( $this, 'bopobb_order_item_quantity' ), 99, 3 );
			add_filter( 'woocommerce_checkout_cart_item_quantity', array(
				$this,
				'bopobb_checkout_item_quantity'
			), 99, 3 );

			// Order again
			add_filter( 'woocommerce_order_again_cart_item_data', array(
				$this,
				'bopobb_order_again_cart_item_data'
			), 10, 2 );
			add_action( 'woocommerce_cart_loaded_from_session', array( $this, 'bopobb_cart_loaded_from_session' ) );

			// Admin order
			add_action( 'woocommerce_ajax_add_order_item_meta', array(
				$this,
				'bopobb_ajax_add_order_item_meta'
			), 10, 3 );
			add_filter( 'woocommerce_hidden_order_itemmeta', array( $this, 'bopobb_hidden_order_item_meta' ), 10, 1 );
			add_action( 'woocommerce_before_order_itemmeta', array( $this, 'bopobb_before_order_item_meta' ), 10, 1 );
			add_action( 'woocommerce_before_order_itemmeta', array(
				$this,
				'bopobb_before_order_item_meta_product'
			), 10, 3 );

			// Shipping
			add_filter( 'woocommerce_cart_shipping_packages', array( $this, 'bopobb_cart_shipping_packages' ), 99, 1 );

			// Coupons
			add_filter( 'woocommerce_coupon_is_valid_for_product', array(
				$this,
				'bopobb_coupon_is_valid_for_product'
			), 10, 4 );

			// Loop add-to-cart
			add_filter( 'woocommerce_loop_add_to_cart_link', array( $this, 'bopobb_loop_add_to_cart_link' ), 99, 2 );

			// Use woocommerce_get_cart_contents instead of woocommerce_before_calculate_totals, prevent price error on mini-cart
			add_filter( 'woocommerce_get_cart_contents', array( $this, 'bopobb_get_cart_contents' ), 99, 1 );

			// Price html
			add_filter( 'woocommerce_get_price_html', array( $this, 'bopobb_get_price_html' ), 99, 2 );

			// Admin
			add_filter( 'display_post_states', array( $this, 'bopobb_display_post_states' ), 10, 2 );

			// Shop title
			add_filter( 'woocommerce_product_add_to_cart_text', array(
				$this,
				'bopobb_display_add_to_cart_text'
			), 10, 2 );

			// Replace popup title with hook
			//add_action( 'bopobb_popup_item_title', array( $this, 'bopobb_popup_item_title' ), 10, 2 );

			// Custom filter for multi currency
			// Cart All In One
			add_action( 'vi-wcaio-product-bopobb-add-to-cart', array( $this, 'product_bopobb_add_to_cart' ), 10, 3 );
			add_filter( 'vi_wcaio_mini_cart_pd_remove', array( $this, 'vi_wcaio_mini_cart_pd_remove' ), 10, 3 );
			add_filter( 'vi_wcaio_mini_cart_pd_qty', array( $this, 'vi_wcaio_mini_cart_pd_qty' ), 10, 4 );
			add_filter( 'viwcaio-sidebar-cart-product-class', array(
				$this,
				'viwcaio_sidebar_cart_product_class'
			), 10, 3 );

			//side-cart-woocommerce
			add_action( 'xoo_wsc_product_start', array( $this, 'product_bopobb_side_cart_start' ), 10, 2 );
			add_action( 'xoo_wsc_product_end', array( $this, 'product_bopobb_side_cart_end' ), 10, 2 );

			//Stripe
			add_filter( 'wc_stripe_payment_request_supported_types', array(
				$this,
				'wc_stripe_payment_request_supported_types'
			), 10, 1 );

			//Show discount on checkout
//			add_action('woocommerce_review_order_before_order_total', array( $this, 'display_saved_amount_on_checkout') );

			// Ajax
			add_action( 'wp_ajax_bopobb_cart_popup_data', array( $this, 'bopobb_cart_popup_data' ) );
			add_action( 'wp_ajax_nopriv_bopobb_cart_popup_data', array( $this, 'bopobb_cart_popup_data' ) );
			add_action( 'wp_ajax_bopobb_product_list', array( $this, 'bopobb_product_list' ) );
			add_action( 'wp_ajax_nopriv_bopobb_product_list', array( $this, 'bopobb_product_list' ) );
			add_action( 'wp_ajax_bopobb_product_variations', array( $this, 'bopobb_product_variations' ) );
			add_action( 'wp_ajax_nopriv_bopobb_product_variations', array( $this, 'bopobb_product_variations' ) );
			add_action( 'wp_ajax_bopobb_search_many_variation', array( $this, 'bopobb_search_many_variation' ) );
			add_action( 'wp_ajax_nopriv_bopobb_search_many_variation', array( $this, 'bopobb_search_many_variation' ) );
			add_action( 'wp_ajax_bopobb_product_gallery', array( $this, 'bopobb_product_gallery' ) );
			add_action( 'wp_ajax_nopriv_bopobb_product_gallery', array( $this, 'bopobb_product_gallery' ) );
			add_action( 'wp_ajax_bopobb_cart_update', array( $this, 'bopobb_cart_update' ) );
			add_action( 'wp_ajax_nopriv_bopobb_cart_update', array( $this, 'bopobb_cart_update' ) );
			// WC ajax
			add_action( 'wp_ajax_woocommerce_bopobb_add_to_cart_ajax', array( $this, 'bopobb_add_to_cart_ajax' ) );
			add_action( 'wp_ajax_nopriv_woocommerce_bopobb_add_to_cart_ajax', array(
				$this,
				'bopobb_add_to_cart_ajax'
			) );
			add_action( 'wc_ajax_bopobb_add_to_cart_ajax', array( $this, 'bopobb_add_to_cart_ajax' ) );
//			add_action( 'wp_ajax_bopobb_export_pdf', array( $this, 'bopobb_export_pdf' ) );
//			add_action( 'wp_ajax_nopriv_bopobb_export_pdf', array( $this, 'bopobb_export_pdf' ) );
		}

		public function bopobb_footer() {
			$assign_page = $this->settings->get_params( 'bopobb_conditional_tag' );
			if ( ! $this->assign_page( $assign_page ) && ! is_cart() && ! is_checkout() ) {
				return;
			}
			?>
            <div class="bopobb-area" id="bopobb-area">
                <div class="bopobb-inner">
                    <div class="bopobb-overlay"></div>
                    <div class="bopobb-popup">
                        <div class="bopobb-popup-inner">
                            <div class="bopobb-popup-header">
                                <div class="bopobb-popup-header-left">
                                    <span class="bopobb-btn-back bopobb-icon-previous"
                                          title="<?php esc_attr_e( 'Back', 'bopo-woocommerce-product-bundle-builder' ); ?>"></span>
                                </div>
                                <div class="bopobb-popup-title" data-title=""><?php if ( empty( $this->language ) ) {
										echo esc_html( $this->settings->get_params( 'bopobb_popup_title' ) );
									} else
										echo esc_html( $this->settings->get_params( 'bopobb_popup_title_' . $this->language ) ) ?></div>
                                <div class="bopobb-popup-header-right">
                                    <span class="bopobb-btn-close bopobb-icon-cross1"
                                          title="<?php esc_attr_e( 'Close', 'bopo-woocommerce-product-bundle-builder' ); ?>"></span>
                                </div>
                            </div>
                            <div class="bopobb-product-gallery-wrap" data-product="">
                                <div class="bopobb-product-gallery-overlay" data-product=""></div>
                                <div class="bopobb-product-gallery" data-product=""></div>
                                <div class="bopobb-gallery-add-wrap" data-product="">
                                    <div class="bopobb-gallery-add"><span class="bopobb-icon-plus2"></span>
                                        <span class=""><?php esc_html_e( 'Add to bundle', 'bopo-woocommerce-product-bundle-builder' ); ?></span>
                                    </div>
                                </div>
                            </div>
                            <div class="bopobb-products-wrap">
                                <div class="bopobb-product-list" data-item=""></div>
                                <div class="bopobb-variation-list <?php
								if ( $this->settings->get_params( 'bopobb_popup_variations' ) == 'select' )
									echo esc_attr( 'bopobb-option-product-wrap' ) ?>" data-item=""
                                     data-product=""></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
			<?php
		}

		function bopobb_shortcode_bundle( $atts ) {
			global $bopobb_shortcode_id;
			$is_current = false;
			$attributes = shortcode_atts(
				array(
					'id'          => '',
					'title'       => '',
					'title_size'  => '',
					'title_color' => '',
					'template'    => '',
					'column'      => '',
					'redirect'    => '',
				),
				$atts
			);
			if ( ! $attributes['id'] ) {
				global $product;
				if ( isset( $product ) && ! empty( $product ) ) {
					//Elementor product
					$is_current = true;
					$_product   = $product;
				} else {
					return false;
				}
			} else {
				$_product = wc_get_product( absint( $attributes['id'] ) );
			}
			if ( ! $_product || ! $_product->is_type( 'bopobb' ) ) {
				return false;
			}

			if ( ! wp_script_is( 'woo-bopo-bundle-frontend' ) ) {
				$this->bopobb_wp_enqueue_scripts( true );
			}

			$bundle_title       = $attributes['title'] ? sanitize_text_field( $attributes['title'] ) : $_product->get_title();
			$bundle_title_size  = $attributes['title_size'] ? sanitize_text_field( $attributes['title_size'] ) : '';
			$bundle_title_color = $attributes['title_color'] ? sanitize_text_field( $attributes['title_color'] ) : '';
			$bundle_template    = $attributes['template'] ? sanitize_text_field( $attributes['template'] ) : '';
			$bundle_top_col     = $attributes['column'] ? sanitize_text_field( $attributes['column'] ) : (int) $this->settings->get_params( 'bopobb_item_column' );
			$bundle_redirect    = $attributes['redirect'] ? sanitize_text_field( $attributes['redirect'] ) : false;
			if ( empty( $bundle_template ) ) {
				switch ( $this->settings->get_params( 'bopobb_single_template' ) ) {
					case 1:
						$bundle_template = 'vertical-bundle';
						break;
					case 2:
						$bundle_template = 'horizontal-bundle';
						break;
					case 3:
					default:
						$bundle_template = 'block-bundle';
						break;
				}
			}
			if ( ! in_array( $bundle_template, $this->settings->get_params( 'bopobb_template_title' ) ) ) {
				$bundle_template = 'vertical-bundle';
			}
			if ( $bopobb_shortcode_id === null ) {
				$bopobb_shortcode_id = 1;
			} else {
				$bopobb_shortcode_id ++;
			}
			$bopo_shortcode_class = 'bopobb-shortcode-wrap bopobb-shortcode-' . $bopobb_shortcode_id;
			ob_start();
			?>
            <div class="bopobb-shortcode-form <?php echo esc_attr( $bopo_shortcode_class ) ?> bopobb-col-<?php
			echo esc_attr( $bundle_top_col ) ?>">
				<?php if ( ! $is_current ) { ?>
                    <div class="bopobb-shortcode-title" style="<?php if ( $bundle_title_size ) {
						echo esc_attr( 'font-size:' . $bundle_title_size . ';' );
					}
					if ( $bundle_title_color )
						echo esc_attr( 'color:' . $bundle_title_color ) . ';' ?>"><?php echo esc_html( $bundle_title ); ?>
                    </div>
					<?php
				}
				$bopobb_sc_mode = array(
					'class' => $bopo_shortcode_class,
					'sc_id' => $bopobb_shortcode_id
				);
				$this->bopobb_show_bundle( $_product, $bopobb_sc_mode, $bundle_template );
				?>
                <p class="price">
					<?php
					echo wp_kses_post( $_product->get_price_html() );
					?>
                </p>
				<?php
				do_action( 'woocommerce_before_add_to_cart_form' );
				$this->bopobb_shortcode_cart_form( $_product, false, '', '', [ 'redirect' => $bundle_redirect ] );
				?>
            </div>
			<?php
			$bundled = ob_get_contents();
			ob_end_clean();

			return $bundled;
		}

		function bopobb_init_single_bundle() {
			$bopobb_single_pos = $this->settings->get_params( 'bopobb_single_pos' );
			if ( ! empty( $bopobb_single_pos ) ) {
				switch ( $bopobb_single_pos ) {
					case 99:
						add_action( 'woocommerce_after_single_product_summary', array(
							$this,
							'bopobb_single_product_summary_bundled'
						) );
						break;
					default:
						add_action( 'woocommerce_single_product_summary', array(
							$this,
							'bopobb_single_product_summary_bundled'
						), (int) $bopobb_single_pos );
						break;
				}
			}
		}

		function bopobb_single_product_summary_bundled() {
			$this->bopobb_show_bundled();
//			$this->bopobb_show_bundle();
		}

		function bopobb_show_bundled( $product = null, $mode = 'single' ) {
			if ( ! $product ) {
				global $product;
			}

			if ( ! $product || ! $product->is_type( 'bopobb' ) ) {
				return;
			}
			$tax_rates['include'] = wc_prices_include_tax() ? 1 : 0;
			$tax_rates['view']    = 'incl' === get_option( 'woocommerce_tax_display_shop' ) ? 1 : 0;
			$tax_rates['rate']    = VI_WOO_BOPO_BUNDLE_Helper::bopobb_tax_rate( $product );
			if ( ! empty( WC()->customer ) && WC()->customer->get_is_vat_exempt() ) {
				$tax_rates['exempt'] = 1;
			} else {
				$tax_rates['exempt'] = 0;
			}

			$bundle_id          = $product->get_id();
			$bundle_link        = $product->get_permalink();
			$bundle_share_title = $product->get_title();
			$bundle_image_link  = wp_get_attachment_image_src( get_post_thumbnail_id( $bundle_id ), 'single-post-thumbnail' );

			if ( $items = $product->get_items() ) {

				$items_data       = $items['items'];
				$bopo_fixed_price = $items['fixed'];
				if ( $product->is_on_sale() ) {
					$bopo_fixed_sale = $items['fixed'];
				} else {
					$bopo_fixed_sale = '';
				}
				$product_arr     = array();
				$calc_price_base = $this->settings->get_params( 'bopobb_calculate_price' );
				if ( isset( $_POST['bopobb_ids'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
					$post_ids   = VI_WOO_BOPO_BUNDLE_Helper::bopohp_clean_ids( sanitize_text_field( wp_unslash( $_POST['bopobb_ids'] ) ) ); // phpcs:ignore WordPress.Security.NonceVerification.Missing
					$post_items = $product->build_items( $post_ids );
					for ( $i = 0; $i < count( $post_items ); $i ++ ) {
						$item_can_change = true;
						if ( isset( $items_data[ $i ] ) ) {
							if ( $items_data[ $i ]['bopobb_bpi_set_default'] == 1 ) {
								$item_can_change = $this->bopobb_search_product( 2, 0, $items_data[ $i ] );
							}
						}
						$post_prd = isset( $post_items[ $i ] ) && isset( $post_items[ $i ]['id'] ) ? wc_get_product( $post_items[ $i ]['id'] ) : '';
						if ( isset( $post_items[ $i ] ) && empty( $post_items[ $i ] ) || empty( $post_prd ) ) {
							$op_discount_type   = isset( $items_data[ $i ]['bopobb_bpi_discount'] ) ? $items_data[ $i ]['bopobb_bpi_discount'] : '';
							$op_discount_number = isset( $items_data[ $i ]['bopobb_bpi_discount_number'] ) ? $items_data[ $i ]['bopobb_bpi_discount_number'] : 0;
							if ( $op_discount_type == 1 || $op_discount_type == 2 ) {
								$op_discount_number = apply_filters( 'bopobb_convert_currency_price', $op_discount_number );
							}
							$op_quantity     = isset( $items_data[ $i ]['bopobb_bpi_quantity'] ) ? $items_data[ $i ]['bopobb_bpi_quantity'] : 1;
							$op_quantity_min = isset( $items_data[ $i ]['bopobb_bpi_quantity_min'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_min'] : 1;
							$op_quantity_max = isset( $items_data[ $i ]['bopobb_bpi_quantity_max'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_max'] : 1;

							$item_arr                              = [];
							$item_arr['bopo_product']              = '';
							$item_arr['bopo_product_id']           = '';
							$item_arr['bopo_product_title']        = '';
							$item_arr['bopo_product_custom_title'] = isset( $items_data[ $i ]['bopobb_bpi_title'] ) ? $items_data[ $i ]['bopobb_bpi_title'] : '';
							$item_arr['bopo_product_image']        = '';
							$item_arr['bopo_quantity']             = $op_quantity;
							$item_arr['bopo_quantity_min']         = $op_quantity_min;
							$item_arr['bopo_quantity_max']         = $op_quantity_max;
							$item_arr['bopo_product_price']        = 0;
							$item_arr['bopo_fixed_price']          = $bopo_fixed_price;
							$item_arr['bopo_fixed_sale']           = $bopo_fixed_sale;
							$item_arr['bopo_discount_type']        = $op_discount_type;
							$item_arr['bopo_discount_number']      = $op_discount_number;
							$item_arr['bopo_product_stock']        = 0;
							$item_arr['bopo_product_variations']   = '';
							$item_arr['bopo_item_can_change']      = $item_can_change;
							array_push( $product_arr, $item_arr );

							continue;
						}
//						$post_prd = wc_get_product( $post_items[ $i ]['id'] );

						if ( isset( $post_items[ $i ]['variations'] ) ) {
							$variation_title = VI_WOO_BOPO_BUNDLE_Helper::bopobb_decode_variations( $post_items[ $i ]['variations'], 1 );
						} else {
							$variation_title = '';
						}
						$post_title           = $post_prd->get_title() . $variation_title;
						$post_image           = $post_prd->get_image( $this->settings->get_params( 'bopobb_image_size' ) );
						$post_discount_type   = isset( $items_data[ $i ]['bopobb_bpi_discount'] ) ? $items_data[ $i ]['bopobb_bpi_discount'] : '';
						$post_discount_number = isset( $items_data[ $i ]['bopobb_bpi_discount_number'] ) ? $items_data[ $i ]['bopobb_bpi_discount_number'] : 0;
						if ( $post_discount_type == 1 || $post_discount_type == 2 ) {
							$post_discount_number = apply_filters( 'bopobb_convert_currency_price', $post_discount_number );
						}
						$post_quantity_min = isset( $items_data[ $i ]['bopobb_bpi_quantity_min'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_min'] : 1;
						$post_quantity_max = isset( $items_data[ $i ]['bopobb_bpi_quantity_max'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_max'] : 1;
						if ( $post_prd->get_manage_stock() ) {
							$post_stock = method_exists( $post_prd, 'get_stock_quantity' ) &&
							              ! empty( $post_prd->get_stock_quantity() ) ? $post_prd->get_stock_quantity() : 0;
						} else {
							$post_stock = - 1;
						};
						//$post_price = wc_get_price_excluding_tax( $post_prd );
						$post_price = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $post_prd, $calc_price_base );

						$bopo_product_variations = isset( $post_items[ $i ]['variations'] ) ? $post_items[ $i ]['variations'] : '';
						if ( $post_prd && $post_items[ $i ]['id'] && $post_items[ $i ]['qty'] ) {
							$item_arr                              = [];
							$item_arr['bopo_product']              = $post_prd;
							$item_arr['bopo_product_id']           = absint( $post_items[ $i ]['id'] );
							$item_arr['bopo_product_title']        = $post_title;
							$item_arr['bopo_product_custom_title'] = isset( $items_data[ $i ]['bopobb_bpi_title'] ) ? $items_data[ $i ]['bopobb_bpi_title'] : '';
							$item_arr['bopo_product_image']        = $post_image;
							$item_arr['bopo_quantity']             = absint( $post_items[ $i ]['qty'] );
							$item_arr['bopo_quantity_min']         = $post_quantity_min;
							$item_arr['bopo_quantity_max']         = $post_quantity_max;
							$item_arr['bopo_product_price']        = $post_price;
							$item_arr['bopo_fixed_price']          = $bopo_fixed_price;
							$item_arr['bopo_fixed_sale']           = $bopo_fixed_sale;
							$item_arr['bopo_discount_type']        = $post_discount_type;
							$item_arr['bopo_discount_number']      = $post_discount_number;
							$item_arr['bopo_product_stock']        = $post_stock;
							$item_arr['bopo_product_variations']   = $bopo_product_variations;
							$item_arr['bopo_item_can_change']      = $item_can_change;
							array_push( $product_arr, $item_arr );
						}
					}
				} elseif ( isset( $_GET['bopobbshare'] ) ) {// phpcs:ignore WordPress.Security.NonceVerification.Recommended
					$get_items = VI_WOO_BOPO_BUNDLE_Helper::bopohp_clean_share_ids( sanitize_text_field( wp_unslash( $_GET['bopobbshare'] ) ) );// phpcs:ignore WordPress.Security.NonceVerification.Recommended

					for ( $i = 0; $i < count( $get_items ); $i ++ ) {
						$item_can_change = true;
						$item_in_bundle  = isset( $get_items[ $i ] ) && isset( $items_data[ $i ] ) ?
							VI_WOO_BOPO_BUNDLE_Helper::bopohp_data_in_bundle( $get_items[ $i ], $items_data[ $i ] ) : false;
						if ( isset( $items_data[ $i ] ) ) {
							if ( $items_data[ $i ]['bopobb_bpi_set_default'] == 1 ) {
								$item_can_change = $this->bopobb_search_product( 2, 0, $items_data[ $i ] );
							}
						}

						$post_prd = isset( $get_items[ $i ] ) && isset( $get_items[ $i ]['id'] ) ? wc_get_product( $get_items[ $i ]['id'] ) : '';
						if ( isset( $get_items[ $i ] ) && empty( $get_items[ $i ] ) || empty( $post_prd ) || ! isset( $get_items[ $i ] ) ||
						     empty( $get_items[ $i ] ) || ! $item_in_bundle ) {
							$prd_data                = $this->bopobb_get_item_product( $items_data, $i );
							$bopo_product            = $prd_data['product'];
							$bopo_product_id         = $prd_data['product_id'];
							$bopo_product_title      = $prd_data['product_title'];
							$bopo_product_image      = $prd_data['product_image'];
							$bopo_product_price      = $prd_data['product_price'];
							$bopo_product_stock      = $prd_data['product_stock'];
							$bopo_product_variations = $prd_data['product_variation'];
							$bopo_discount_type      = isset( $items_data[ $i ]['bopobb_bpi_discount'] ) ? $items_data[ $i ]['bopobb_bpi_discount'] : '';
							$bopo_discount_number    = isset( $items_data[ $i ]['bopobb_bpi_discount_number'] ) ? $items_data[ $i ]['bopobb_bpi_discount_number'] : 0;
							if ( $bopo_discount_type == 1 || $bopo_discount_type == 2 ) {
								$bopo_discount_number = apply_filters( 'bopobb_convert_currency_price', $bopo_discount_number );
							}
							$bopo_quantity     = isset( $items_data[ $i ]['bopobb_bpi_quantity'] ) ? $items_data[ $i ]['bopobb_bpi_quantity'] : 1;
							$bopo_quantity_min = isset( $items_data[ $i ]['bopobb_bpi_quantity_min'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_min'] : 1;
							$bopo_quantity_max = isset( $items_data[ $i ]['bopobb_bpi_quantity_max'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_max'] : 1;

							$item_arr                              = [];
							$item_arr['bopo_product']              = $bopo_product;
							$item_arr['bopo_product_id']           = $bopo_product_id;
							$item_arr['bopo_product_title']        = $bopo_product_title;
							$item_arr['bopo_product_custom_title'] = isset( $items_data[ $i ]['bopobb_bpi_title'] ) ? $items_data[ $i ]['bopobb_bpi_title'] : '';
							$item_arr['bopo_product_image']        = $bopo_product_image;
							$item_arr['bopo_quantity']             = $bopo_quantity;
							$item_arr['bopo_quantity_min']         = $bopo_quantity_min;
							$item_arr['bopo_quantity_max']         = $bopo_quantity_max;
							$item_arr['bopo_product_price']        = $bopo_product_price;
							$item_arr['bopo_fixed_price']          = $bopo_fixed_price;
							$item_arr['bopo_fixed_sale']           = $bopo_fixed_sale;
							$item_arr['bopo_discount_type']        = $bopo_discount_type;
							$item_arr['bopo_discount_number']      = $bopo_discount_number;
							$item_arr['bopo_product_stock']        = $bopo_product_stock;
							$item_arr['bopo_product_variations']   = $bopo_product_variations;
							$item_arr['bopo_item_can_change']      = $item_can_change;
							array_push( $product_arr, $item_arr );
						} else {

							if ( isset( $get_items[ $i ]['variations'] ) ) {
								$variation_title = VI_WOO_BOPO_BUNDLE_Helper::bopobb_decode_variations( $get_items[ $i ]['variations'], 1 );
							} else {
								$variation_title = '';
							}
							$post_title           = $post_prd->get_title() . $variation_title;
							$post_image           = $post_prd->get_image( $this->settings->get_params( 'bopobb_image_size' ) );
							$post_discount_type   = isset( $items_data[ $i ]['bopobb_bpi_discount'] ) ? $items_data[ $i ]['bopobb_bpi_discount'] : '';
							$post_discount_number = isset( $items_data[ $i ]['bopobb_bpi_discount_number'] ) ? $items_data[ $i ]['bopobb_bpi_discount_number'] : 0;
							if ( $post_discount_type == 1 || $post_discount_type == 2 ) {
								$post_discount_number = apply_filters( 'bopobb_convert_currency_price', $post_discount_number );
							}
							$post_quantity_min = isset( $items_data[ $i ]['bopobb_bpi_quantity_min'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_min'] : 1;
							$post_quantity_max = isset( $items_data[ $i ]['bopobb_bpi_quantity_max'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_max'] : 1;
							if ( $post_prd->get_manage_stock() ) {
								$post_stock = method_exists( $post_prd, 'get_stock_quantity' ) &&
								              ! empty( $post_prd->get_stock_quantity() ) ? $post_prd->get_stock_quantity() : 0;
							} else {
								$post_stock = - 1;
							};
							//$post_price = wc_get_price_excluding_tax( $post_prd );
							$post_price = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $post_prd, $calc_price_base );

							$bopo_product_variations = isset( $get_items[ $i ]['variations'] ) ? $get_items[ $i ]['variations'] : '';
							if ( $post_prd && $get_items[ $i ]['id'] && $get_items[ $i ]['qty'] ) {
								$item_arr                              = [];
								$item_arr['bopo_product']              = $post_prd;
								$item_arr['bopo_product_id']           = absint( $get_items[ $i ]['id'] );
								$item_arr['bopo_product_title']        = $post_title;
								$item_arr['bopo_product_custom_title'] = isset( $items_data[ $i ]['bopobb_bpi_title'] ) ? $items_data[ $i ]['bopobb_bpi_title'] : '';
								$item_arr['bopo_product_image']        = $post_image;
								$item_arr['bopo_quantity']             = absint( $get_items[ $i ]['qty'] );
								$item_arr['bopo_quantity_min']         = $post_quantity_min;
								$item_arr['bopo_quantity_max']         = $post_quantity_max;
								$item_arr['bopo_product_price']        = $post_price;
								$item_arr['bopo_fixed_price']          = $bopo_fixed_price;
								$item_arr['bopo_fixed_sale']           = $bopo_fixed_sale;
								$item_arr['bopo_discount_type']        = $post_discount_type;
								$item_arr['bopo_discount_number']      = $post_discount_number;
								$item_arr['bopo_product_stock']        = $post_stock;
								$item_arr['bopo_product_variations']   = $bopo_product_variations;
								$item_arr['bopo_item_can_change']      = $item_can_change;
								array_push( $product_arr, $item_arr );
							}
						}
					}
				} else {
					for ( $i = 0; $i < $items['count']; $i ++ ) {
						$item_can_change = true;
						if ( isset( $items_data[ $i ] ) ) {
							if ( $items_data[ $i ]['bopobb_bpi_set_default'] == 1 ) {
								$item_can_change = $this->bopobb_search_product( 2, 0, $items_data[ $i ] );
							}
						}
						$prd_data                = $this->bopobb_get_item_product( $items_data, $i );
						$bopo_product            = $prd_data['product'];
						$bopo_product_id         = $prd_data['product_id'];
						$bopo_product_title      = $prd_data['product_title'];
						$bopo_product_image      = $prd_data['product_image'];
						$bopo_product_price      = $prd_data['product_price'];
						$bopo_product_stock      = $prd_data['product_stock'];
						$bopo_product_variations = $prd_data['product_variation'];
						$bopo_discount_type      = isset( $items_data[ $i ]['bopobb_bpi_discount'] ) ? $items_data[ $i ]['bopobb_bpi_discount'] : '';
						$bopo_discount_number    = isset( $items_data[ $i ]['bopobb_bpi_discount_number'] ) ? $items_data[ $i ]['bopobb_bpi_discount_number'] : 0;
						if ( $bopo_discount_type == 1 || $bopo_discount_type == 2 ) {
							$bopo_discount_number = apply_filters( 'bopobb_convert_currency_price', $bopo_discount_number );
						}
						$bopo_quantity     = isset( $items_data[ $i ]['bopobb_bpi_quantity'] ) ? $items_data[ $i ]['bopobb_bpi_quantity'] : 1;
						$bopo_quantity_min = isset( $items_data[ $i ]['bopobb_bpi_quantity_min'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_min'] : 1;
						$bopo_quantity_max = isset( $items_data[ $i ]['bopobb_bpi_quantity_max'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_max'] : 1;

						$item_arr                              = [];
						$item_arr['bopo_product']              = $bopo_product;
						$item_arr['bopo_product_id']           = $bopo_product_id;
						$item_arr['bopo_product_title']        = $bopo_product_title;
						$item_arr['bopo_product_custom_title'] = isset( $items_data[ $i ]['bopobb_bpi_title'] ) ? $items_data[ $i ]['bopobb_bpi_title'] : '';
						$item_arr['bopo_product_image']        = $bopo_product_image;
						$item_arr['bopo_quantity']             = $bopo_quantity;
						$item_arr['bopo_quantity_min']         = $bopo_quantity_min;
						$item_arr['bopo_quantity_max']         = $bopo_quantity_max;
						$item_arr['bopo_product_price']        = $bopo_product_price;
						$item_arr['bopo_fixed_price']          = $bopo_fixed_price;
						$item_arr['bopo_fixed_sale']           = $bopo_fixed_sale;
						$item_arr['bopo_discount_type']        = $bopo_discount_type;
						$item_arr['bopo_discount_number']      = $bopo_discount_number;
						$item_arr['bopo_product_stock']        = $bopo_product_stock;
						$item_arr['bopo_product_variations']   = $bopo_product_variations;
						$item_arr['bopo_item_can_change']      = $item_can_change;
						array_push( $product_arr, $item_arr );
					}
				}
				$social_setting = $this->settings->get_params( 'bopobb_social_share' );
				$social_link    = [];
				if ( ! empty( $social_setting ) ) {
					$social_link['url']         = $bundle_link;
					$social_link['share_title'] = $bundle_share_title;
					$social_link['email_body']  = esc_html__( 'Check this out: ', 'bopo-woocommerce-product-bundle-builder' );
					$social_link['image_url']   = ! empty( $bundle_image_link ) && is_array( $bundle_image_link ) && isset( $bundle_image_link[0] ) ? $bundle_image_link[0] : '';
				}
//				if ( $this->settings->get_params( 'bopobb_single_template' ) == 1 ) {
//					$bopobb_template = 'vertical-bundle.php';
//				} else {
//					$bopobb_template = 'horizontal-bundle.php';
//				}
				switch ( $this->settings->get_params( 'bopobb_single_template' ) ) {
					case 1:
						$bopobb_template = 'vertical-bundle.php';
						break;
					case 2:
						$bopobb_template = 'horizontal-bundle.php';
						break;
					case 3:
					default:
						$bopobb_template = 'block-bundle.php';
						break;
				}
				bopobb_get_template( $bopobb_template, array(
					'items'            => $items,
					'bundle_id'        => $bundle_id,
					'product_array'    => $product_arr,
					'bopo_fixed_price' => $bopo_fixed_price,
					'bopo_fixed_sale'  => $bopo_fixed_sale,
					'bopo_tax_array'   => $tax_rates,
					'social_setting'   => $social_setting,
					'social_link'      => $social_link
				), '', VI_WOO_BOPO_BUNDLE_TEMP_DIR );
			}
		}

		function bopobb_show_bundle( $product = null, $mode = '', $temp = '' ) {
			if ( ! $product ) {
				global $product;
			}

			if ( ! $product || ! $product->is_type( 'bopobb' ) ) {
				return;
			}
			$tax_rates['include'] = wc_prices_include_tax() ? 1 : 0;
			$tax_rates['view']    = 'incl' === get_option( 'woocommerce_tax_display_shop' ) ? 1 : 0;
			$tax_rates['rate']    = VI_WOO_BOPO_BUNDLE_Helper::bopobb_tax_rate( $product );
			if ( ! empty( WC()->customer ) && WC()->customer->get_is_vat_exempt() ) {
				$tax_rates['exempt'] = 1;
			} else {
				$tax_rates['exempt'] = 0;
			}

			$bundle_id          = $product->get_id();
			$bundle_link        = $product->get_permalink();
			$bundle_share_title = $product->get_title();

			if ( $items = $product->get_items() ) {
				$items_data       = $items['items'];
				$bopo_fixed_price = $items['fixed'];
				if ( $product->is_on_sale() ) {
					$bopo_fixed_sale = $items['fixed'];
				} else {
					$bopo_fixed_sale = '';
				}
				$product_arr = array();

				for ( $i = 0; $i < $items['count']; $i ++ ) {
					$item_can_change = true;
					if ( isset( $items_data[ $i ] ) ) {
						if ( $items_data[ $i ]['bopobb_bpi_set_default'] == 1 ) {
							$item_can_change = $this->bopobb_search_product( 2, 0, $items_data[ $i ] );
						}
					}
					$prd_data                = $this->bopobb_get_item_product( $items_data, $i );
					$bopo_product            = $prd_data['product'];
					$bopo_product_id         = $prd_data['product_id'];
					$bopo_product_title      = $prd_data['product_title'];
					$bopo_product_image      = $prd_data['product_image'];
					$bopo_product_price      = $prd_data['product_price'];
					$bopo_product_stock      = $prd_data['product_stock'];
					$bopo_product_variations = $prd_data['product_variation'];
					$bopo_discount_type      = isset( $items_data[ $i ]['bopobb_bpi_discount'] ) ? $items_data[ $i ]['bopobb_bpi_discount'] : '';
					$bopo_discount_number    = isset( $items_data[ $i ]['bopobb_bpi_discount_number'] ) ? $items_data[ $i ]['bopobb_bpi_discount_number'] : 0;
					if ( $bopo_discount_type == 1 ) {
						$bopo_discount_number = apply_filters( 'bopobb_convert_currency_price', $bopo_discount_number );
					}
					$bopo_quantity     = isset( $items_data[ $i ]['bopobb_bpi_quantity'] ) ? $items_data[ $i ]['bopobb_bpi_quantity'] : 1;
					$bopo_quantity_min = isset( $items_data[ $i ]['bopobb_bpi_quantity_min'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_min'] : 1;
					$bopo_quantity_max = isset( $items_data[ $i ]['bopobb_bpi_quantity_max'] ) ? $items_data[ $i ]['bopobb_bpi_quantity_max'] : 1;

					$item_arr                              = [];
					$item_arr['bopo_product']              = $bopo_product;
					$item_arr['bopo_product_id']           = $bopo_product_id;
					$item_arr['bopo_product_title']        = $bopo_product_title;
					$item_arr['bopo_product_custom_title'] = isset( $items_data[ $i ]['bopobb_bpi_title'] ) ? $items_data[ $i ]['bopobb_bpi_title'] : '';
					$item_arr['bopo_product_image']        = $bopo_product_image;
					$item_arr['bopo_quantity']             = $bopo_quantity;
					$item_arr['bopo_quantity_min']         = $bopo_quantity_min;
					$item_arr['bopo_quantity_max']         = $bopo_quantity_max;
					$item_arr['bopo_product_price']        = $bopo_product_price;
					$item_arr['bopo_fixed_price']          = $bopo_fixed_price;
					$item_arr['bopo_fixed_sale']           = $bopo_fixed_sale;
					$item_arr['bopo_discount_type']        = $bopo_discount_type;
					$item_arr['bopo_discount_number']      = $bopo_discount_number;
					$item_arr['bopo_product_stock']        = $bopo_product_stock;
					$item_arr['bopo_product_variations']   = $bopo_product_variations;
					$item_arr['bopo_item_can_change']      = $item_can_change;
					array_push( $product_arr, $item_arr );
				}

				$social_setting = $this->settings->get_params( 'bopobb_social_share' );
				$social_link    = [];
				if ( ! empty( $social_setting ) ) {
					$social_link['url']         = $bundle_link;
					$social_link['share_title'] = $bundle_share_title;
					$social_link['email_body']  = esc_html__( 'Check this out: ', 'bopo-woocommerce-product-bundle-builder' );
					$social_link['image_url']   = ! empty( $bundle_image_link ) && is_array( $bundle_image_link ) && isset( $bundle_image_link[0] ) ? $bundle_image_link[0] : '';
				}

				if ( $temp ) {
					$bopobb_template = $temp . '.php';
				} else {
					switch ( $this->settings->get_params( 'bopobb_single_template' ) ) {
						case 1:
							$bopobb_template = 'vertical-bundle.php';
							break;
						case 2:
							$bopobb_template = 'horizontal-bundle.php';
							break;
						case 3:
						default:
							$bopobb_template = 'block-bundle.php';
							break;
					}
				}
				bopobb_get_template( $bopobb_template, array(
					'items'            => $items,
					'bundle_id'        => $bundle_id,
					'product_array'    => $product_arr,
					'bopo_fixed_price' => $bopo_fixed_price,
					'bopo_fixed_sale'  => $bopo_fixed_sale,
					'bopo_tax_array'   => $tax_rates,
					'bopo_mode'        => $mode,
					'social_setting'   => $social_setting,
					'social_link'      => $social_link,
					'bopo_template'    => str_replace( '.php', '', $bopobb_template )
				), '', VI_WOO_BOPO_BUNDLE_TEMP_DIR );
			}
		}

		function bopobb_get_price_html( $price, $product_src ) {
			if ( $product_src && $product_src->is_type( 'bopobb' ) && ( $items = $product_src->get_items() ) ) {
				if ( ! $product_src->is_fixed_price() ) {
					$calc_price_base = $this->settings->get_params( 'bopobb_calculate_price' );
					$price           = $price_sale = 0;
					$isSetPrice      = true;
					for ( $i = 0; $i < $items['count']; $i ++ ) {
						if ( isset( $items['items'][ $i ] ) ) {
							if ( ! $items['items'][ $i ]['bopobb_bpi_set_default'] ) {
								$isSetPrice = false;
							}
						} else {
							$isSetPrice = false;
						}
					}
					if ( $isSetPrice ) {
						foreach ( $items['items'] as $item ) {
							$_product = '';
							if ( isset( $item['bopobb_bpi_default_product'] ) ) {
								$def_product_data = explode( '%/', $item['bopobb_bpi_default_product'] );
								$_product         = wc_get_product( $def_product_data[0] );

							} else {
								//query get default;
								$_product_array = $this->bopobb_search_product( 1, 0, $item );
								if ( $_product_array ) {
									$_productID = $_product_array['product_id'];
									$_product   = wc_get_product( $_productID );
								}
							}
							if ( $_product ) {
								$_price = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_original_price_total( $_product, $item['bopobb_bpi_quantity'], $calc_price_base );

								$price += $_price;

//								if ( ! $item['bopobb_bpi_discount'] ) {
//									// if haven't discount_amount, apply discount percentage
//									$price_sale += ( $_price / 100 ) * $item['bopobb_bpi_discount_number'];
//								} else {
//									$price_sale += $item['bopobb_bpi_discount_number'];
//								}

								switch ( $item['bopobb_bpi_discount'] ) {
									case '2':
										$price_sale += floatval( $item['bopobb_bpi_discount_number'] );
										break;
									case '1':
										$price_sale += floatval( $_price ) - floatval( $item['bopobb_bpi_discount_number'] );
										break;
									case '0':
									default:
										$price_sale += $_price - ( ( $_price / 100 ) * floatval( $item['bopobb_bpi_discount_number'] ) );
								}
							}
						}
//						$price_sale = $price - $price_sale;
						$price      = VI_WOO_BOPO_BUNDLE_Helper::bopobb_price_show( $product_src, $price );
						$price_sale = VI_WOO_BOPO_BUNDLE_Helper::bopobb_price_show( $product_src, $price_sale );

						$price      = apply_filters( 'bopobb_convert_currency_price', (float) $price );
						$price_sale = apply_filters( 'bopobb_convert_currency_price', (float) $price_sale );

						if ( $price_sale && $price_sale != $price ) {
							return wc_format_sale_price( wc_price( $price ), wc_price( $price_sale ) ) . $product_src->get_price_suffix();
						}

						return wc_price( $price ) . $product_src->get_price_suffix();
					} elseif ( ! is_product() ) {
						if ( $this->settings->get_params( 'bopobb_meta_field_range' ) ) {
							$price_meta     = $product_src->get_meta( 'bopobb_min_price', true );
							$max_price_meta = $product_src->get_meta( 'bopobb_max_price', true );
							if ( $price_meta != '' && $max_price_meta != '' ) {
								$price_meta     = apply_filters( 'bopobb_convert_currency_price', (float) $price_meta );
								$max_price_meta = apply_filters( 'bopobb_convert_currency_price', (float) $max_price_meta );
								if ( $max_price_meta && $max_price_meta != $price_meta ) {
									return wc_price( $price_meta ) . $product_src->get_price_suffix() .
									       '<span class="bopobb-product-price-range-separator"> - </span>' . wc_price( $max_price_meta ) . $product_src->get_price_suffix();
								}

								return wc_price( $price_meta ) . $product_src->get_price_suffix();
							}
						}
						$available = 0;
						$max_price = 0;
						foreach ( $items['items'] as $item ) {
//							if ( is_array( $item ) && isset( $item['bopobb_bpi_optional_item'] ) && $item['bopobb_bpi_optional_item'] ) {
//								$available ++;
//								continue;
//							}
							$_product_array = $this->bopobb_search_range_product( $item );
							if ( ! empty( $_product_array ) && isset( $_product_array['max'] ) && isset( $_product_array['min'] ) ) {
								$max_price += (float) $_product_array['max'];
								$price     += (float) $_product_array['min'];
								$available ++;
							}
						}
						if ( $available != $items['count'] ) {
							return '';
						}
						$price     = VI_WOO_BOPO_BUNDLE_Helper::bopobb_price_show( $product_src, $price );
						$max_price = VI_WOO_BOPO_BUNDLE_Helper::bopobb_price_show( $product_src, $max_price );

						global $product;
						if ( empty( $product ) ) {
							$active_theme = wp_get_theme();
							if ( is_object( $active_theme ) && ! empty( $active_theme ) && property_exists( $active_theme, 'template' ) ) {
								if ( 'porto' == $active_theme->template ) {
									$product = $product_src;
								}
							}
						}

						$price     = apply_filters( 'bopobb_convert_currency_price', (float) $price );
						$max_price = apply_filters( 'bopobb_convert_currency_price', (float) $max_price );
						if ( $max_price && $max_price != $price ) {
							return wc_price( $price ) . $product_src->get_price_suffix() . '<span class="bopobb-product-price-range-separator"> - </span>' . wc_price( $max_price ) . $product_src->get_price_suffix();
						}

						return wc_price( $price ) . $product_src->get_price_suffix();

					}
				}
			}

			return $price;
		}

		function bopobb_display_post_states( $states, $post ) {
			if ( 'product' == get_post_type( $post->ID ) ) {
				if ( ( $_product = wc_get_product( $post->ID ) ) && $_product->is_type( 'bopobb' ) ) {
					$count = 0;

					if ( $items = $_product->get_items() ) {
						$count = count( $items['items'] );
					}

					$states[] = apply_filters( 'bopobb_post_states', '<span class="bopobb-state">' . sprintf( '%s (%s)', esc_html__( 'Bundle', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $count ) ) . '</span>', $count, $_product );
				}
			}

			return $states;
		}

		function bopobb_search_product( $val = 0, $get_variable = 1, $arg_input = [] ) {
			$cat         = isset( $arg_input['bopobb_pbi_category'] ) ? $arg_input['bopobb_pbi_category'] : '';
			$ex_cat      = isset( $arg_input['bopobb_pbi_category_exclude'] ) ? $arg_input['bopobb_pbi_category_exclude'] : '';
			$tag         = isset( $arg_input['bopobb_pbi_tag'] ) ? $arg_input['bopobb_pbi_tag'] : '';
			$ex_tag      = isset( $arg_input['bopobb_pbi_tag_exclude'] ) ? $arg_input['bopobb_pbi_tag_exclude'] : '';
			$prod        = isset( $arg_input['bopobb_pbi_title'] ) ? $arg_input['bopobb_pbi_title'] : '';
			$ex_prod     = isset( $arg_input['bopobb_pbi_title_exclude'] ) ? $arg_input['bopobb_pbi_title_exclude'] : '';
			$sort        = isset( $arg_input['bopobb_bpi_sort'] ) ? $arg_input['bopobb_bpi_sort'] : '';
			$order       = isset( $arg_input['bopobb_bpi_order'] ) ? $arg_input['bopobb_bpi_order'] : '';
			$prod_var    = isset( $arg_input['bopobb_pbi_title_variation'] ) ? $arg_input['bopobb_pbi_title_variation'] : '';
			$ex_prod_var = isset( $arg_input['bopobb_pbi_title_variation_exclude'] ) ? $arg_input['bopobb_pbi_title_variation_exclude'] : '';
			$key         = isset( $arg_input['key_word'] ) ? $arg_input['key_word'] : '';

			$arg     = array(
				'post_status'    => 'publish',
				'post_type'      => 'product',
				'posts_per_page' => - 1,
				's'              => $key
			);
			$tax_arr = [];
			if ( ! empty( $cat ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_cat',
					'field'    => 'term_id',
					'terms'    => $cat,
				];
			}
			if ( ! empty( $ex_cat ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_cat',
					'field'    => 'term_id',
					'terms'    => $ex_cat,
					'operator' => 'NOT IN',
				];
			}
			if ( ! empty( $tag ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_tag',
					'field'    => 'term_id',
					'terms'    => $tag,
				];
			}
			if ( ! empty( $ex_tag ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_tag',
					'field'    => 'term_id',
					'terms'    => $ex_tag,
					'operator' => 'NOT IN',
				];
			}
			if ( ! empty( $tax_arr ) ) {
				$arg['tax_query'] = $tax_arr;// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_tax_query
			}
			if ( ! empty( $prod ) ) {
				$arg['post__in'] = $prod;
			}

			switch ( $sort ) {
				case 'date':
					$arg['orderby'] = array(
						'date'       => $order,
						'menu_order' => 'ASC',
					);
					break;
				case 'ratting':
					$arg['orderby']  = 'meta_value_num';
					$arg['meta_key'] = '_wc_average_rating';// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_key
					$arg['order']    = $order;
					break;
				case 'price':
					$arg['orderby']  = 'meta_value_num';
					$arg['meta_key'] = '_price';// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_key
					$arg['order']    = $order;
					break;
				default:
					$arg['orderby'] = 'title';
					$arg['order']   = $order;
					break;
			}

			$the_query = new WP_Query( $arg );
			//item_can_change
			$founded_count = $the_query->found_posts;
			if ( $val == 2 && $founded_count > 1 ) {
				return true;
			}
			$found_products = array();
			if ( $the_query->have_posts() ) {
				$s_product_ids = $the_query->posts;
				foreach ( $s_product_ids as $s_index => $s_product_object ) {
					if ( ! is_object( $s_product_object ) || empty( $s_product_object ) || ! property_exists( $s_product_object, 'ID' ) ) {
						continue;
					}
					$s_product_id = $s_product_object->ID;
					if ( is_array( $s_product_id ) || is_object( $s_product_id ) || empty( $s_product_id ) ) {
						continue;
					}
					$prd = wc_get_product( $s_product_id );

					if ( ! $prd->is_purchasable() ) {
						continue;
					}

					if ( ! empty( $ex_prod ) ) {
						if ( in_array( strval( $s_product_id ), array_values( $ex_prod ), true ) ) {
							if ( $val == 2 && $founded_count == 1 ) {

								return true;
							}
							continue;
						}
					}

					if ( ! in_array( $prd->get_type(), $this->settings->get_params( 'bopobb_type_include' ), true ) ) {
						continue;
					}

					//item_can_change
					if ( $val == 2 ) {
						if ( $prd->is_type( 'variable' ) ) {
							$product_children = $prd->get_children();
							if ( count( $product_children ) == 1 ) {
								$valriation_prd                = wc_get_product( $product_children[0] );
								$variation_any                 = false;
								$child_wc_variation_attributes = $valriation_prd->get_variation_attributes();

								foreach ( $child_wc_variation_attributes as $attr_v ) {
									if ( empty( $attr_v ) ) {
										$variation_any = true;
									}
								}
								if ( ! $variation_any && $valriation_prd->is_purchasable() ) {

									return false;
								} else {

									return true;
								}
							} else {
							    if ( ! empty( $prod_var ) && is_array( $prod_var ) ) {
								    $change_child_ids = array_intersect( $prod_var, $product_children );
								    if ( count( $prod_var ) == 1 && ! empty( $prod_var[0] ) && $change_child_ids ) {
									    $c_valriation_prd                = wc_get_product( $change_child_ids[0] );
									    $c_variation_any                 = false;
									    $c_child_wc_variation_attributes = $c_valriation_prd->get_variation_attributes();

									    foreach ( $c_child_wc_variation_attributes as $c_attr_v ) {
										    if ( empty( $c_attr_v ) ) {
											    $c_variation_any = true;
										    }
									    }
									    if ( ! $c_variation_any && $c_valriation_prd->is_purchasable() ) {

										    return false;
									    } else {

										    return true;
									    }
								    }
							    }

								return true;
							}
						} else {
							if ( $prd->is_purchasable() ) {

								return false;
							} else {

								return true;
							}
						}
						continue;
					}

					// Get default
					if ( $val == 1 ) {
						if ( $get_variable ) {

							return $s_product_id;
						}
						if ( $prd->is_type( 'variable' ) ) {
							$product_children = $prd->get_children();
							// Check child valid for sale
							if ( count( $product_children ) ) {
								for ( $i = 0; $i < count( $product_children ); $i ++ ) {
									if ( ! empty( $prod_var ) ) {
										if ( ! in_array( $product_children[ $i ], $prod_var ) ) {
											continue;
										}
									}
									if ( ! empty( $ex_prod_var ) ) {
										if ( in_array( $product_children[ $i ], $ex_prod_var ) ) {
											continue;
										}
									}
									$valriation_prd = wc_get_product( $product_children[ $i ] );
									//not load out stock product ignore setting bopobb_out_stock
									$out_stock = false;
									if ( $valriation_prd->is_purchasable() && $valriation_prd->get_price() &&
									     ( ( $valriation_prd->get_manage_stock() && $valriation_prd->get_stock_quantity() ) ||
									       ( ! $valriation_prd->get_manage_stock() && 'outofstock' != $valriation_prd->get_stock_status() ) || $out_stock ) ) {
										$variation_any                 = false;
										$child_wc_variation_attributes = $valriation_prd->get_variation_attributes();

										foreach ( $child_wc_variation_attributes as $attr_v ) {
											if ( empty( $attr_v ) ) {
												$variation_any = true;
											}
										}

										if ( $variation_any ) {
											// Variation any
											$any_variations = VI_WOO_BOPO_BUNDLE_Helper::bopobb_get_variation_default( $prd, $valriation_prd, $child_wc_variation_attributes );
											$set_arr        = array();

											if ( ! empty( $any_variations ) ) {
												$key_arr = array_keys( $child_wc_variation_attributes );
												if ( is_array( $any_variations ) || is_object( $any_variations ) ) {
													if ( count( $key_arr ) == count( $any_variations ) ) {
														$set_arr = array_combine( $key_arr, $any_variations );
													}
												} else {
													$any_v = [ $any_variations ];
													if ( count( $key_arr ) == count( $any_variations ) ) {
														$set_arr = array_combine( $key_arr, $any_variations );
													}
												}
											} else {
												continue;
											}

											$default_array['product_id']        = $product_children[ $i ];
											$default_array['product_variation'] = VI_WOO_BOPO_BUNDLE_Helper::bopobb_build_variations( $set_arr );

											return $default_array;
										} else {
											// Variation adequate
											$get_atts = $valriation_prd->get_variation_attributes();

											$default_array['product_id']        = $product_children[ $i ];
											$default_array['product_variation'] = VI_WOO_BOPO_BUNDLE_Helper::bopobb_build_variations( $get_atts );

											return $default_array;
										}
									}
								}
								continue;
							} else {
								continue;
							}

						} else if ( $prd->is_purchasable() && ( ( $prd->get_manage_stock() && $prd->get_stock_quantity() ) ||
						                                        ( ! $prd->get_manage_stock() && 'outofstock' != $prd->get_stock_status() ) ) ) {
							// Simple
							$default_array['product_id'] = $s_product_id;

							return $default_array;
						} else {
							continue;
						}
					}
					$product_title = get_the_title();
					$the_product   = new WC_Product( $s_product_id );
					if ( ! $the_product->is_in_stock() ) {
						$product_title .= ' (out-of-stock)';
					}
					$found_products[] = $s_product_id;
				}
//				while ( $the_query->have_posts() ) {
//					$the_query->the_post();
//					$prd          = wc_get_product( get_the_ID() );
//					$s_product_id = get_the_ID();
//
//					if ( ! $prd->is_purchasable() ) {
//						continue;
//					}
//
//					if ( ! empty( $ex_prod ) ) {
//						if ( in_array( strval( $s_product_id ), array_values( $ex_prod ), true ) ) {
//							if ( $val == 2 && $founded_count == 1 ) {
//								wp_reset_postdata();
//
//								return true;
//							}
//							continue;
//						}
//					}
//
//					if ( ! in_array( $prd->get_type(), $this->settings->get_params( 'bopobb_type_include' ), true ) ) {
//						continue;
//					}
//
//					if ( $val == 2 ) {
//						if ( $prd->is_type( 'variable' ) ) {
//							$product_children = $prd->get_children();
//							if ( count( $product_children ) == 1 ) {
//								$valriation_prd                = wc_get_product( $product_children[0] );
//								$variation_any                 = false;
//								$child_wc_variation_attributes = $valriation_prd->get_variation_attributes();
//
//								foreach ( $child_wc_variation_attributes as $attr_v ) {
//									if ( empty( $attr_v ) ) {
//										$variation_any = true;
//									}
//								}
//								if ( ! $variation_any && $valriation_prd->is_purchasable() ) {
//									wp_reset_postdata();
//
//									return false;
//								} else {
//									wp_reset_postdata();
//
//									return true;
//								}
//							} else {
//								wp_reset_postdata();
//
//								return true;
//							}
//						} else {
//							if ( $prd->is_purchasable() ) {
//								wp_reset_postdata();
//
//								return false;
//							} else {
//								wp_reset_postdata();
//
//								return true;
//							}
//						}
//						continue;
//					}
//
//					// Get default
//					if ( $val == 1 ) {
//						if ( $get_variable ) {
//							wp_reset_postdata();
//
//							return $s_product_id;
//						}
//						if ( $prd->is_type( 'variable' ) ) {
//							$product_children = $prd->get_children();
//							// Check child valid for sale
//							if ( count( $product_children ) ) {
//								for ( $i = 0; $i < count( $product_children ); $i ++ ) {
//									if ( ! empty( $prod_var ) ) {
//										if ( ! in_array( $product_children[ $i ], $prod_var ) ) {
//											continue;
//										}
//									}
//									if ( ! empty( $ex_prod_var ) ) {
//										if ( in_array( $product_children[ $i ], $ex_prod_var ) ) {
//											continue;
//										}
//									}
//									$valriation_prd = wc_get_product( $product_children[ $i ] );
//									//not load out stock product ignore setting bopobb_out_stock
//									$out_stock = false;
//									if ( $valriation_prd->is_purchasable() && $valriation_prd->get_price() &&
//									     ( ( $valriation_prd->get_manage_stock() && $valriation_prd->get_stock_quantity() ) ||
//									       ( ! $valriation_prd->get_manage_stock() && 'outofstock' != $valriation_prd->get_stock_status() ) || $out_stock ) ) {
//										$variation_any                 = false;
//										$child_wc_variation_attributes = $valriation_prd->get_variation_attributes();
//
//										foreach ( $child_wc_variation_attributes as $attr_v ) {
//											if ( empty( $attr_v ) ) {
//												$variation_any = true;
//											}
//										}
//
//										if ( $variation_any ) {
//											// Variation any
//											$any_variations = VI_WOO_BOPO_BUNDLE_Helper::bopobb_get_variation_default( $prd, $valriation_prd, $child_wc_variation_attributes );
//											$set_arr        = array();
//
//											if ( ! empty( $any_variations ) ) {
//												$key_arr = array_keys( $child_wc_variation_attributes );
//												if ( is_array( $any_variations ) || is_object( $any_variations ) ) {
//													if ( count( $key_arr ) == count( $any_variations ) ) {
//														$set_arr = array_combine( $key_arr, $any_variations );
//													}
//												} else {
//													$any_v = [ $any_variations ];
//													if ( count( $key_arr ) == count( $any_variations ) ) {
//														$set_arr = array_combine( $key_arr, $any_variations );
//													}
//												}
//											} else {
//												continue;
//											}
//
//											$default_array['product_id']        = $product_children[ $i ];
//											$default_array['product_variation'] = VI_WOO_BOPO_BUNDLE_Helper::bopobb_build_variations( $set_arr );
//											wp_reset_postdata();
//
//											return $default_array;
//										} else {
//											// Variation adequate
//											$get_atts = $valriation_prd->get_variation_attributes();
//
//											$default_array['product_id']        = $product_children[ $i ];
//											$default_array['product_variation'] = VI_WOO_BOPO_BUNDLE_Helper::bopobb_build_variations( $get_atts );
//											wp_reset_postdata();
//
//											return $default_array;
//										}
//									}
//								}
//								continue;
//							} else {
//								continue;
//							}
//
//						} else if ( $prd->is_purchasable() && ( ( $prd->get_manage_stock() && $prd->get_stock_quantity() ) ||
//						                                        ( ! $prd->get_manage_stock() && 'outofstock' != $prd->get_stock_status() ) ) ) {
//							// Simple
//							wp_reset_postdata();
//							$default_array['product_id'] = $s_product_id;
//
//							return $default_array;
//						} else {
//							continue;
//						}
//					}
//					$product_title = get_the_title();
//					$the_product   = new WC_Product( $s_product_id );
//					if ( ! $the_product->is_in_stock() ) {
//						$product_title .= ' (out-of-stock)';
//					}
//					$found_products[] = $s_product_id;
//				}
//				wp_reset_postdata();
				if ( $val == 2 ) {
					return count( $found_products ) > 1 ? true : false;
				}

				return $found_products;
			} else {
				if ( $val == 2 ) {
					return false;
				}
			}
			wp_reset_postdata();

			return null;
		}

		function bopobb_search_range_product( $arg_input = [] ) {
			$cat         = isset( $arg_input['bopobb_pbi_category'] ) ? $arg_input['bopobb_pbi_category'] : '';
			$ex_cat      = isset( $arg_input['bopobb_pbi_category_exclude'] ) ? $arg_input['bopobb_pbi_category_exclude'] : '';
			$tag         = isset( $arg_input['bopobb_pbi_tag'] ) ? $arg_input['bopobb_pbi_tag'] : '';
			$ex_tag      = isset( $arg_input['bopobb_pbi_tag_exclude'] ) ? $arg_input['bopobb_pbi_tag_exclude'] : '';
			$prod        = isset( $arg_input['bopobb_pbi_title'] ) ? $arg_input['bopobb_pbi_title'] : '';
			$ex_prod     = isset( $arg_input['bopobb_pbi_title_exclude'] ) ? $arg_input['bopobb_pbi_title_exclude'] : '';
			$sort        = isset( $arg_input['bopobb_bpi_sort'] ) ? $arg_input['bopobb_bpi_sort'] : '';
			$order       = isset( $arg_input['bopobb_bpi_order'] ) ? $arg_input['bopobb_bpi_order'] : '';
			$prod_var    = isset( $arg_input['bopobb_pbi_title_variation'] ) ? $arg_input['bopobb_pbi_title_variation'] : '';
			$ex_prod_var = isset( $arg_input['bopobb_pbi_title_variation_exclude'] ) ? $arg_input['bopobb_pbi_title_variation_exclude'] : '';
			$key         = isset( $arg_input['key_word'] ) ? $arg_input['key_word'] : '';

			$optional_item   = isset( $arg_input['bopobb_bpi_optional_item'] ) ? $arg_input['bopobb_bpi_optional_item'] : '';
			$discount_item   = isset( $arg_input['bopobb_bpi_discount'] ) ? $arg_input['bopobb_bpi_discount'] : '';
			$discount_number = isset( $arg_input['bopobb_bpi_discount_number'] ) ? $arg_input['bopobb_bpi_discount_number'] : '';

			$arg     = array(
				'post_status'    => 'publish',
				'post_type'      => 'product',
				'posts_per_page' => - 1,
				's'              => $key
			);
			$tax_arr = [];
			if ( ! empty( $cat ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_cat',
					'field'    => 'term_id',
					'terms'    => $cat,
				];
			}
			if ( ! empty( $ex_cat ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_cat',
					'field'    => 'term_id',
					'terms'    => $ex_cat,
					'operator' => 'NOT IN',
				];
			}
			if ( ! empty( $tag ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_tag',
					'field'    => 'term_id',
					'terms'    => $tag,
				];
			}
			if ( ! empty( $ex_tag ) ) {
				$tax_arr[] = [
					'taxonomy' => 'product_tag',
					'field'    => 'term_id',
					'terms'    => $ex_tag,
					'operator' => 'NOT IN',
				];
			}
			if ( ! empty( $tax_arr ) ) {
				$arg['tax_query'] = $tax_arr;// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_tax_query
			}
			if ( ! empty( $prod ) ) {
				$arg['post__in'] = $prod;
			}

			switch ( $sort ) {
				case 'ratting':
					$arg['orderby']  = 'meta_value_num';
					$arg['meta_key'] = '_wc_average_rating';// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_key
					$arg['order']    = $order;
					break;
				case 'price':
					$arg['orderby']  = 'meta_value_num';
					$arg['meta_key'] = '_price';// phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_key
					$arg['order']    = $order;
					break;
				default:
					$arg['orderby'] = 'title';
					$arg['order']   = $order;
					break;
			}

			$the_query       = new WP_Query( $arg );
			$founded_count   = $the_query->found_posts;
			$calc_price_base = $this->settings->get_params( 'bopobb_calculate_price' );

			$found_products = array();
			if ( $the_query->have_posts() ) {
				$s_product_ids = $the_query->posts;
				foreach ( $s_product_ids as $s_index => $s_product_object ) {
					if ( ! is_object( $s_product_object ) || empty( $s_product_object ) || ! property_exists( $s_product_object, 'ID' ) ) {
						continue;
					}
					$s_product_id = $s_product_object->ID;
					if ( is_array( $s_product_id ) || is_object( $s_product_id ) || empty( $s_product_id ) ) {
						continue;
					}
					$prd = wc_get_product( $s_product_id );

					if ( ! $prd || ! $prd->is_purchasable() ) {
						continue;
					}
					if ( ! empty( $ex_prod ) ) {
						if ( in_array( strval( $s_product_id ), array_values( $ex_prod ), true ) ) {

							continue;
						}
					}
					if ( ! in_array( $prd->get_type(), $this->settings->get_params( 'bopobb_type_include' ), true ) ) {
						continue;
					}

					// Get default
					if ( $prd->is_type( 'variable' ) ) {
						$product_children = $prd->get_children();
						// Check child valid for sale
						if ( count( $product_children ) ) {
							for ( $i = 0; $i < count( $product_children ); $i ++ ) {
								if ( ! empty( $prod_var ) ) {
									if ( ! in_array( $product_children[ $i ], $prod_var ) ) {
										continue;
									}
								}
								if ( ! empty( $ex_prod_var ) ) {
									if ( in_array( $product_children[ $i ], $ex_prod_var ) ) {
										continue;
									}
								}
								$valriation_prd = wc_get_product( $product_children[ $i ] );
								$out_stock      = $this->settings->get_params( 'bopobb_out_stock' );
								if ( $valriation_prd->is_purchasable() && $valriation_prd->get_price() &&
								     ( ( $valriation_prd->get_manage_stock() && $valriation_prd->get_stock_quantity() ) || ( ! $valriation_prd->get_manage_stock() ) || $out_stock ) ) {
									$the_product_price = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_calc_price( $valriation_prd, $calc_price_base );
									$found_products[]  = array(
										'id'    => $product_children[ $i ],
										'price' => (float) $the_product_price
									);
								}
							}
							continue;
						} else {
							continue;
						}

					} else if ( $prd->is_purchasable() ) {
						// Simple
//						wp_reset_postdata();
						$the_product       = new WC_Product( $s_product_id );
						$the_product_price = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_calc_price( $the_product, $calc_price_base );
						$found_products[]  = array( 'id' => $s_product_id, 'price' => (float) $the_product_price );
					} else {
						continue;
					}
				}
//				while ( $the_query->have_posts() ) {
//					$the_query->the_post();
//					$prd          = wc_get_product( get_the_ID() );
//					$s_product_id = get_the_ID();
//
//					if ( ! $prd || ! $prd->is_purchasable() ) {
//						continue;
//					}
//					if ( ! empty( $ex_prod ) ) {
//						if ( in_array( strval( $s_product_id ), array_values( $ex_prod ), true ) ) {
//
//							continue;
//						}
//					}
//					if ( ! in_array( $prd->get_type(), $this->settings->get_params( 'bopobb_type_include' ), true ) ) {
//						continue;
//					}
//
//					// Get default
//					if ( $prd->is_type( 'variable' ) ) {
//						$product_children = $prd->get_children();
//						// Check child valid for sale
//						if ( count( $product_children ) ) {
//							for ( $i = 0; $i < count( $product_children ); $i ++ ) {
//								if ( ! empty( $prod_var ) ) {
//									if ( ! in_array( $product_children[ $i ], $prod_var ) ) {
//										continue;
//									}
//								}
//								if ( ! empty( $ex_prod_var ) ) {
//									if ( in_array( $product_children[ $i ], $ex_prod_var ) ) {
//										continue;
//									}
//								}
//								$valriation_prd = wc_get_product( $product_children[ $i ] );
//								$out_stock      = $this->settings->get_params( 'bopobb_out_stock' );
//								if ( $valriation_prd->is_purchasable() && $valriation_prd->get_price() &&
//								     ( ( $valriation_prd->get_manage_stock() && $valriation_prd->get_stock_quantity() ) || ( ! $valriation_prd->get_manage_stock() ) || $out_stock ) ) {
//									$the_product_price = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_calc_price( $valriation_prd, $calc_price_base );
//									$found_products[]  = array(
//										'id'    => $product_children[ $i ],
//										'price' => (float) $the_product_price
//									);
//								}
//							}
//							continue;
//						} else {
//							continue;
//						}
//
//					} else if ( $prd->is_purchasable() ) {
//						// Simple
//						wp_reset_postdata();
//						$the_product       = new WC_Product( $s_product_id );
//						$the_product_price = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_calc_price( $the_product, $calc_price_base );
//						$found_products[]  = array( 'id' => $s_product_id, 'price' => (float) $the_product_price );
////						$default_array;
//					} else {
//						continue;
//					}
//				}
//				wp_reset_postdata();
				if ( ! empty( $found_products ) ) {
					$max_product = $min_product = array();
					foreach ( $found_products as $found_product ) {
						if ( ! isset( $found_product['price'] ) || ! isset( $found_product['id'] ) ) {
							continue;
						}
						if ( empty( $max_product ) ) {
							$max_product = $found_product;
						} else {
							if ( $max_product['price'] < $found_product['price'] ) {
								$max_product = $found_product;
							}
						}
						if ( empty( $min_product ) ) {
							$min_product = $found_product;
						} else {
							if ( $min_product['price'] > $found_product['price'] ) {
								$min_product = $found_product;
							}
						}
					}
					$min_product['price'] = $optional_item ? 0 : $this->calculate_discount_item( $min_product['price'], $discount_item, $discount_number );
					$max_product['price'] = $this->calculate_discount_item( $max_product['price'], $discount_item, $discount_number );

					return array( 'max' => $max_product['price'], 'min' => $min_product['price'] );
				}

				return $found_products;
			}
			wp_reset_postdata();

			return null;
		}

		function bopobb_cart_popup_data() {
			check_ajax_referer( 'bopo-nonce', 'nonce' );

			if ( isset( $_POST['item'] ) && ( $_POST['item'] !== '' ) ) {
				$item_index = absint( $_POST['item'] );
			} else {
				return;
			}
			if ( isset( $_POST['product'] ) && ( $_POST['product'] !== '' ) ) {
				$p_product_id = absint( $_POST['product'] );
//				ob_start();
				$data_product_list = $this->bopobb_load_product_list( $p_product_id, $item_index );
//                $data_product_list = ob_get_clean();
			} else {
				return;
			}
			$product_bundle = wc_get_product( $p_product_id );
			$variation_in   = isset( $data_product_list['variation'] ) ? $data_product_list['variation'] : '';
			$variation_ex   = isset( $data_product_list['variation_ex'] ) ? $data_product_list['variation_ex'] : '';
//			if ( $product_bundle ) {
//				$product_items = $product_bundle->get_items();
//				if ( isset( $product_items['items'][$item_index] ) && ! empty( $product_items['items'][$item_index] ) ) {
//					$variation_in = isset( $product_items['items'][$item_index]['bopobb_pbi_title_variation'] ) ?
//						$product_items['items'][$item_index]['bopobb_pbi_title_variation'] : 0;
//					$variation_ex = isset( $product_items['items'][$item_index]['bopobb_pbi_title_variation_exclude'] ) ?
//						$product_items['items'][$item_index]['bopobb_pbi_title_variation_exclude'] : 0;
//				}
//			}
			$discount_type   = 0;
			$discount_number = 0;
			if ( isset( $_POST['discount_type'] ) && ( $_POST['discount_type'] !== '' ) ) {
				$discount_type = wc_clean( wp_unslash( $_POST['discount_type'] ) );
			}
			if ( isset( $_POST['discount_number'] ) && ( $_POST['discount_number'] !== '' ) ) {
				$discount_number = wc_clean( wp_unslash( $_POST['discount_number'] ) );
			}
			if ( isset( $_POST['variation'] ) && ( $_POST['variation'] !== '' ) ) {
				$p_variation_id = absint( $_POST['variation'] );
				$p_variation    = wc_get_product( $p_variation_id );

				if ( $p_variation ) {
					$variable_id    = $p_variation->get_parent_id();
					$variable_title = get_the_title( $variable_id );
					ob_start();
					if ( $this->settings->get_params( 'bopobb_popup_variations' ) == 'list' ) {
						$this->bopobb_load_product_variations( $variable_id, $discount_type, $discount_number, $variation_in, $variation_ex );
					} else {
						$this->bopobb_load_product_options( $variable_id, $discount_type, $discount_number, $variation_in, $variation_ex );
					}
					$data_product_variations = ob_get_clean();
				} else {
					return;
				}
			} else {
				return;
			}
			ob_start();
			do_action( 'bopobb_popup_item_title', $p_product_id, $item_index );
			$filter_item_title = wp_kses_post( ob_get_clean() );

			$return_arr = [];
			array_push( $return_arr, isset( $data_product_list['products'] ) ? $data_product_list['products'] : '' );
			array_push( $return_arr, $data_product_variations );
			array_push( $return_arr, $variable_id );
			array_push( $return_arr, $variable_title );
			array_push( $return_arr, $variation_in );
			array_push( $return_arr, $variation_ex );
			array_push( $return_arr, $filter_item_title );
			wp_send_json( $return_arr );
		}

		function bopobb_product_list() {
			check_ajax_referer( 'bopo-nonce', 'nonce' );
			if ( isset( $_POST['item'] ) && ( $_POST['item'] !== '' ) ) {
				$item_index = absint( $_POST['item'] );
			} else {
				return;
			}
			if ( isset( $_POST['product'] ) && ( $_POST['product'] !== '' ) ) {
				$p_product_id = absint( $_POST['product'] );
			} else {
				return;
			}
			$page     = isset( $_POST['page'] ) ? absint( $_POST['page'] ) : 1;
			$category = isset( $_POST['category'] ) ? sanitize_text_field( wp_unslash( $_POST['category'] ) ) : '';
			$key_word = isset( $_POST['key'] ) ? sanitize_text_field( wp_unslash( $_POST['key'] ) ) : '';
			$o_data   = $this->bopobb_load_product_list( $p_product_id, $item_index, $page, $category, $key_word );
			wp_send_json( $o_data );

			wp_die();
		}

		function bopobb_load_product_list( $product_id, $item_index, $page = 1, $category = '', $key_word = '' ) {
			$product_bundle = wc_get_product( $product_id );
			$per_page       = intval( $this->settings->get_params( 'bopobb_popup_page_items' ) );
			$is_link_title  = $this->settings->get_params( 'bopobb_popup_link' );
			if ( empty( $per_page ) || $per_page < 1 ) {
				$per_page = 32;
			}
			if ( $items = $product_bundle->get_items() ) {
				$item_categories = $product_bundle->bopobb_get_categories( $item_index );
				$items_data      = $items['items'][ $item_index ];
				if ( ! empty( $category ) ) {
					$items_data['bopobb_pbi_category'] = array( $category );
				}
				if ( ! empty( $key_word ) ) {
					$items_data['key_word'] = $key_word;
				}
				$o_data['variation']    = isset( $items_data['bopobb_pbi_title_variation'] ) ? $items_data['bopobb_pbi_title_variation'] : '';
				$o_data['variation_ex'] = isset( $items_data['bopobb_pbi_title_variation_exclude'] ) ? $items_data['bopobb_pbi_title_variation_exclude'] : '';
				$i_product_ids          = $this->bopobb_search_product( 0, 1, $items_data );
				$calc_price_base        = $this->settings->get_params( 'bopobb_calculate_price' );
				ob_start();
				if ( $i_product_ids ) {
					$page_wrap  = intval( $page * $per_page );
					$page_end   = $page_wrap > count( $i_product_ids ) ? count( $i_product_ids ) : $page_wrap;
					$page_start = $page_wrap - $per_page;

					$filter_enable = $search_enable = $paging_enable = false;
					$filter_wrap   = 0;
					if ( $this->settings->get_params( 'bopobb_popup_filter' ) == 1 && ! empty( $item_categories ) ) {
						$filter_wrap ++;
						$filter_enable = true;
					}
					if ( $this->settings->get_params( 'bopobb_popup_search' ) == 1 ) {
						$filter_wrap ++;
						$search_enable = true;
					}
					if ( count( $i_product_ids ) > $per_page ) {
						$filter_wrap ++;
						$paging_enable = true;
					}
					$paging_class = 'bopobb-paging-hidden';
					if ( $filter_wrap >= 2 ) {
						$paging_class = 'bopobb-paging-full';
					} elseif ( $filter_enable || $search_enable || $paging_enable ) {
						$paging_class = 'bopobb-paging-part';
					}
					for ( $i = $page_start; $i < $page_end; $i ++ ) {
						if ( empty( $i_product_ids[ $i ] ) ) {
							continue;
						}
						$wc_product = wc_get_product( $i_product_ids[ $i ] );
//						$price_src = wc_get_price_excluding_tax( $wc_product );
						$price_src  = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $wc_product, $calc_price_base );
						$price_html = VI_WOO_BOPO_BUNDLE_Helper::bopohp_price_scope( $wc_product,
							array(
								$items_data['bopobb_bpi_discount'],
								$items_data['bopobb_bpi_discount_number']
							), false, $calc_price_base );
						$out_stock  = $this->settings->get_params( 'bopobb_out_stock' );
						if ( ! $wc_product->is_purchasable() ) {
							continue;
						}
						if ( $wc_product->get_manage_stock() ) {
							$wc_product_stock = method_exists( $wc_product, 'get_stock_quantity' ) &&
							                    ! empty( $wc_product->get_stock_quantity() ) ? $wc_product->get_stock_quantity() : 0;
							$allow_backorder  = method_exists( $wc_product, 'backorders_allowed' ) ? $wc_product->backorders_allowed() : 0;
						} else {
							$wc_product_stock = - 1;
							$allow_backorder  = 0;
							if ( 'outofstock' == $wc_product->get_stock_status() ) {
								$wc_product_stock = 0;
							}
						};
						if ( ! $wc_product->is_in_stock() && $out_stock != '1' ) {
							continue;
						}
						?>
                        <div class="bopobb-product bopobb-product-id-<?php echo esc_attr( $i_product_ids[ $i ] ) ?>"
                             data-product="<?php echo esc_attr( $i_product_ids[ $i ] ) ?>"
                             data-type="<?php echo esc_attr( $wc_product->get_type() ); ?>"
                             data-price="<?php echo esc_attr( $price_src ); ?>">
                            <div class="bopobb-product-img-wrap"
                                 title="<?php esc_attr_e( 'Add', 'bopo-woocommerce-product-bundle-builder' ); ?>">
								<?php echo wp_kses_post( $wc_product->get_image( $this->settings->get_params( 'bopobb_popup_image_size' ) ) ); ?>
                                <span class="bopobb-product-zoom"
                                      title="<?php esc_attr_e( 'Gallery', 'bopo-woocommerce-product-bundle-builder' ); ?>"><p
                                            class="bopobb-icon-image3"></p></span>
                            </div>
                            <div class="bopobb-product-title-wrap">
								<?php if ( $is_link_title ) { ?>
                                    <a class="bopobb-product-title"
                                       data-link="<?php echo esc_url( $wc_product->get_permalink() ) ?>"
                                       href="<?php echo esc_url( $wc_product->get_permalink() ) ?>" target="_blank">
										<?php echo wp_kses_post( $wc_product->get_title() ); ?>
                                    </a>
								<?php } else { ?>
                                    <div class="bopobb-product-title"
                                         data-link="<?php echo esc_url( $wc_product->get_permalink() ) ?>">
										<?php echo wp_kses_post( $wc_product->get_title() ); ?>
                                    </div>
								<?php } ?>
                            </div>
                            <div class="bopobb-product-ratting">
								<?php if ( ! empty( $wc_product->get_rating_count() ) && $this->settings->get_params( 'bopobb_view_ratting' ) ) {
									echo wp_kses_post( wc_get_rating_html( $wc_product->get_average_rating() ) );
								}
								?>
                            </div>
                            <div class="bopobb-product-price">
								<?php echo wp_kses_post( $price_html[0] ); ?>
                            </div>
                            <div class="bopobb-product-stock" data-stock="<?php echo esc_attr( $wc_product_stock ) ?>"
                                 data-backorder="<?php echo esc_attr( $allow_backorder ) ?>">
								<?php if ( $this->settings->get_params( 'bopobb_view_stock' ) ) {
									echo wp_kses_post( wc_get_stock_html( $wc_product ) );
								} ?>
                            </div>
							<?php
							if ( $this->settings->get_params( 'bopobb_view_description' ) ) { ?>
                                <div class="bopobb-product-description">
									<?php echo wp_kses_post( $wc_product->get_short_description() ); ?>
                                </div>
							<?php } ?>
							<?php
							if ( $this->settings->get_params( 'bopobb_view_full_description' ) ) { ?>
                                <div class="bopobb-product-full-description">
									<?php echo wp_kses_post( $wc_product->get_description() ); ?>
                                </div>
							<?php } ?>
                        </div>
						<?php
					} ?>
                    <div class="bopobb-product-paging-wrap <?php echo esc_attr( $paging_class ) ?>">
						<?php if ( $filter_enable ) { ?>
                            <div class="bopobb-category-filter-wrap">
                                <select class="bopobb-category-filter">
                                    <option value=""><?php esc_html_e( 'Filter by category', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
									<?php foreach ( $item_categories as $key => $val ) { ?>
                                        <option value="<?php echo esc_attr( $key ) ?>"><?php echo esc_html( $val ) ?></option>
									<?php } ?>
                                </select>
                            </div>
						<?php }
						if ( $search_enable ) { ?>
                            <div class="bopobb-search-filter-wrap">
                                <input type="text" class="bopobb-search-filter-input"
                                       value="<?php echo esc_attr( $key_word ) ?>"
                                       placeholder="<?php esc_attr_e( 'Search by title', 'bopo-woocommerce-product-bundle-builder' ); ?>">
                                <div class="bopobb-search-filter-button"></div>
                            </div>
						<?php }
						if ( $paging_enable ) {
							$total_page = count( $i_product_ids ) % $per_page == 0 ?
								intdiv( count( $i_product_ids ), $per_page ) :
								intdiv( count( $i_product_ids ), $per_page ) + 1;
							?>
                            <div class="bopobb-product-paging">
								<?php for ( $p = 1; $p <= $total_page; $p ++ ) {
									if ( $p == 1 || $p == $total_page ) { ?>
                                        <div class="bopobb-product-pages <?php
										if ( $p == $page )
											echo esc_attr( 'bopobb-product-page-active' ) ?>" data-page="<?php
										echo esc_attr( $p ) ?>"><?php echo esc_html( $p ) ?></div>
										<?php continue;
									}
									if ( $p <= $page ) {
										if ( $p < $page - 2 ) {
											continue;
										}
										if ( $p > $page - 2 ) {
											?>
                                            <div class="bopobb-product-pages <?php
											if ( $p == $page )
												echo esc_attr( 'bopobb-product-page-active' ) ?>" data-page="<?php
											echo esc_attr( $p ) ?>"><?php echo esc_html( $p ) ?></div>
											<?php
											continue;
										}
										if ( $p == $page - 2 ) {
											if ( $p != 2 ) {
												?>
                                                <div class="bopobb-product-pages-break">...</div>
											<?php } ?>
                                            <div class="bopobb-product-pages <?php
											if ( $p == $page )
												echo esc_attr( 'bopobb-product-page-active' ) ?>" data-page="<?php
											echo esc_attr( $p ) ?>"><?php echo esc_html( $p ) ?></div>
											<?php
											continue;
										}
									} else {
										if ( $p > $page + 2 ) {
											continue;
										}
										if ( $p < $page + 2 ) {
											?>
                                            <div class="bopobb-product-pages <?php
											if ( $p == $page )
												echo esc_attr( 'bopobb-product-page-active' ) ?>" data-page="<?php
											echo esc_attr( $p ) ?>"><?php echo esc_html( $p ) ?></div>
											<?php
											continue;
										}
										if ( $p == $page + 2 ) {
											?>
                                            <div class="bopobb-product-pages <?php
											if ( $p == $page )
												echo esc_attr( 'bopobb-product-page-active' ) ?>" data-page="<?php
											echo esc_attr( $p ) ?>"><?php echo esc_html( $p ) ?></div>
											<?php if ( $p + 1 != $total_page ) {
												?>
                                                <div class="bopobb-product-pages-break">...</div>
											<?php }
											continue;
										}
									}
								} ?>
                            </div>
						<?php } ?>
                    </div>
				<?php } else {
					$filter_enable = $this->settings->get_params( 'bopobb_popup_filter' ) == 1 && ! empty( $item_categories );
					$search_enable = $this->settings->get_params( 'bopobb_popup_search' );
					$paging_class  = 'bopobb-paging-hidden';
					if ( $filter_enable && $search_enable ) {
						$paging_class = 'bopobb-paging-full';
					} else {
						$paging_class = 'bopobb-paging-part';
					}
					?>
                    <div class="bopobb-product-paging-wrap <?php echo esc_attr( $paging_class ) ?>">
						<?php if ( $filter_enable ) { ?>
                            <div class="bopobb-category-filter-wrap">
                                <select class="bopobb-category-filter">
                                    <option value=""><?php esc_html_e( 'Filter by category', 'bopo-woocommerce-product-bundle-builder' ) ?></option>
									<?php foreach ( $item_categories as $key => $val ) { ?>
                                        <option value="<?php echo esc_attr( $key ) ?>"><?php echo esc_html( $val ) ?></option>
									<?php } ?>
                                </select>
                            </div>
						<?php }
						if ( $search_enable ) { ?>
                            <div class="bopobb-search-filter-wrap">
                                <input type="text" class="bopobb-search-filter-input"
                                       value="<?php echo esc_attr( $key_word ) ?>"
                                       placeholder="<?php esc_attr_e( 'Search by title', 'bopo-woocommerce-product-bundle-builder' ); ?>">
                                <div class="bopobb-search-filter-button"></div>
                            </div>
						<?php } ?>
                    </div>
				<?php }
				$o_data['products'] = ob_get_clean();
				ob_start();
				do_action( 'bopobb_popup_item_title', $product_id, $item_index );
				$o_data['item_title'] = wp_kses_post( ob_get_clean() );

				return $o_data;
			}

			return '';
		}

		function bopobb_popup_item_title( $product_id, $item_index ) {
			$item_product = wc_get_product( $product_id );
			$item_title   = '';
			if ( ! $item_product || 'bopobb' != $item_product->get_type() ) {
				return;
			}
			$product_data = $item_product->get_items();
			if ( ! $product_data || ! is_array( $product_data ) || ! is_array( $product_data['items'] )
			     || ! isset( $product_data['items'][ $item_index ] ) || ! isset( $product_data['items'][ $item_index ]['bopobb_pbi_category'] )
			     || ! is_array( $product_data['items'][ $item_index ]['bopobb_pbi_category'] ) || empty( $product_data['items'][ $item_index ]['bopobb_pbi_category'] ) ) {
				return;
			}
			foreach ( $product_data['items'][ $item_index ]['bopobb_pbi_category'] as $cat_id ) {
				if ( empty( $cat_id ) ) {
					continue;
				}
				$item_category = get_the_category_by_ID( $cat_id );
				if ( ! $item_category ) {
					continue;
				}
				if ( empty( $item_title ) ) {
					$item_title = $item_category;
				} else {
					$item_title .= ', ' . $item_category;
				}
			}
			echo wp_kses_post( $item_title );
		}

		function bopobb_product_variations() {
			check_ajax_referer( 'bopo-nonce', 'nonce' );
			if ( isset( $_POST['product'] ) && ( $_POST['product'] !== '' ) ) {
				$p_product_id = absint( $_POST['product'] );
			} else {
				return;
			}
			$variation_in    = 0;
			$variation_ex    = 0;
			$discount_type   = 0;
			$discount_number = 0;
			if ( isset( $_POST['variation_in'] ) && ( $_POST['variation_in'] !== '' ) ) {
				$variation_in = wc_clean( wp_unslash( $_POST['variation_in'] ) );
				$variation_in = ! empty( $variation_in ) ? explode( ',', $variation_in ) : 0;
			}
			if ( isset( $_POST['variation_ex'] ) && ( $_POST['variation_ex'] !== '' ) ) {
				$variation_ex = wc_clean( wp_unslash( $_POST['variation_ex'] ) );
				$variation_ex = ! empty( $variation_ex ) ? explode( ',', $variation_ex ) : 0;
			}
			if ( isset( $_POST['discount_type'] ) && ( $_POST['discount_type'] !== '' ) ) {
				$discount_type = wc_clean( wp_unslash( $_POST['discount_type'] ) );
			}
			if ( isset( $_POST['discount_number'] ) && ( $_POST['discount_number'] !== '' ) ) {
				$discount_number = wc_clean( wp_unslash( $_POST['discount_number'] ) );
			}
			if ( $this->settings->get_params( 'bopobb_popup_variations' ) == 'list' ) {
				$this->bopobb_load_product_variations( $p_product_id, $discount_type, $discount_number, $variation_in, $variation_ex );
			} else {
				$this->bopobb_load_product_options( $p_product_id, $discount_type, $discount_number, $variation_in, $variation_ex );
			}
			wp_die();
		}

		function bopobb_search_many_variation() {
			check_ajax_referer( 'bopo-nonce', 'nonce' );

			if ( isset( $_POST['data'] ) && ( $_POST['data'] !== '' ) ) {
				$p_variation_data = array_map( 'esc_attr', wp_unslash( $_POST['data'] ) );// phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
			} else {
				wp_die();
			}
			if ( isset( $p_variation_data['product_id'] ) && ( $p_variation_data['product_id'] ) ) {
				$p_product_id = absint( $p_variation_data['product_id'] );
			} else {
				wp_die();
			}

			$variable_product = wc_get_product( $p_product_id );

			if ( ! $variable_product ) {
				wp_die();
			}
			$d_type   = $p_variation_data['type'];
			$d_number = $p_variation_data['number'];
			unset( $p_variation_data['type'] );
			unset( $p_variation_data['number'] );
			$data_store      = WC_Data_Store::load( 'product' );
			$variation_id    = $data_store->find_matching_product_variation( $variable_product, wp_unslash( $p_variation_data ) );
			$variation       = $variation_id ? $variable_product->get_available_variation( $variation_id ) : false;
			$calc_price_base = $this->settings->get_params( 'bopobb_calculate_price' );
			if ( $variation ) {
				$child_product           = wc_get_product( $variation_id );
				$price_html              = VI_WOO_BOPO_BUNDLE_Helper::bopohp_price_scope( $child_product, array(
					$d_type,
					$d_number
				), true, $calc_price_base );
				$variation['price_html'] = $price_html[0];
//				$variation['display_price'] = (float) wc_get_price_excluding_tax( $child_product );
				$variation['display_price'] = (float) VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $child_product, $calc_price_base );
			}
			wp_send_json( $variation );

			wp_die();
		}

		function bopobb_load_product_options( $p_variable_id, $d_type, $d_number, $variation_in = 0, $variation_ex = 0 ) {
			$product_variable = wc_get_product( $p_variable_id );
			$calc_price_base  = $this->settings->get_params( 'bopobb_calculate_price' );
			$is_link_title    = $this->settings->get_params( 'bopobb_popup_link' );
			if ( $product_variable->has_child() && $product_variable->is_type( 'variable' ) ) {
				$get_variations       = count( $product_variable->get_children() ) <= apply_filters( 'woocommerce_ajax_variation_threshold', 30, $product_variable );
				$available_variations = $get_variations ? $product_variable->get_available_variations() : false;
				if ( $available_variations ) {
					$include_variation = array();
					foreach ( $available_variations as $var_key => $var_val ) {
						if ( ! empty( $variation_in ) ) {
							if ( ! in_array( $var_val['variation_id'], $variation_in ) ) {
								continue;
							}
						}
						if ( ! empty( $variation_ex ) ) {
							if ( in_array( $var_val['variation_id'], $variation_ex ) ) {
								continue;
							}
						}
						$child_product                                  = wc_get_product( $var_val['variation_id'] );
						$price_html                                     = VI_WOO_BOPO_BUNDLE_Helper::bopohp_price_scope( $child_product, array(
							$d_type,
							$d_number
						), true, $calc_price_base );
						$available_variations[ $var_key ]['price_html'] = $price_html[0];
//		                $available_variations[ $var_key ]['display_price'] = (float) wc_get_price_excluding_tax( $child_product );
						$available_variations[ $var_key ]['display_price'] = (float) VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $child_product, $calc_price_base );
						$include_variation[]                               = $available_variations[ $var_key ];
					}
					$variations_json = wp_json_encode( $include_variation );
//	                $variations_json = wp_json_encode( $available_variations );
					$variations_attr = function_exists( 'wc_esc_json' ) ? wc_esc_json( $variations_json ) : _wp_specialchars( $variations_json, ENT_QUOTES, 'UTF-8', true );

				} else {
					$variations_attr = wp_json_encode( false );
				}
				?>
                <div class="bopobb-option-product" data-product="" data-type="variation" data-price="">
                    <div class="bopobb-option-image-wrap">
						<?php echo wp_kses_post( $product_variable->get_image( $this->settings->get_params( 'bopobb_popup_image_size' ) ) ); ?>
                    </div>
                    <div class="bopobb-option-detail-wrap">
                        <input type="hidden" class="bopobb-product-variations" value="" readonly="readonly">
                        <div class="bopobb-option-short-description bopobb-product-description"><?php
							echo wp_kses_post( $product_variable->get_short_description() ) ?></div>
                        <div class="bopobb-option-variations"
                             data-product_variations="<?php echo $variations_attr; //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>">
                            <table>
                                <tbody>
								<?php foreach ( $product_variable->get_variation_attributes() as $attribute_name => $options ) : ?>
                                    <tr class="bopobb-option-variation<?php echo class_exists( 'VIWPVS_WOOCOMMERCE_PRODUCT_VARIATIONS_SWATCHES' ) ||
									                                             class_exists( 'VI_WOO_PRODUCT_VARIATIONS_SWATCHES' ) ? ' bopobb-option-swatches' : '' ?>">
										<?php $option_label = wc_attribute_label( $attribute_name ) ?>
                                        <th>
                                            <span class="bopobb-option-label"><?php echo esc_html( ucfirst( $option_label ) ) ?></span>
                                        </th>
                                        <td>
											<?php
											if ( class_exists( 'VIWPVS_WOOCOMMERCE_PRODUCT_VARIATIONS_SWATCHES' ) ||
											     class_exists( 'VI_WOO_PRODUCT_VARIATIONS_SWATCHES' ) ) {
												wc_dropdown_variation_attribute_options(
													array(
														'options'   => $options,
														'attribute' => $attribute_name,
														'product'   => $product_variable,
														'class'     => 'bopobb-option-select',
													)
												);
											} else {
												?>
                                                <select id="<?php echo esc_attr( sanitize_title( $attribute_name ) ) ?>"
                                                        name="<?php echo esc_attr( 'attribute_' . sanitize_title( $attribute_name ) ) ?>"
                                                        class="<?php echo esc_attr( 'bopobb-option-select' ) ?>"
                                                        data-attribute-name="<?php echo esc_attr( 'attribute_' . sanitize_title( $attribute_name ) ) ?>">
													<?php foreach ( $options as $option ) {
														$cur_term = get_term_by( 'slug', $option, $attribute_name );
														echo '<option value="' . esc_attr( $option ) . '">' . esc_html( ! empty( $cur_term->name ) ? $cur_term->name : $option ) . '</option>';
													} ?>
                                                </select>
											<?php } ?>
                                        </td>
                                    </tr>
								<?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                        <div class="bopobb-variation-description"></div>
                        <div class="bopobb-product-full-description bopobb-hidden">
							<?php echo wp_kses_post( $product_variable->get_description() ? $product_variable->get_description() : '' ); ?>
                        </div>
                        <div class="bopobb-product-ratting bopobb-hidden">
							<?php if ( ! empty( $product_variable->get_rating_count() ) && $this->settings->get_params( 'bopobb_view_ratting' ) ) {
								echo wp_kses_post( wc_get_rating_html( $product_variable->get_average_rating() ) );
							}
							?>
                        </div>
                        <div class="bopobb-product-title-wrap bopobb-hidden">
							<?php if ( $is_link_title ) { ?>
                                <a class="bopobb-product-title"
                                   data-title="<?php echo esc_attr( $product_variable->get_title() ); ?>">
									<?php echo esc_html( $product_variable->get_title() ); ?>
                                </a>
							<?php } else { ?>
                                <div class="bopobb-product-title"
                                     data-title="<?php echo esc_attr( $product_variable->get_title() ); ?>">
									<?php echo esc_html( $product_variable->get_title() ); ?>
                                </div>
							<?php } ?>
                        </div>
                        <div class="bopobb-option-price-wrap"></div>
                        <div class="bopobb-product-stock<?php echo $this->settings->get_params( 'bopobb_view_stock' ) ? '' : ' bopobb-hidden' ?>"></div>
                        <div class="bopobb-option-add-wrap">
                            <div class="bopobb-option-add"><?php esc_html_e( 'Add to bundle', 'bopo-woocommerce-product-bundle-builder' ); ?></div>
                        </div>
                    </div>
                </div>
				<?php
				wp_reset_postdata();
			}
		}

		function bopobb_load_product_variations( $p_variable_id, $d_type = 0, $d_number = 0, $variation_in = 0, $variation_ex = 0 ) {
			$product_variable = wc_get_product( $p_variable_id );
			$calc_price_base  = $this->settings->get_params( 'bopobb_calculate_price' );
			$is_link_title    = $this->settings->get_params( 'bopobb_popup_link' );
			if ( $product_variable->has_child() && $product_variable->is_type( 'variable' ) ) {

				$product_children = $product_variable->get_children();
				$variation_arr    = [];
				$out_stock        = $this->settings->get_params( 'bopobb_out_stock' );
				if ( count( $product_children ) ) {
					foreach ( $product_children as $product_child ) {
						if ( ! empty( $variation_in ) ) {
							if ( ! in_array( $product_child, $variation_in ) ) {
								continue;
							}
						}
						if ( ! empty( $variation_ex ) ) {
							if ( in_array( $product_child, $variation_ex ) ) {
								continue;
							}
						}
						$child_wc = wc_get_product( $product_child );
						if ( ! $child_wc->is_purchasable() ) {
							continue;
						}
						if ( $out_stock != '1' && ! $child_wc->is_in_stock() ) {
							continue;
						}

						$variation_any                 = false;
						$child_wc_variation_attributes = $child_wc->get_variation_attributes();

						foreach ( $child_wc_variation_attributes as $attr_k => $attr_v ) {
							if ( empty( $attr_v ) && $attr_v !== 0 && $attr_v != '0' ) {
								$variation_any = true;
							}
						}
						if ( $variation_any ) {
							// simple compare array
							$any_variations = VI_WOO_BOPO_BUNDLE_Helper::bopobb_get_variations( $product_variable, $product_child, $child_wc_variation_attributes, $variation_arr );

							if ( ! empty( $any_variations ) ) {
								$any_to_all    = VI_WOO_BOPO_BUNDLE_Helper::bopobb_set_array( $any_variations, $product_child );
								$variation_arr = array_merge( $variation_arr, $any_to_all );
								foreach ( $any_variations as $any_v ) {
									$key_arr = array_keys( $child_wc_variation_attributes );
									if ( is_array( $any_v ) || is_object( $any_v ) ) {
										if ( count( $key_arr ) == count( $any_v ) ) {
											$set_arr = array_combine( $key_arr, $any_v );
											self::bopobb_get_variations_html( $p_variable_id, $product_child, $set_arr, $d_type, $d_number );
										}
									} else {
										$any_v = [ $any_v ];
										if ( count( $key_arr ) == count( $any_v ) ) {
											$set_arr = array_combine( $key_arr, $any_v );
											self::bopobb_get_variations_html( $p_variable_id, $product_child, $set_arr, $d_type, $d_number );
										}
									}
								}
							}

						} else {
							$achieve_arr        = [];
							$achieve_arr['id']  = $product_child;
							$child_wc_title     = '';
							$variable_title     = $product_variable->get_title();
							$price_html         = VI_WOO_BOPO_BUNDLE_Helper::bopohp_price_scope( $child_wc, array(
								$d_type,
								$d_number
							), false, $calc_price_base );
							$get_atts           = $child_wc->get_variation_attributes();
							$is_variation_valid = VI_WOO_BOPO_BUNDLE_Helper::bopobb_is_variation_allow( $product_variable, $product_child, $get_atts, $variation_arr );
							if ( ! $is_variation_valid ) {
								continue;
							}
							foreach ( $get_atts as $att_k => $att_v ) {
								$cur_key       = substr( $att_k, 10 );
								$cur_term      = get_term_by( 'slug', $att_v, $cur_key );
								$achieve_arr[] = $att_v;
								if ( ! empty( $cur_term ) ) {
									$tax_name = wc_attribute_label( $cur_term->taxonomy );
									if ( empty( $child_wc_title ) ) {
										$child_wc_title = $tax_name . ': ' . $cur_term->name;
									} else {
										$child_wc_title .= ', ' . $tax_name . ': ' . $cur_term->name;
									}
									$variable_title .= ' - ' . $cur_term->name;
								} else {
									if ( empty( $child_wc_title ) ) {
										$child_wc_title = ucfirst( $cur_key ) . ': ' . $att_v;
									} else {
										$child_wc_title .= ', ' . ucfirst( $cur_key ) . ': ' . $att_v;
									}
									$variable_title .= ' - ' . $att_v;
								}
							}
							$variation_arr = array_merge( $variation_arr, [ $achieve_arr ] );

							if ( $child_wc->get_manage_stock() ) {
								$wc_product_stock = ! empty( $child_wc->get_stock_quantity() ) ? $child_wc->get_stock_quantity() : 0;
								$allow_backorder  = method_exists( $child_wc, 'backorders_allowed' ) ? $child_wc->backorders_allowed() : 0;
							} else {
								$wc_product_stock = - 1;
								$allow_backorder  = 0;
								if ( 'outofstock' == $child_wc->get_stock_status() ) {
									$wc_product_stock = 0;
								}
							};
							?>
                            <div class="bopobb-product" data-product="<?php echo esc_attr( $product_child ) ?>"
                                 data-type="variation"
                                 data-price="<?php //echo esc_attr( wc_get_price_excluding_tax( $child_wc ) );
							     echo esc_attr( VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $child_wc, $calc_price_base ) ); ?>" <?php
							foreach ( $child_wc_variation_attributes as $attr_k => $attr_v ) {
								?> data-<?php echo esc_attr( $attr_k ) ?>="<?php echo esc_attr( $attr_v ) ?>"
								<?php
							}
							?> >
                                <input class="bopobb-product-variations"
                                       value="<?php echo esc_attr( VI_WOO_BOPO_BUNDLE_Helper::bopobb_build_variations( $get_atts ) ) ?>"
                                       readonly="readonly">
                                <div class="bopobb-product-img-wrap"
                                     title="<?php esc_attr_e( 'Add', 'bopo-woocommerce-product-bundle-builder' ); ?>">
									<?php echo wp_kses_post( $child_wc->get_image( $this->settings->get_params( 'bopobb_popup_image_size' ) ) ); ?>
                                </div>
                                <div class="bopobb-product-title-wrap"><?php
									if ( $is_link_title ) { ?>
                                        <a class="bopobb-product-title"
                                           data-title="<?php echo esc_attr( $variable_title ); ?>">
											<?php echo esc_html( $variable_title ); ?>
                                        </a>
                                        <a class="bopobb-variation-title"
                                           data-link="<?php echo esc_url( $child_wc->get_permalink() ) ?>"
                                           href="<?php echo esc_url( $child_wc->get_permalink() ) ?>" target="_blank">
											<?php echo esc_html( $child_wc_title ); ?>
                                        </a>
									<?php } else { ?>
                                        <div class="bopobb-product-title"
                                             data-title="<?php echo esc_attr( $variable_title ); ?>">
											<?php echo esc_html( $variable_title ); ?>
                                        </div>
                                        <div class="bopobb-variation-title"
                                             data-link="<?php echo esc_url( $child_wc->get_permalink() ) ?>">
											<?php echo esc_html( $child_wc_title ); ?>
                                        </div>
									<?php } ?>
                                </div>
                                <div class="bopobb-product-ratting">
									<?php if ( ! empty( $product_variable->get_rating_count() ) && $this->settings->get_params( 'bopobb_view_ratting' ) ) {
										echo wp_kses_post( wc_get_rating_html( $product_variable->get_average_rating() ) );
									}
									?>
                                </div>
                                <div class="bopobb-product-price">
									<?php echo wp_kses_post( $price_html[0] ); ?>
                                </div>
                                <div class="bopobb-product-stock"
                                     data-stock="<?php echo esc_attr( $wc_product_stock ) ?>"
                                     data-backorder="<?php echo esc_attr( $allow_backorder ) ?>">
									<?php if ( $this->settings->get_params( 'bopobb_view_stock' ) ) {
										echo wp_kses_post( wc_get_stock_html( $child_wc ) );
									}
									?>
                                </div>
								<?php
								if ( $this->settings->get_params( 'bopobb_view_description' ) ) { ?>
                                    <div class="bopobb-product-description bopobb-hidden">
										<?php echo wp_kses_post( $product_variable->get_short_description() ); ?>
                                    </div>
								<?php } ?>
								<?php
								if ( $this->settings->get_params( 'bopobb_view_full_description' ) ) {
									$child_des = $child_wc->get_description(); ?>
                                    <div class="bopobb-product-full-description<?php if ( empty( $child_des ) )
										echo ' bopobb-hidden' ?>">
										<?php echo wp_kses_post( empty( $child_des ) ? $product_variable->get_description() : $child_des ); ?>
                                    </div>
								<?php } ?>
                            </div>
							<?php
						}
					}
					?>
                    <div class="bopobb-product-filter">
                        <div class="bopobb-filter-variations" cellspacing="0">
							<?php foreach ( $product_variable->get_variation_attributes() as $attribute_name => $options ) : ?>
                                <div class="bopobb-filter-variation">
                                    <div class="bopobb-attr-value">
										<?php
										$attribute_name_o = strtolower( $attribute_name );
										$attribute_name_o = preg_replace( '/\s+/', '-', $attribute_name_o );
										?>
                                        <select id="<?php echo esc_attr( $attribute_name_o ) ?>"
                                                name="<?php echo esc_attr( 'attribute_' . $attribute_name_o ) ?>"
                                                class="<?php echo esc_attr( 'bopobb-attr-select' ) ?>"
                                                data-attribute-name="<?php echo esc_attr( 'attribute_' . $attribute_name_o ) ?>">
                                            <option value=""><?php esc_html_e( 'Filter by ', 'bopo-woocommerce-product-bundle-builder' );
												echo esc_html( wc_attribute_label( $attribute_name ) ) ?></option>
											<?php foreach ( $options as $option ) {
												$cur_term = get_term_by( 'slug', $option, $attribute_name );
												if ( $cur_term ) {
													echo '<option value="' . esc_attr( $option ) . '">' . esc_html( $cur_term->name ) . '</option>';
												} else {
													echo '<option value="' . esc_attr( $option ) . '">' . esc_html( $option ) . '</option>';
												}
											} ?>
                                        </select>
                                    </div>
                                </div>
							<?php endforeach; ?>
                        </div>
                    </div>
					<?php
				}
			}
		}

		function bopobb_product_gallery() {
			check_ajax_referer( 'bopo-nonce', 'nonce' );
			if ( isset( $_POST['product'] ) && ( $_POST['product'] !== '' ) ) {
				$p_product_id = absint( $_POST['product'] );
			} else {
				return;
			}
			global $post, $product;
			$post    = get_post( $p_product_id );
			$product = wc_get_product( $p_product_id );
			bopobb_get_template( 'product-image.php', array(), '', VI_WOO_BOPO_BUNDLE_TEMP_DIR );
			wp_reset_postdata();

			wp_die();
		}

		function bopobb_cart_update() {
			check_ajax_referer( 'bopo-nonce', 'nonce' );
			if ( isset( $_POST['bopobb_cart_key'] ) && ( $_POST['bopobb_cart_key'] !== '' ) ) {
				$cart_key = sanitize_text_field( wp_unslash( $_POST['bopobb_cart_key'] ) );
			} else {
				return;
			}
			if ( isset( $_POST['bopobb_cart_parent'] ) && ( $_POST['bopobb_cart_parent'] !== '' ) ) {
				$parent_key = sanitize_text_field( wp_unslash( $_POST['bopobb_cart_parent'] ) );
			} else {
				return;
			}
			if ( isset( $_POST['bopobb_cart_item_data'] ) && ( $_POST['bopobb_cart_item_data'] !== '' ) ) {
				$item_data = sanitize_text_field( wp_unslash( $_POST['bopobb_cart_item_data'] ) );
			} else {
				return;
			}
			if ( ! isset( WC()->cart->cart_contents[ $parent_key ] ) ) {
				return;
			}
			$old_bundle_data = WC()->cart->cart_contents[ $parent_key ];

			WC()->cart->remove_cart_item( $parent_key );
			$_key = WC()->cart->add_to_cart( $old_bundle_data['product_id'], $old_bundle_data['quantity'] );
			if ( $_key ) {
				//return cart data
				$cart_url = wc_get_cart_url();
				wp_send_json_success( true );
			} else {
				wp_send_json_error();
			}

			wp_die();
		}

		function bopobb_get_variations_html( $p_product_id, $product_child, $variation_arr, $d_type = 0, $d_number = 0 ) {
			$product_variable     = wc_get_product( $p_product_id );
			$child_wc             = wc_get_product( $product_child );
			$variation_title      = $child_wc->get_title();
			$child_wc_title       = '';
			$child_variable_title = $product_variable->get_title();
			$is_link_title        = $this->settings->get_params( 'bopobb_popup_link' );
			$calc_price_base      = $this->settings->get_params( 'bopobb_calculate_price' );
			$price_html           = VI_WOO_BOPO_BUNDLE_Helper::bopohp_price_scope( $child_wc, array(
				$d_type,
				$d_number
			), false, $calc_price_base );
			foreach ( $variation_arr as $att_k => $att_v ) {
				$cur_key  = substr( $att_k, 10 );
				$cur_term = get_term_by( 'slug', $att_v, $cur_key );
				if ( ! empty( $cur_term ) ) {
					$tax_name = wc_attribute_label( $cur_term->taxonomy );
					if ( empty( $child_wc_title ) ) {
						$child_wc_title = $tax_name . ': ' . $cur_term->name;
					} else {
						$child_wc_title .= ', ' . $tax_name . ': ' . $cur_term->name;
					}
					$child_variable_title .= ' - ' . $cur_term->name;
				} else {
					if ( empty( $child_wc_title ) ) {
						$child_wc_title = ucfirst( $cur_key ) . ': ' . $att_v;
					} else {
						$child_wc_title .= ', ' . ucfirst( $cur_key ) . ': ' . $att_v;
					}
					$child_variable_title .= ' - ' . $att_v;
				}
			}
			if ( $child_wc->get_manage_stock() ) {
				$wc_product_stock = method_exists( $child_wc, 'get_stock_quantity' ) &&
				                    ! empty( $child_wc->get_stock_quantity() ) ? $child_wc->get_stock_quantity() : 0;
				$allow_backorder  = method_exists( $child_wc, 'backorders_allowed' ) ? $child_wc->backorders_allowed() : 0;
			} else {
				$wc_product_stock = - 1;
				$allow_backorder  = 0;
				if ( 'outofstock' == $child_wc->get_stock_status() ) {
					$wc_product_stock = 0;
				}
			};
			?>
            <div class="bopobb-product" data-product="<?php echo esc_attr( $product_child ) ?>" data-type="variation"
                 data-price="<?php //echo esc_attr( wc_get_price_excluding_tax( $child_wc ) );
			     echo esc_attr( VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $child_wc, $calc_price_base ) ); ?>" <?php
			foreach ( $variation_arr as $attr_k => $attr_v ) {
				?> data-<?php echo esc_attr( $attr_k ) ?>="<?php echo esc_attr( $attr_v ) ?>"
				<?php
			}
			?> >
                <input class="bopobb-product-variations"
                       value="<?php echo esc_attr( VI_WOO_BOPO_BUNDLE_Helper::bopobb_build_variations( $variation_arr ) ) ?>"
                       readonly="readonly">
                <div class="bopobb-product-img-wrap"
                     title="<?php esc_attr_e( 'Add', 'bopo-woocommerce-product-bundle-builder' ); ?>">
					<?php echo wp_kses_post( $child_wc->get_image( $this->settings->get_params( 'bopobb_popup_image_size' ) ) ); ?>
                </div>
                <div class="bopobb-product-title-wrap">
					<?php if ( $is_link_title ) { ?>
                        <a class="bopobb-product-title" data-title="<?php echo esc_attr( $variation_title ); ?>">
							<?php echo esc_html( $child_variable_title ); ?>
                        </a>
                        <a class="bopobb-variation-title"
                           data-link="<?php echo esc_url( $child_wc->get_permalink() ) ?>"
                           href="<?php echo esc_url( $child_wc->get_permalink() ) ?>" target="_blank">
							<?php echo esc_html( $child_wc_title ); ?>
                        </a>
					<?php } else { ?>
                        <div class="bopobb-product-title" data-title="<?php echo esc_attr( $variation_title ); ?>">
							<?php echo esc_html( $child_variable_title ); ?>
                        </div>
                        <div class="bopobb-variation-title"
                             data-link="<?php echo esc_url( $child_wc->get_permalink() ) ?>">
							<?php echo esc_html( $child_wc_title ); ?>
                        </div>
					<?php } ?>
                </div>
                <div class="bopobb-product-ratting">
					<?php if ( ! empty( $product_variable->get_rating_count() ) && $this->settings->get_params( 'bopobb_view_ratting' ) ) {
						echo wp_kses_post( wc_get_rating_html( $product_variable->get_average_rating() ) );
					}
					?>
                </div>
                <div class="bopobb-product-price">
					<?php echo wp_kses_post( $price_html[0] ); ?>
                </div>
                <div class="bopobb-product-stock" data-stock="<?php echo esc_attr( $wc_product_stock ) ?>"
                     data-backorder="<?php echo esc_attr( $allow_backorder ) ?>">
					<?php if ( $this->settings->get_params( 'bopobb_view_stock' ) ) {
						echo wp_kses_post( wc_get_stock_html( $child_wc ) );
					} ?>
                </div>
				<?php
				if ( $this->settings->get_params( 'bopobb_view_description' ) ) { ?>
                    <div class="bopobb-product-description bopobb-hidden">
						<?php echo wp_kses_post( $product_variable->get_short_description() ); ?>
                    </div>
				<?php } ?>
				<?php
				if ( $this->settings->get_params( 'bopobb_view_full_description' ) ) {
					$child_des = $child_wc->get_description(); ?>
                    <div class="bopobb-product-full-description<?php if ( empty( $child_des ) )
						echo ' bopobb-hidden' ?>">
						<?php echo wp_kses_post( empty( $child_des ) ? $product_variable->get_description() : $child_des ); ?>
                    </div>
				<?php } ?>
            </div>
			<?php
		}

		protected function bopobb_get_item_product( $items_data, $index ) {
			$o_array                      = [];
			$o_array['product']           = '';
			$o_array['product_id']        = '';
			$o_array['product_title']     = '';
			$o_array['product_image']     = '';
			$o_array['product_price']     = 0;
			$o_array['product_stock']     = 0;
			$o_array['product_variation'] = '';
			$calc_price_base              = $this->settings->get_params( 'bopobb_calculate_price' );
			if ( isset( $items_data[ $index ]['bopobb_bpi_set_default'] ) && $items_data[ $index ]['bopobb_bpi_set_default'] ) {
				if ( isset( $items_data[ $index ]['bopobb_bpi_default_product'] ) && ! empty( $items_data[ $index ]['bopobb_bpi_default_product'] ) ) {
					$default_product = $items_data[ $index ]['bopobb_bpi_default_product'];
					if ( str_contains( $default_product, '%/' ) ) {
						$id_array = explode( '%/', $default_product );
					} elseif ( str_contains( $default_product, '/' ) ) {
						$id_array = explode( '/', $default_product );
					} else {
						$id_array = array( $default_product );
					}

					$o_prd = wc_get_product( $id_array[0] );
					if ( $o_prd && ! $o_prd->is_purchasable() ) {
						$o_prd = '';
					}
				} else {
					$o_prd = '';
				}
				if ( ! isset( $items_data[ $index ]['bopobb_bpi_default_product'] ) || empty( $o_prd ) ) {
					$i_product_array = $this->bopobb_search_product( 1, 0, $items_data[ $index ] );
					if ( $i_product_array ) {
						$get_product = wc_get_product( $i_product_array['product_id'] );
						if ( isset( $i_product_array['product_variation'] ) ) {
							// Variation product
							$variable_id              = $get_product->get_parent_id();
							$variable_prd             = wc_get_product( $variable_id );
							$variation_title          = $variable_prd->get_title();
							$variation_title          .= VI_WOO_BOPO_BUNDLE_Helper::bopobb_decode_variations( $i_product_array['product_variation'], 1 );
							$o_array['product']       = $get_product;
							$o_array['product_id']    = $i_product_array['product_id'];
							$o_array['product_title'] = $variation_title;
							$o_array['product_image'] = $get_product->get_image( $this->settings->get_params( 'bopobb_image_size' ) );
//                            $o_array['product_price'] = wc_get_price_excluding_tax( $get_product );
							$o_array['product_price'] = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $get_product, $calc_price_base );
							if ( $get_product->get_manage_stock() ) {
								$o_array['product_stock'] = method_exists( $get_product, 'get_stock_quantity' ) &&
								                            ! empty( $get_product->get_stock_quantity() ) ? $get_product->get_stock_quantity() : 0;
							} else {
								$o_array['product_stock'] = - 1;
							};
							$o_array['product_variation'] = $i_product_array['product_variation'];

							return $o_array;
						} else {
							// Simple product
							$o_array['product']       = $get_product;
							$o_array['product_id']    = $i_product_array['product_id'];
							$o_array['product_title'] = $get_product->get_title();
							$o_array['product_image'] = $get_product->get_image( $this->settings->get_params( 'bopobb_image_size' ) );
//                            $o_array['product_price'] = wc_get_price_excluding_tax( $get_product );
							$o_array['product_price'] = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $get_product, $calc_price_base );
							if ( $get_product->get_manage_stock() ) {
								$o_array['product_stock'] = method_exists( $get_product, 'get_stock_quantity' ) &&
								                            ! empty( $get_product->get_stock_quantity() ) ? $get_product->get_stock_quantity() : 0;
							} else {
								$o_array['product_stock'] = - 1;
							};
							$o_array['product_variation'] = '';

							return $o_array;
						}
					} else {

						return $o_array;
					}
				} else {
					// Meta default product
					$variation_title  = '';
					$variation_string = '';
					if ( count( $id_array ) > 1 ) {
						$variation_title  .= VI_WOO_BOPO_BUNDLE_Helper::bopobb_decode_variations( $id_array[1], 1 );
						$variation_string = $id_array[1];
					}
					$o_array['product']    = wc_get_product( $id_array[0] );
					$o_array['product_id'] = $id_array[0];
					if ( $o_prd->is_type( 'variation' ) ) {
						$variable_id  = $o_prd->get_parent_id();
						$variable_prd = wc_get_product( $variable_id );
						$item_title   = $variable_prd->get_title();
//						$o_array['product_price'] = wc_get_price_excluding_tax( $o_prd );
						$o_array['product_price'] = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $o_prd, $calc_price_base );
					} else {
						$item_title = $o_prd->get_title();
//					    $o_array['product_price'] = wc_get_price_excluding_tax( $o_prd );
						$o_array['product_price'] = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price_excluding_tax( $o_prd, $calc_price_base );
					}
					$o_array['product_title']     = $item_title . $variation_title;
					$o_array['product_image']     = $o_prd->get_image( $this->settings->get_params( 'bopobb_image_size' ) );
					$o_array['product_variation'] = $variation_string;
					if ( $o_prd->get_manage_stock() ) {
						$o_array['product_stock'] = method_exists( $o_prd, 'get_stock_quantity' ) &&
						                            ! empty( $o_prd->get_stock_quantity() ) ? $o_prd->get_stock_quantity() : 0;
					} else {
						$o_array['product_stock'] = - 1;
					};

					return $o_array;
				}
			}

			return $o_array;
		}

		function bopobb_is_bundled( $p_id, $vr_str ) {
			$p_product = wc_get_product( $p_id );
			if ( $p_product && $p_product->is_type( 'variable' ) ) {
				$child_atts = VI_WOO_BOPO_BUNDLE_Helper::bopobb_decode_variations( $vr_str );
				if ( $child_atts ) {
					$child_arr      = array_values( $child_atts );
					$aval_atts      = array();
					$child_products = $p_product->get_children();
					if ( count( $child_products ) ) {
						foreach ( $child_products as $product_child ) {
							$child_wc                      = wc_get_product( $product_child );
							$variation_any                 = false;
							$child_wc_variation_attributes = $child_wc->get_variation_attributes();

							foreach ( $child_wc_variation_attributes as $attr_k => $attr_v ) {
								if ( empty( $attr_v ) ) {
									$variation_any = true;
								}
							}
							if ( $variation_any ) {
								$any_variations = VI_WOO_BOPO_BUNDLE_Helper::bopobb_get_variations( $p_product, $product_child, $child_wc_variation_attributes, $aval_atts );
								if ( $any_variations ) {
									$any_to_all = VI_WOO_BOPO_BUNDLE_Helper::bopobb_set_array( $any_variations, $product_child );
									$aval_atts  = array_merge( $aval_atts, $any_to_all );
								}
							} else {
								$achieve_arr        = [];
								$achieve_arr['id']  = $product_child;
								$child_wc_title     = '';
								$get_atts           = $child_wc->get_variation_attributes();
								$is_variation_valid = VI_WOO_BOPO_BUNDLE_Helper::bopobb_is_variation_allow( $p_product, $product_child, $get_atts, $aval_atts );
								if ( ! $is_variation_valid ) {
									continue;
								}
								foreach ( $get_atts as $att_k => $att_v ) {
									$achieve_arr[] = $att_v;
								}
								$aval_atts = array_merge( $aval_atts, [ $achieve_arr ] );
							}
						}
					}
					$aval_atts = VI_WOO_BOPO_BUNDLE_Helper::bopobb_get_simple_compare( $aval_atts );
					if ( in_array( $child_arr, $aval_atts ) ) {
						return true;
					}
				}
			}

			return false;
		}

		function bopobb_calc_price( $id, $index, $quantity, $discount = array() ) {
			$price      = array();
			$_price     = 0;
			$price_sale = 0;
			$_product   = wc_get_product( $id );
			if ( $_product ) {
				$calc_price_base = $this->settings->get_params( 'bopobb_calculate_price' );
				$_price          = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_original_price_total( $_product, $quantity, $calc_price_base );

//				if ( $discount[ $index ]['by'] == 0 ) {
//					$price_sale += ( $_price / 100 ) * $discount[ $index ]['number'];
//				} else {
//					$price_sale += $discount[ $index ]['number'] >= $_price ? $_price : $discount[ $index ]['number'];
//				}
				switch ( $discount[ $index ]['by'] ) {
					case 1:
						$price_sale += $discount[ $index ]['number'] >= $_price ? $_price : $discount[ $index ]['number'];
						break;
					case 2:
						$price_sale     += floatval( $discount[ $index ]['number'] );
						$price['price'] = $_price;
						$price['sale']  = $price_sale;

						return $price;
					case 0:
					default:
						$price_sale += ( $_price / 100 ) * $discount[ $index ]['number'];
				}
			}

			$price_sale     = $_price - $price_sale;
			$price['price'] = $_price;
			$price['sale']  = $price_sale;

			return $price;
		}

		function bopobb_is_purchasable( $purchasable, $product ) {
			if ( $product->exists() && ( 'publish' === $product->get_status() || current_user_can( 'edit_post', $product->get_id() ) ) ) {
				if ( $product->get_price() === '' && ! $product->is_type( 'bopobb' ) ) {
					return $purchasable;
				} else {
					return true;
				}
			}

			return $purchasable;
		}

		function bopobb_add_to_cart_quantity( $quantity, $product ) {
			if ( $product ) {
				if ( $product->is_type( 'bopobb' ) && ! $this->settings->get_params( 'bopobb_bundle_quantity' ) ) {
					return 1;
				}
			}

			return $quantity;
		}

		function bopobb_single_product_image_thumbnail_html( $html, $post_thumbnail_id ) {

			global $product;
			if ( ! $product || ! $product->is_type( 'bopobb' ) ) {
				return $html;
			}
			if ( isset( $_POST['bopobb_ids'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
				// reload previous items images
			} else {
				// default load
				if ( $items = $product->get_items() ) {
					foreach ( $items['items'] as $item ) {
						if ( isset( $item['bopobb_bpi_set_default'] ) && $item['bopobb_bpi_set_default'] == 1 ) {
							if ( isset( $item['bopobb_bpi_default_product'] ) && ! empty( $item['bopobb_bpi_default_product'] ) ) {
								// set def
								$id_array = explode( '%/', $item['bopobb_bpi_default_product'] );
								if ( ! isset( $id_array[0] ) ) {
									return $html;
								}
								$_product = wc_get_product( intval( $id_array[0] ) );
								$image_id = $_product->get_image_id();

								if ( $_product->is_type( 'variation' ) ) {
									$variation_id  = $_product->get_parent_id();
									$variation_prd = wc_get_product( $variation_id );
									$gallery_ids   = $variation_prd->get_gallery_image_ids();
								} else {
									$gallery_ids = $_product->get_gallery_image_ids();
								}

								if ( $product->get_image_id() != $post_thumbnail_id ) {

									$is_gallery = strpos( $html, '<div class="col">' );

									if ( $is_gallery == 0 && $is_gallery != '' ) {
										$gallery_thumbnail = wc_get_image_size( apply_filters( 'woocommerce_gallery_thumbnail_size', 'woocommerce_gallery_thumbnail' ) );
										$image             = wp_get_attachment_image_src( $image_id, apply_filters( 'woocommerce_gallery_thumbnail_size', 'woocommerce_' . 'gallery_thumbnail' ) );
										$image_alt         = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
										$image             = '<img src="' . $image[0] . '" alt="' . $image_alt . '" width="' . $gallery_thumbnail['width'] . '" height="' . $gallery_thumbnail['height'] . '"  class="attachment-woocommerce_thumbnail" />';

										$html .= sprintf( '<div class="col"><a>%s</a></div>', $image );
										if ( count( $gallery_ids ) > 0 ) {
											foreach ( $gallery_ids as $gallery_id ) {
												$image     = wp_get_attachment_image_src( $gallery_id, apply_filters( 'woocommerce_gallery_thumbnail_size', 'woocommerce_' . 'gallery_thumbnail' ) );
												$image_alt = get_post_meta( $gallery_id, '_wp_attachment_image_alt', true );
												$image     = '<img src="' . $image[0] . '" alt="' . $image_alt . '" width="' . $gallery_thumbnail['width'] . '" height="' . $gallery_thumbnail['height'] . '"  class="attachment-woocommerce_thumbnail" />';

												$html .= sprintf( '<div class="col"><a>%s</a></div>', $image );
											}
										}
									} else {
										$html .= wc_get_gallery_image_html( $image_id );
										if ( count( $gallery_ids ) > 0 ) {
											foreach ( $gallery_ids as $gallery_id ) {
												$html .= wc_get_gallery_image_html( $gallery_id );
											}
										}
									}
								}
							}
						}
					}
				}
			}

			return $html;
		}

		function bopobb_shortcode_cart_form( $product = null, $sticky = false, $settings = '', $lang = '', $params = [] ) {

			if ( ! $product || ! $product->is_type( 'bopobb' ) ) {
				return;
			}

			wc_setup_product_data( $product->get_id() );
			do_action( 'woocommerce_before_add_to_cart_button' );
			bopobb_get_template( 'single-add-to-cart.php', array(
				'sticky'        => $sticky,
				'settings'      => $settings,
				'bopo_settings' => [ 'bopobb_single_note' => $this->settings->get_params( 'bopobb_single_note' ) ],
				'parameters'    => $params,
				'sc_product'    => $product,
				'language'      => $lang
			), '', VI_WOO_BOPO_BUNDLE_TEMP_DIR );
			do_action( 'woocommerce_after_add_to_cart_button' );

			wp_reset_postdata();
		}

		function bopobb_add_to_cart_form() {
			global $product;

			if ( ! $product || ! $product->is_type( 'bopobb' ) ) {
				return;
			}

			wc_get_template( 'single-product/add-to-cart/simple.php' );
		}

		function bopobb_add_to_cart_button() {
			global $product;
			if ( $product && $product->is_type( 'bopobb' ) ) {
				if ( $items = $product->get_items() ) {
					$isDefault    = true;
					$isGetDefault = true;
					foreach ( $items['items'] as $item ) {
						if ( $item['bopobb_bpi_set_default'] != 1 || ! isset( $item['bopobb_bpi_default_product'] ) ) {
							$isDefault = false;
						}
						if ( $item['bopobb_bpi_set_default'] != 1 ) {
							$isGetDefault = false;
						}
					}
					if ( $isDefault ) {
						// All item has default in meta
						$ids = $product->get_ids();
					} else if ( $isGetDefault ) {
						// Search default
						$ids = '';
						foreach ( $items['items'] as $item ) {
							$cart_product_array = $this->bopobb_search_product( 1, 0, $item );
							if ( empty( $cart_product_array ) ) {
								break;
							}
							$cart_product_id       = $cart_product_array['product_id'];
							$cart_variation_string = isset( $cart_product_array['product_variation'] ) ? '%/' . $cart_product_array['product_variation'] : '';

							if ( $ids == '' ) {
								$ids .= $cart_product_id . '%/' . $item['bopobb_bpi_quantity'] . $cart_variation_string;
							} else {
								$ids .= '%&' . $cart_product_id . '%/' . $item['bopobb_bpi_quantity'] . $cart_variation_string;
							}
						}
					} else {
						$ids = '';
					}

					echo '<input name="bopobb_ids" class="bopobb_ids bopobb-ids" type="hidden" value="' . esc_attr( $ids ) . '"/>';
				}
				if ( $this->settings->get_params( 'bopobb_single_note' ) == 1 ) {
					echo '<input type="hidden" name="bopobb_product_note" id="bopobb_product_note" value="">';
				}
			}
		}

		function bopobb_check_in_cart( $product_id ) {
			foreach ( WC()->cart->get_cart() as $cart_item ) {
				if ( $cart_item['product_id'] === $product_id ) {
					return true;
				}
			}

			return false;
		}

		function bopobb_add_to_cart_validation( $passed, $product_id ) {
			$b_product         = wc_get_product( $product_id );
			$empty_option_item = 0;

			if ( $b_product && $b_product->is_type( 'bopobb' ) ) {
				$items = '';
//				$item_require = $b_product->get_meta('bopobb_items_require') ?: '';
				if ( isset( $_REQUEST['bopobb_ids'] ) ) {// phpcs:ignore WordPress.Security.NonceVerification.Recommended
					$ids   = VI_WOO_BOPO_BUNDLE_Helper::bopohp_clean_ids( sanitize_text_field( wp_unslash( $_REQUEST['bopobb_ids'] ) ) );// phpcs:ignore WordPress.Security.NonceVerification.Recommended
					$items = $b_product->build_items( $ids );
				}
				$bundles_data = $b_product->get_items();
				$qty          = isset( $_REQUEST['quantity'] ) ? absint( $_REQUEST['quantity'] ) : 1;// phpcs:ignore WordPress.Security.NonceVerification.Recommended

				//total item per bundle
//				$b_qty = 0;

				if ( ! empty( $items ) ) {
					foreach ( $items as $items_i => $item ) {
						if ( empty( $item ) ) {
							if ( isset( $bundles_data['items'] ) && isset( $bundles_data['items'][ $items_i ] )
							     && isset( $bundles_data['items'][ $items_i ]['bopobb_bpi_optional_item'] ) && 1 == $bundles_data['items'][ $items_i ]['bopobb_bpi_optional_item'] ) {
								$empty_option_item += 1;
								continue;
							}

							return false;
						}
						$_id  = $item['id'];
						$_qty = $item['qty'];
//						$b_qty = $b_qty + intval( $_qty );
						if ( ! isset( $bundles_data['items'][ $items_i ] ) ) {
							wc_add_notice( esc_html__( 'One of the bundled products is unavailable.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );
							wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

							return false;
						}
						$items_data    = $bundles_data['items'][ $items_i ];
						$i_product_ids = $this->bopobb_search_product( 0, 1, $items_data );
						$_variant      = isset( $item['variations'] ) ? $item['variations'] : '';
						$_product      = wc_get_product( $item['id'] );

						if ( ! $_product ) {
							wc_add_notice( esc_html__( 'One of the bundled products is unavailable.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );
							wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

							return false;
						}

						if ( $_product->is_type( 'variable' ) || $_product->is_type( 'bopobb' ) ) {
							/* translators: %s: product name */
							wc_add_notice( sprintf( esc_html__( '"%s" is un-purchasable.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ) ), 'error' );
							wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

							return false;
						}

						if ( $_product->is_type( 'variation' ) ) {
							$variable_id = $_product->get_parent_id();
							if ( $variable_id && $i_product_ids && ! in_array( $variable_id, $i_product_ids ) ) {
								/* translators: %1$s: product name %2$s: bundle name */
								wc_add_notice( sprintf( esc_html__( '"%1$s" is not bundled of "%2$s".', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ), esc_html( $b_product->get_name() ) ), 'error' );
								wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

								return false;
							}
							if ( $variable_id && ! self::bopobb_is_bundled( $variable_id, $_variant ) ) {
								/* translators: %s: product name*/
								wc_add_notice( sprintf( esc_html__( '"%s" is invalid variation.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ) ), 'error' );
								wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

								return false;
							}
						}

						if ( ! $_product->is_type( 'variation' ) ) {
							if ( $i_product_ids && ! in_array( $_id, $i_product_ids ) ) {
								/* translators: %1$s: product name, %2$s: bundle name */
								wc_add_notice( sprintf( esc_html__( '"%1$s" is not bundled of "%2$s".', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ), esc_html( $b_product->get_name() ) ), 'error' );
								wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

								return false;
							}
						}
						if ( isset( $items_data['bopobb_bpi_quantity_min'] ) && ! empty( $items_data['bopobb_bpi_quantity_min'] ) ) {
							if ( $_qty < $items_data['bopobb_bpi_quantity_min'] ) {
								/* translators: %s: product name */
								wc_add_notice( sprintf( esc_html__( '"%s" requested quantity is not available in this bundle.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ) ), 'error' );
								wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

								return false;
							}
						}
						if ( isset( $items_data['bopobb_bpi_quantity_max'] ) && ! empty( $items_data['bopobb_bpi_quantity_max'] ) ) {
							if ( $_qty > $items_data['bopobb_bpi_quantity_max'] ) {
								/* translators: %s: product name */
								wc_add_notice( sprintf( esc_html__( '"%s" requested quantity is not available in this bundle.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ) ), 'error' );
								wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

								return false;
							}
						}

						if ( ! $_product->is_in_stock() || ! $_product->is_purchasable() ) {
							/* translators: %s: product name */
							wc_add_notice( sprintf( esc_html__( '"%s" is un-purchasable.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ) ), 'error' );
							wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

							return false;
						}

						if ( ! $_product->has_enough_stock( $_qty * $qty ) ) {
							/* translators: %s: product name */
							wc_add_notice( sprintf( esc_html__( '"%s" has not enough stock.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ) ), 'error' );
							wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

							return false;
						}

						if ( $_product->is_sold_individually() && $this->bopobb_check_in_cart( $_id ) ) {
							/* translators: %s: product name */
							wc_add_notice( sprintf( esc_html__( 'You cannot add another "%s" to the cart.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ) ), 'error' );
							wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

							return false;
						}

						if ( $_product->managing_stock() ) {
							$products_qty_in_cart = WC()->cart->get_cart_item_quantities();

							if ( isset( $products_qty_in_cart[ $_product->get_stock_managed_by_id() ] ) && ! $_product->has_enough_stock( $products_qty_in_cart[ $_product->get_stock_managed_by_id() ] + $_qty * $qty ) ) {
								/* translators: %s: product name */
							    wc_add_notice( sprintf( esc_html__( '"%s" has not enough stock.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ) ), 'error' );
								wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

								return false;
							}
						}

						if ( post_password_required( $_id ) ) {
							/* translators: %s: product name */
							wc_add_notice( sprintf( esc_html__( '"%s" is protected and cannot be purchased.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $_product->get_name() ) ), 'error' );
							wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

							return false;
						}
					}

					if ( $empty_option_item == count( $items ) ) {
						wc_add_notice( esc_html__( 'Please add at least 1 item to bundle.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );
						wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );

						return false;
					}

//					if ( $item_require && $empty_option_item == count( $items ) ) {
//						wc_add_notice( sprintf( esc_html__( 'Please add at least %s item to bundle.', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $item_require ) ), 'error' );
//						wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );
//
//						return false;
//                    }
//					if ( isset( $bundles_data['min_quantity'] ) && '' != $bundles_data['min_quantity']
//                         && intval( $b_qty ) < intval( $bundles_data['min_quantity'] ) ) {
//						wc_add_notice( sprintf( esc_html__( 'The total item in a bundle must be greater than "%s".', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $bundles_data['min_quantity'] ) ), 'error' );
//						wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );
//
//						return false;
//                    }
//					if ( isset( $bundles_data['max_quantity'] ) && '' != $bundles_data['max_quantity']
//					     && intval( $b_qty ) > intval( $bundles_data['max_quantity'] ) ) {
//						wc_add_notice( sprintf( esc_html__( 'The total item in a bundle must be lower than "%s".', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $bundles_data['max_quantity'] ) ), 'error' );
//						wc_add_notice( esc_html__( 'You cannot add this bundle to the cart.', 'bopo-woocommerce-product-bundle-builder' ), 'error' );
//
//						return false;
//                    }
				} else {

					return false;
				}
			}

			return $passed;
		}


		function bopobb_add_cart_item_data( $cart_item_data, $product_id ) {
			$_product = wc_get_product( $product_id );

			if ( $_product && $_product->is_type( 'bopobb' ) ) {
				$ids           = $_product->get_ids();
				$product_notes = '';
				// make sure that is bundle
				if ( isset( $_REQUEST['bopobb_ids'] ) ) {// phpcs:ignore WordPress.Security.NonceVerification.Recommended
					$ids = VI_WOO_BOPO_BUNDLE_Helper::bopohp_clean_ids( sanitize_text_field( wp_unslash( $_REQUEST['bopobb_ids'] ) ) );// phpcs:ignore WordPress.Security.NonceVerification.Recommended
					unset( $_REQUEST['bopobb_ids'] );
				}

				if ( isset( $_POST['bopobb_cart_item_data'] ) && ( $_POST['bopobb_cart_item_data'] !== '' ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
					$ids = VI_WOO_BOPO_BUNDLE_Helper::bopohp_clean_ids( sanitize_text_field( wp_unslash( $_POST['bopobb_cart_item_data'] ) ), $product_id ); // phpcs:ignore WordPress.Security.NonceVerification.Missing
				}

				if ( isset( $_POST['bopobb_product_note'] ) && ( $_POST['bopobb_product_note'] !== '' ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Missing
					$product_notes = wc_clean( wp_unslash( $_POST['bopobb_product_note'] ) ); // phpcs:ignore WordPress.Security.NonceVerification.Missing
				}

				if ( ! empty( $ids ) ) {
					$cart_item_data['bopobb_ids'] = $ids;
				}

				if ( ! empty( $product_notes ) ) {
					$cart_item_data['bopobb_product_note'] = $product_notes;
				}
			}
			if ( isset( $cart_item_data['bopobb_parent_id'] ) ) {
				if ( isset( $cart_item_data['yith_wapo_options'] ) ) {
					unset( $cart_item_data['yith_wapo_options'] );
				}
				if ( isset( $cart_item_data['thwepof_options'] ) ) {
					unset( $cart_item_data['thwepof_options'] );
				}
			}

			return $cart_item_data;
		}

		function bopobb_add_to_cart( $cart_item_key, $product_id, $quantity, $variation_id, $variation, $cart_item_data ) {
			if ( ! empty( $cart_item_data['bopobb_ids'] ) ) {
				$items = WC()->cart->cart_contents[ $cart_item_key ]['data']->build_items( $cart_item_data['bopobb_ids'] );

				$this->bopobb_add_to_cart_items( $items, $cart_item_key, $product_id, $quantity );
			}
		}

		function bopobb_add_custom_price( $cart_object ) {
			foreach ( $cart_object->get_cart() as $cart_key => $cart_item_data ) {
				if ( isset( $cart_item_data['bopobb_ids'] ) && isset( $cart_item_data['bopobb_price'] ) &&
				     isset( $cart_item_data['bopobb_fixed_price'] ) && ! $cart_item_data['bopobb_fixed_price'] ) {
					$cart_item_data['data']->set_price( (float) $cart_item_data['bopobb_price'] );
				}
			}
		}

		function bopobb_add_to_cart_items( $items, $cart_item_key, $product_id, $quantity ) {
			// remove cart init
			global $woocommerce;

			$fixed_price    = WC()->cart->cart_contents[ $cart_item_key ]['data']->is_fixed_price();
			$discount_array = WC()->cart->cart_contents[ $cart_item_key ]['data']->get_discount_amount();
			$max_qty_array  = WC()->cart->cart_contents[ $cart_item_key ]['data']->bopo_get_max_quantity();
			$min_qty_array  = WC()->cart->cart_contents[ $cart_item_key ]['data']->bopo_get_min_quantity();
			// save current key associated with bopobb_parent_key
			WC()->cart->cart_contents[ $cart_item_key ]['bopobb_key']             = $cart_item_key;
			WC()->cart->cart_contents[ $cart_item_key ]['bopobb_fixed_price']     = $fixed_price;
			WC()->cart->cart_contents[ $cart_item_key ]['bopobb_discount_amount'] = $discount_array;

			if ( is_array( $items ) && ( count( $items ) > 0 ) ) {
				if ( $this->settings->get_params( 'bopobb_remove_ready_cart' ) ) {
					foreach ( $woocommerce->cart->get_cart() as $ready_cart_key => $ready_cart_item ) {
						$cart_product_id        = $ready_cart_item['product_id'];
						$cart_variation_id      = $ready_cart_item['variation_id'];
						$cart_product_variation = isset( $ready_cart_item['variation'] ) ? $ready_cart_item['variation'] : 0;
						if ( ! isset( $ready_cart_item['bopobb_ids'] ) ) {
							continue;
						} else {
							foreach ( $items as $bundle_item ) {
								if ( empty( $bundle_item ) ) {
									continue;
								}
								if ( $cart_product_variation ) {
									if ( $bundle_item['id'] == $cart_variation_id ) {
										$variation_arr = VI_WOO_BOPO_BUNDLE_Helper::bopobb_decode_variations( $bundle_item['variations'] );
										if ( $variation_arr == $cart_product_variation ) {
											$woocommerce->cart->remove_cart_item( $ready_cart_key );
										}
									}
								} else {
									if ( $bundle_item['id'] == $cart_product_id ) {
										$woocommerce->cart->remove_cart_item( $ready_cart_key );
									}
								}
							}
						}
					}
				}

				for ( $i = 0; $i < count( $items ); $i ++ ) {
					if ( isset( $items[ $i ] ) && empty( $items[ $i ] ) ) {
						continue;
					}
					$_id      = $items[ $i ]['id'];
					$_qty     = $items[ $i ]['qty'];
					$_variant = isset( $items[ $i ]['variations'] ) ? $items[ $i ]['variations'] : '';
					$_product = wc_get_product( $items[ $i ]['id'] );

					if ( ! $_product || ( $_qty <= 0 ) || in_array( $_product->get_type(), $this->settings->get_params( 'bopobb_type_exclude' ), true ) ) {
						continue;
					}

					$_variation_id = '';
					$_variation    = array();
					$_price        = VI_WOO_BOPO_BUNDLE_Helper::bopohp_get_price( $_product, 'src' );

					if ( $_product instanceof WC_Product_Variation ) {
						// ensure we don't add a variation to the cart directly by variation ID
						$_variation_id = $_id;
						$_id           = $_product->get_parent_id();
						$_variation    = VI_WOO_BOPO_BUNDLE_Helper::bopobb_decode_variations( $_variant );
					}


					if ( ! $fixed_price && is_array( $discount_array ) ) {
						if ( ! empty( $_variation_id ) ) {
							$calc_price = self::bopobb_calc_price( $_variation_id, $i, $_qty, $discount_array );
						} else {
							$calc_price = self::bopobb_calc_price( $_id, $i, $_qty, $discount_array );
						}
						$_price = $calc_price['sale'];
					}

					// add to cart
					$_data = array(
						'bopobb_index'          => $i,
						'bopobb_qty'            => $_qty,
						'bopobb_min_qty'        => isset( $min_qty_array[ $i ] ) ? $min_qty_array[ $i ] : 1,
						'bopobb_max_qty'        => isset( $max_qty_array[ $i ] ) ? $max_qty_array[ $i ] : 1,
						'bopobb_price'          => $_price,
						'bopobb_parent_id'      => $product_id,
						'bopobb_parent_key'     => $cart_item_key,
						'bopobb_fixed_price'    => $fixed_price,
						'bopobb_discount_array' => $discount_array,
					);

					if ( $this->settings->get_params( 'bopobb_item_price_single' ) != 'hide' || $this->settings->get_params( 'bopobb_item_price_total' ) != 'hide' ) {
						$_data['bopobb_tax_rate'] = VI_WOO_BOPO_BUNDLE_Helper::bopobb_tax_rate( wc_get_product( $product_id ) );
					}

					$_key = WC()->cart->add_to_cart( $_id, $_qty * $quantity, $_variation_id, $_variation, $_data );

					if ( empty( $_key ) ) {
						// can't add the bundled product
						if ( isset( WC()->cart->cart_contents[ $cart_item_key ]['bopobb_keys'] ) ) {
							$keys = WC()->cart->cart_contents[ $cart_item_key ]['bopobb_keys'];

							foreach ( $keys as $key ) {
								// remove all bundled products
								WC()->cart->remove_cart_item( $key );
							}

							// remove the bundle
							WC()->cart->remove_cart_item( $cart_item_key );

							// break out of the loop
							break;
						}
					} elseif ( ! isset( WC()->cart->cart_contents[ $cart_item_key ]['bopobb_keys'] ) || ! in_array( $_key, WC()->cart->cart_contents[ $cart_item_key ]['bopobb_keys'], true ) ) {
						// save current key
						WC()->cart->cart_contents[ $_key ]['bopobb_key'] = $_key;

						// add keys for parent
						WC()->cart->cart_contents[ $cart_item_key ]['bopobb_keys'][] = $_key;
					}
				} // end foreach
			}
		}

		public function bopobb_cart_item_restored( $cart_item_key, $cart ) {
			if ( ! empty( $cart->cart_contents[ $cart_item_key ]['bopobb_ids'] ) ) {
				$bundled_item_cart_keys = $cart->cart_contents[ $cart_item_key ]['bopobb_keys'];
				foreach ( $bundled_item_cart_keys as $bundled_item_cart_key ) {
					$cart->restore_cart_item( $bundled_item_cart_key );
				}
			}
		}

		function bopobb_get_cart_item_from_session( $cart_item, $session_values ) {
			if ( isset( $session_values['bopobb_ids'] ) && ! empty( $session_values['bopobb_ids'] ) ) {
				$cart_item['bopobb_ids'] = $session_values['bopobb_ids'];
			}

			if ( isset( $session_values['bopobb_parent_id'] ) ) {
				$cart_item['bopobb_parent_id']  = $session_values['bopobb_parent_id'];
				$cart_item['bopobb_parent_key'] = $session_values['bopobb_parent_key'];
				$cart_item['bopobb_qty']        = $session_values['bopobb_qty'];
			}

			return $cart_item;
		}

		function bopobb_loop_add_to_cart_link( $link, $product ) {
			if ( $product->is_type( 'bopobb' ) ) {
				$link = str_replace( 'ajax_add_to_cart', '', $link );
			}

			return $link;
		}

		function bopobb_get_cart_contents( $cart_contents ) {
			foreach ( $cart_contents as $cart_item_key => $cart_item ) {
				// bundled products
				if ( ! empty( $cart_item['bopobb_parent_id'] ) ) {
					// remove orphaned bundled products
					if ( isset( $cart_item['bopobb_parent_key'] ) && ! empty( $cart_item['bopobb_parent_key'] ) ) {
						$parent_key = $cart_item['bopobb_parent_key'];

						if ( ! isset( $cart_contents[ $parent_key ] ) && ! ( $cart_item['data'] instanceof WC_Product_Subscription ) && ! ( $cart_item['data'] instanceof WC_Product_Subscription_Variation ) ) {
							unset( $cart_contents[ $cart_item_key ] );
							continue;
						}
					}

					// set price
					$cart_item['data']->set_price( 0 );

					// sync quantity
					if ( ! empty( $cart_item['bopobb_parent_key'] ) && ! empty( $cart_item['bopobb_qty'] ) ) {
						$parent_key = $cart_item['bopobb_parent_key'];

						if ( isset( $cart_contents[ $parent_key ] ) ) {
							$cart_contents[ $cart_item_key ]['quantity'] = $cart_item['bopobb_qty'] * $cart_contents[ $parent_key ]['quantity'];
						} elseif ( ( $parent_new_key = array_search( $parent_key, array_column( $cart_contents, 'bopobb_key', 'key' ) ) ) !== false ) {
							$cart_contents[ $cart_item_key ]['quantity'] = $cart_item['bopobb_qty'] * $cart_contents[ $parent_new_key ]['quantity'];
						}
					}
				}

				// bundles
				if ( ! empty( $cart_item['bopobb_ids'] ) && isset( $cart_item['bopobb_fixed_price'] ) && ! $cart_item['bopobb_fixed_price'] ) {
					// set price zero, calculate later

					if ( ! empty( $cart_item['bopobb_keys'] ) ) {
						$bundle_price = 0;

						foreach ( $cart_item['bopobb_keys'] as $key ) {
							if ( isset( $cart_contents[ $key ] ) && isset( $cart_contents[ $key ]['bopobb_price'] ) ) {
								if ( class_exists( 'WC_Product_Price_Based_Country' ) || class_exists( 'WC_Product_Price_Based_Country_Pro' ) ) {
									if ( isset( $cart_contents[ $key ]['bopobb_discount_array'] ) && ! empty( $cart_contents[ $key ]['bopobb_discount_array'] )
									     && isset( $cart_contents[ $key ]['bopobb_qty'] ) && isset( $cart_contents[ $key ]['bopobb_index'] ) ) {
										$calc_price_base = $cart_contents[ $key ]['bopobb_price'];
										if ( $cart_contents[ $key ]['variation_id'] ) {
											$calc_price_base = self::bopobb_calc_price( $cart_contents[ $key ]['variation_id'], $cart_contents[ $key ]['bopobb_index'], $cart_contents[ $key ]['bopobb_qty'], $cart_contents[ $key ]['bopobb_discount_array'] );
										} elseif ( $cart_contents[ $key ]['product_id'] ) {
											$calc_price_base = self::bopobb_calc_price( $cart_contents[ $key ]['product_id'], $cart_contents[ $key ]['bopobb_index'], $cart_contents[ $key ]['bopobb_qty'], $cart_contents[ $key ]['bopobb_discount_array'] );
										}

										$calc_price_base = is_array( $calc_price_base ) ? $calc_price_base['sale'] : $calc_price_base;
										$bundle_price    += floatval( $calc_price_base );
									}
								} else {
									$bundle_price += floatval( $cart_contents[ $key ]['bopobb_price'] );
								}
							} elseif ( is_plugin_active( 'woo-variation-swatches/woo-variation-swatches.php' ) ) {
								foreach ( $cart_contents as $l_cart_content ) {
									if ( isset( $l_cart_content['bopobb_key'] ) && isset( $l_cart_content['bopobb_index'] ) &&
									     $l_cart_content['bopobb_key'] == $key ) {
										if ( class_exists( 'WC_Product_Price_Based_Country' ) || class_exists( 'WC_Product_Price_Based_Country_Pro' ) ) {
											if ( isset( $l_cart_content['bopobb_discount_array'] ) && ! empty( $l_cart_content['bopobb_discount_array'] )
											     && isset( $l_cart_content['bopobb_qty'] ) && isset( $l_cart_content['bopobb_index'] ) ) {
												$calc_price_base = $l_cart_content['bopobb_price'];
												if ( $l_cart_content['variation_id'] ) {
													$calc_price_base = self::bopobb_calc_price( $l_cart_content['variation_id'], $l_cart_content['bopobb_index'], $l_cart_content['bopobb_qty'], $l_cart_content['bopobb_discount_array'] );
												} elseif ( $l_cart_content['product_id'] ) {
													$calc_price_base = self::bopobb_calc_price( $l_cart_content['product_id'], $l_cart_content['bopobb_index'], $l_cart_content['bopobb_qty'], $l_cart_content['bopobb_discount_array'] );
												}

												$calc_price_base = is_array( $calc_price_base ) ? $calc_price_base['sale'] : $calc_price_base;
												$bundle_price    += floatval( $calc_price_base );
												break;
											}
										} else {
											$bundle_price += floatval( $l_cart_content['bopobb_price'] );
											break;
										}
									}
								}
							}
						}

						$bundle_price = VI_WOO_BOPO_BUNDLE_Helper::bopobb_price_standard( $cart_item['data'], $bundle_price );
						if ( $cart_item['quantity'] > 0 ) {
							$cart_contents[ $cart_item_key ]['bopobb_price'] = $bundle_price;
						}
					}
					if ( isset( $cart_contents[ $cart_item_key ]['bopobb_price'] ) && $cart_contents[ $cart_item_key ]['bopobb_price'] ) {
						$cart_item['data']->set_price( (float) $cart_contents[ $cart_item_key ]['bopobb_price'] );
					} else {
						$cart_item['data']->set_price( 0 );
					}
				}
			}

			return $cart_contents;
		}

		function bopobb_cart_item_name( $name, $cart_item ) {
			if ( isset( $cart_item['bopobb_parent_id'] ) && ! empty( $cart_item['bopobb_parent_id'] ) ) {
				$variation_names = isset( $cart_item['variation'] ) ? VI_WOO_BOPO_BUNDLE_Helper::bopobb_build_title( $cart_item['variation'] ) : '';
				if ( isset( $cart_item['product_id'] ) && ! empty( $cart_item['product_id'] ) && isset( $cart_item['bopobb_index'] ) ) {

					if ( isset( $cart_item['variation_id'] ) && ! empty( $cart_item['variation_id'] ) && ! empty( $cart_item['variation'] ) ) {
						$product_id = $cart_item['variation_id'];
					} else {
						$product_id = $cart_item['product_id'];
					}
					$variation_string = isset( $cart_item['variation'] ) ? VI_WOO_BOPO_BUNDLE_Helper::bopobb_variation_merge( $cart_item['variation'] ) : '';
					$variation_qty    = isset( $cart_item['bopobb_qty'] ) ? $cart_item['bopobb_qty'] : '';
					$discount_type    = isset( $cart_item['bopobb_discount_array'][ $cart_item['bopobb_index'] ]['by'] ) ?
						$cart_item['bopobb_discount_array'][ $cart_item['bopobb_index'] ]['by'] : 0;
					if ( $discount_type == 0 ) {
						$discount_number = isset( $cart_item['bopobb_discount_array'][ $cart_item['bopobb_index'] ]['number'] ) ?
							(float) $cart_item['bopobb_discount_array'][ $cart_item['bopobb_index'] ]['number'] : 0;
					} else {
						$discount_number = isset( $cart_item['bopobb_discount_array'][ $cart_item['bopobb_index'] ]['number'] ) ?
							apply_filters( 'bopobb_convert_currency_price', (float) $cart_item['bopobb_discount_array'][ $cart_item['bopobb_index'] ]['number'] ) : 0;
					}
					$info_html = '<div class="bopobb-cart-info" data-id="' . esc_attr( $cart_item['key'] ) . '" data-parent="' . esc_attr( $cart_item['bopobb_parent_key'] ) . '" 
                        data-product-id="' . esc_attr( $product_id ) . '" data-variation="' . esc_attr( $variation_string ) . '" 
                        data-variable="' . esc_attr( $cart_item['product_id'] ) . '" data-quantity="' . esc_attr( $variation_qty ) . '" 
                        data-title="' . esc_attr( $cart_item['data']->get_name() ) . '" data-index="' . esc_attr( $cart_item['bopobb_index'] ) . '" 
                        data-discount-type="' . esc_attr( $discount_type ) . '"
                        data-discount-number="' . esc_attr( $discount_number ) . '"></div>';
					$edit_html = '';
					if ( is_checkout() ) {
						if ( $this->settings->get_params( 'bopobb_edit_checkout' ) ) {
							$edit_html .= '<div class="bopobb-order-change-wrap"><div class="bopobb-order-change bopobb-icon-pencil"
                                data-index="' . esc_attr( $cart_item['bopobb_index'] ) . '"
                                data-bundle="' . esc_attr( $cart_item['bopobb_parent_id'] ) . '"
                                data-qty-min="' . esc_attr( $cart_item['bopobb_min_qty'] ) . '"
                                data-qty-max="' . esc_attr( $cart_item['bopobb_max_qty'] ) . '"
                                title="' . esc_attr( $this->settings->get_params( 'bopobb_swap_text' ) ) . '"></div></div>';
						}
					} else {
						if ( $this->settings->get_params( 'bopobb_edit_cart' ) ) {
							$edit_html .= '<div class="bopobb-cart-change-wrap"><div class="bopobb-cart-change bopobb-icon-pencil"
                                data-index="' . esc_attr( $cart_item['bopobb_index'] ) . '"
                                data-bundle="' . esc_attr( $cart_item['bopobb_parent_id'] ) . '"
                                data-qty-min="' . esc_attr( isset( $cart_item['bopobb_min_qty'] ) ? $cart_item['bopobb_min_qty'] : 1 ) . '"
                                data-qty-max="' . esc_attr( isset( $cart_item['bopobb_max_qty'] ) ? $cart_item['bopobb_max_qty'] : 1 ) . '"
                                title="' . esc_attr( $this->settings->get_params( 'bopobb_swap_text' ) ) . '"></div></div>';
						}
					}
//					if ( ( strpos( $name, '</a>' ) === false ) ) {
//						return $name;
//					}
					$name = '<div class="bopobb-child-title">' . $name . $edit_html . '</div>' . $info_html;
				}
			}
			if ( isset( $cart_item['bopobb_product_note'] ) && ! empty( $cart_item['bopobb_product_note'] ) ) {
				$name .= '<div class="bopobb-cart-note-wrap">' . esc_html__( 'Bundle note', 'bopo-woocommerce-product-bundle-builder' ) . ': ' . esc_html( $cart_item['bopobb_product_note'] ) . '</div>';
			}

			return $name;
		}

		public function bopobb_cart_item_quantity( $quantity, $cart_item_key, $cart_item ) {
			if ( isset( $cart_item['bopobb_ids'] ) ) {
				if ( ! $this->settings->get_params( 'bopobb_bundle_quantity' ) ) {
					return '<div class="bopobb-cart-product-quantity">' . sprintf( '&times;&nbsp;%s', $cart_item['quantity'] ) . '</div>';
				}
			}
			if ( isset( $cart_item['bopobb_parent_id'] ) ) {
				if ( $this->settings->get_params( 'bopobb_edit_cart' ) ) {
					if ( ( ! empty( $cart_item['bopobb_max_qty'] ) && $cart_item['bopobb_qty'] > $cart_item['bopobb_max_qty'] )
					     || ( isset( $cart_item['bopobb_max_qty'] ) && $cart_item['bopobb_max_qty'] == 1 ) ) {
						return '<div class="bopobb-cart-product-quantity">' . sprintf( '&times;&nbsp;%s', $cart_item['bopobb_qty'] ) . '</div>';
					} else {
						if ( isset( $cart_item['bopobb_min_qty'] ) && isset( $cart_item['bopobb_max_qty'] ) && isset( $cart_item['bopobb_qty'] ) ) {
							$product_quantity = '<div class="bopobb-cart-item-quantity">
                                                <input type="number" class="bopobb-cart-item-qty" step="1" 
                                                min="' . $cart_item['bopobb_min_qty'] . '" 
                                                inputmode="numeric" max="' . $cart_item['bopobb_max_qty'] . '" name=""
                                                data-value="' . $cart_item['bopobb_qty'] . '"
                                                value="' . $cart_item['bopobb_qty'] . '">
                                            </div>';

							return $product_quantity;
						}
					}
				} else {
					return '<div class="bopobb-cart-product-quantity">' . sprintf( '&times;&nbsp;%s', $cart_item['bopobb_qty'] ) . '</div>';
				}
			}

			return $quantity;
		}

		public function bopobb_order_item_quantity( $item_qty, $item ) {
			if ( isset( $item['bopobb_parent_id'] ) && ! empty( $item['bopobb_qty'] ) ) {
				return '<strong class="product-quantity">' . sprintf( '&times;&nbsp;%s', $item['bopobb_qty'] ) . '</strong>';
			}

			return $item_qty;
		}

		public function bopobb_checkout_item_quantity( $item_qty, $cart_item, $cart_item_key ) {
			if ( isset( $cart_item['bopobb_parent_id'] ) ) {
				if ( $this->settings->get_params( 'bopobb_edit_checkout' ) && is_checkout() ) {
					if ( ( ! empty( $cart_item['bopobb_max_qty'] ) && $cart_item['bopobb_qty'] > $cart_item['bopobb_max_qty'] )
					     || $cart_item['bopobb_max_qty'] == 1 ) {
						return '<strong class="product-quantity">' . sprintf( '&times;&nbsp;%s', $cart_item['bopobb_qty'] ) . '</strong>';
					} else {
						$product_quantity = '<div class="bopobb-order-item-quantity">
                                            <input type="number" class="bopobb-order-item-qty" step="1" 
                                            min="' . $cart_item['bopobb_min_qty'] . '" 
                                            inputmode="numeric" max="' . $cart_item['bopobb_max_qty'] . '" name=""
                                            data-value="' . $cart_item['bopobb_qty'] . '"
                                            value="' . $cart_item['bopobb_qty'] . '">
                                        </div>';

						return $product_quantity;
					}
				} else {
					return '<strong class="product-quantity">' . sprintf( '&times;&nbsp;%s', $cart_item['bopobb_qty'] ) . '</strong>';
				}
			}

			return $item_qty;
		}

		public function bopobb_cart_item_remove_link( $link, $cart_item_key ) {
			if ( isset( WC()->cart->cart_contents[ $cart_item_key ]['bopobb_parent_key'] ) ) {
				$parent_key = WC()->cart->cart_contents[ $cart_item_key ]['bopobb_parent_key'];

				if ( isset( WC()->cart->cart_contents[ $parent_key ] ) || array_search( $parent_key, array_column( WC()->cart->cart_contents, 'bopobb_key' ) ) !== false ) {
					if ( $this->settings->get_params( 'bopobb_edit_cart' ) ) {
					    $item_index = WC()->cart->cart_contents[ $cart_item_key ]['bopobb_index'];
						$parent_object_data =  WC()->cart->cart_contents[ $parent_key ]['data'];
						if ( ! is_object( $parent_object_data ) || ! property_exists( $parent_object_data, 'items' ) ) {
							return '';
                        }
						$parent_data = $parent_object_data->get_items();
						$parent_item = $parent_data['items'];
                        if ( isset( $parent_item[$item_index] ) && $parent_item[$item_index]['bopobb_bpi_optional_item'] ) {
                            return $link;
                        }
					}
				    return '';
				}
			}

			return $link;
		}

		// Set price for bundled item
		public function bopobb_cart_item_price( $price, $cart_item ) {
			if ( isset( $cart_item['bopobb_parent_id'], $cart_item['bopobb_price'], $cart_item['bopobb_parent_key'] ) ) {
				if ( ( is_plugin_active( 'side-cart-woocommerce/xoo-wsc-main.php' ) || is_plugin_active( 'side-cart-woocommerce/xoo-wsc.php' ) )
				     && ( ! is_cart() || ! is_checkout() ) ) {
					return wc_price( 0 );
				} else {
					switch ( $this->settings->get_params( 'bopobb_item_price_single' ) ) {
						case 'price':
//						    $item_base = $cart_item['data']->get_data()['price'] * $cart_item['bopobb_qty'];
							$item_base = $cart_item['data']->get_data()['price'];
							$item_base = apply_filters( 'bopobb_convert_currency_price', $item_base );

							return wc_price( $item_base );
						case 'price_bundle':
							$item_price = $cart_item['bopobb_price'] / (int) $cart_item['bopobb_qty'];
							$icl_tax    = 'incl' == get_option( 'woocommerce_tax_display_cart' ) ? 1 : 0;
							if ( isset( $cart_item['bopobb_tax_rate'] ) ) {
								$tax_rate = (float) $cart_item['bopobb_tax_rate'];
							} else {
								$tax_rate = VI_WOO_BOPO_BUNDLE_Helper::bopobb_tax_rate( wc_get_product( $cart_item['bopobb_parent_id'] ) );
							}
							$item_price = $icl_tax ? $item_price + ( $item_price * ( $tax_rate / 100 ) ) : $item_price;
							$item_price = apply_filters( 'bopobb_convert_currency_price', $item_price );

							return wc_price( $item_price );
						case 'price_discount':
							$item_price = $cart_item['bopobb_price'] / (int) $cart_item['bopobb_qty'];
							$icl_tax    = 'incl' == get_option( 'woocommerce_tax_display_cart' ) ? 1 : 0;
							if ( isset( $cart_item['bopobb_tax_rate'] ) ) {
								$tax_rate = (float) $cart_item['bopobb_tax_rate'];
							} else {
								$tax_rate = VI_WOO_BOPO_BUNDLE_Helper::bopobb_tax_rate( wc_get_product( $cart_item['bopobb_parent_id'] ) );
							}
							$item_price = $icl_tax ? $item_price + ( $item_price * ( $tax_rate / 100 ) ) : $item_price;
							$item_price = apply_filters( 'bopobb_convert_currency_price', $item_price );
//						    $item_base = $cart_item['data']->get_data()['price'] * $cart_item['bopobb_qty'];
							$item_base = $cart_item['data']->get_data()['price'];
							$item_base = apply_filters( 'bopobb_convert_currency_price', $item_base );

							return wc_format_sale_price( $item_base, $item_price );
						default:
							return '';
					}
				}
			}

			return $price;
		}


		// Set subtotal price for bundled item
		function bopobb_cart_item_subtotal( $subtotal, $cart_item = null ) {
			$new_subtotal = false;

			if ( isset( $cart_item['bopobb_parent_id'], $cart_item['bopobb_price'], $cart_item['bopobb_fixed_price'] ) ) {
				if ( ( is_plugin_active( 'side-cart-woocommerce/xoo-wsc-main.php' ) || is_plugin_active( 'side-cart-woocommerce/xoo-wsc.php' ) )
				     && ( ! is_cart() || ! is_checkout() ) ) {
					$subtotal = wc_price( 0 );
				} else {
					$subtotal = '';
					switch ( $this->settings->get_params( 'bopobb_item_price_total' ) ) {
						case 'price':
							$item_base = $cart_item['data']->get_data()['price'] * $cart_item['bopobb_qty'];
							$item_base = apply_filters( 'bopobb_convert_currency_price', $item_base );

							return wc_price( $item_base );
						case 'price_bundle':
							$item_price = $cart_item['bopobb_price'];
							$icl_tax    = 'incl' == get_option( 'woocommerce_tax_display_cart' ) ? 1 : 0;
							if ( isset( $cart_item['bopobb_tax_rate'] ) ) {
								$tax_rate = (float) $cart_item['bopobb_tax_rate'];
							} else {
								$tax_rate = VI_WOO_BOPO_BUNDLE_Helper::bopobb_tax_rate( wc_get_product( $cart_item['bopobb_parent_id'] ) );
							}
							$item_price = $icl_tax ? $item_price + ( $item_price * ( $tax_rate / 100 ) ) : $item_price;
							$item_price = apply_filters( 'bopobb_convert_currency_price', $item_price );

							return wc_price( $item_price );
						case 'price_discount':
							$item_price = $cart_item['bopobb_price'];
							$icl_tax    = 'incl' == get_option( 'woocommerce_tax_display_cart' ) ? 1 : 0;
							if ( isset( $cart_item['bopobb_tax_rate'] ) ) {
								$tax_rate = (float) $cart_item['bopobb_tax_rate'];
							} else {
								$tax_rate = VI_WOO_BOPO_BUNDLE_Helper::bopobb_tax_rate( wc_get_product( $cart_item['bopobb_parent_id'] ) );
							}
							$item_price = $icl_tax ? $item_price + ( $item_price * ( $tax_rate / 100 ) ) : $item_price;
							$item_price = apply_filters( 'bopobb_convert_currency_price', $item_price );
							$item_base  = $cart_item['data']->get_data()['price'] * $cart_item['bopobb_qty'];
							$item_base  = apply_filters( 'bopobb_convert_currency_price', $item_base );

							return wc_format_sale_price( $item_base, $item_price );
						default:
							return '';
					}
				}

				return $subtotal;
			}

			if ( $new_subtotal && ( $cart_product = $cart_item['data'] ) ) {
				if ( $cart_product->is_taxable() ) {
					if ( WC()->cart->display_prices_including_tax() ) {
						if ( ! wc_prices_include_tax() && WC()->cart->get_subtotal_tax() > 0 ) {
							$subtotal .= ' <small class="tax_label">' . WC()->countries->inc_tax_or_vat() . '</small>';
						}
					} else {
						if ( wc_prices_include_tax() && WC()->cart->get_subtotal_tax() > 0 ) {
							$subtotal .= ' <small class="tax_label">' . WC()->countries->ex_tax_or_vat() . '</small>';
						}
					}
				}
			}

			return $subtotal;
		}

		function bopobb_cart_item_removed( $cart_item_key, $cart ) {
			if ( isset( $cart->removed_cart_contents[ $cart_item_key ]['bopobb_keys'] ) ) {
				$keys = $cart->removed_cart_contents[ $cart_item_key ]['bopobb_keys'];

				foreach ( $keys as $key ) {
					$cart->remove_cart_item( $key );

					if ( ( $new_key = array_search( $key, array_column( $cart->cart_contents, 'bopobb_key', 'key' ) ) ) !== false ) {
						$cart->remove_cart_item( $new_key );
					}
				}
			}
		}

		function bopobb_cart_contents_count( $count ) {
			// count for cart contents
			$cart_count = get_option( '_bopobb_cart_contents_count', 'bundle' );

			if ( $cart_count !== 'both' ) {
				$cart_contents = WC()->cart->cart_contents;

				foreach ( $cart_contents as $cart_item_key => $cart_item ) {
					if ( ( $cart_count === 'bundled_products' ) && ! empty( $cart_item['bopobb_ids'] ) ) {
						$count -= $cart_item['quantity'];
					}

					if ( ( $cart_count === 'bundle' ) && ! empty( $cart_item['bopobb_parent_id'] ) ) {
						$count -= $cart_item['quantity'];
					}
				}
			}

			return $count;
		}

		function bopobb_order_formatted_line_subtotal( $subtotal, $order_item ) {
			if ( isset( $order_item['_bopobb_parent_id'] ) ) {
				return '';
			}

			return $subtotal;
		}

		public function bopobb_add_order_item_meta( $item_id, $values, $cart_item_key ) {
			if ( isset( $values['bopobb_parent_id'] ) ) {
				wc_add_order_item_meta( $item_id, '_bopobb_parent_id', $values['bopobb_parent_id'] );
			}

			if ( isset( $values['bopobb_ids'] ) ) {
				wc_add_order_item_meta( $item_id, '_bopobb_ids', $values['bopobb_ids'] );
			}

			if ( isset( $values['bopobb_product_note'] ) ) {
				wc_add_order_item_meta( $item_id, '_bopobb_product_note', $values['bopobb_product_note'] );
			}

			if ( isset( $values['bopobb_price'] ) ) {
				// use _ to hide the data
				wc_add_order_item_meta( $item_id, '_bopobb_price', $values['bopobb_price'] );
			}
		}

		function bopobb_checkout_create_order_line_item( $order_item, $cart_item_key, $values ) {
			if ( isset( $values['bopobb_parent_id'] ) ) {
				// use _ to hide the data
				$order_item->update_meta_data( '_bopobb_parent_id', $values['bopobb_parent_id'] );
			}

			if ( isset( $values['bopobb_ids'] ) ) {
				// use _ to hide the data
				$order_item->update_meta_data( '_bopobb_ids', $values['bopobb_ids'] );
			}

			if ( isset( $values['bopobb_product_note'] ) ) {
				// use _ to hide the data
				$order_item->update_meta_data( '_bopobb_product_note', $values['bopobb_product_note'] );
			}

			if ( isset( $values['bopobb_price'] ) ) {
				// use _ to hide the data
				$order_item->update_meta_data( '_bopobb_price', $values['bopobb_price'] );
			}
		}

		function bopobb_item_class( $class, $cart_item ) {
			if ( isset( $cart_item['bopobb_parent_id'] ) ) {
				$class .= ' bopobb-cart-item bopobb-cart-child';
			} elseif ( isset( $cart_item['bopobb_ids'] ) ) {
				$class .= ' bopobb-cart-item bopobb-cart-parent';
			}

			return $class;
		}

		function product_bopobb_side_cart_start( $_product, $cart_item_key ) {
			if ( WC()->cart && ! empty( $cart_item_key ) ) {
				$cart_item = WC()->cart->get_cart_item( $cart_item_key );
				if ( $cart_item ) {
					if ( isset( $cart_item['bopobb_parent_key'] ) ) {
						echo wp_kses_post( '<div class="bopobb-xoo-wsc-child">' );
					}
					if ( isset( $cart_item['bopobb_ids'] ) ) {
						echo wp_kses_post( '<div class="bopobb-xoo-wsc-parent">' );
					}
				}
			}

			return;
		}

		function product_bopobb_side_cart_end( $_product, $cart_item_key ) {
			if ( WC()->cart && ! empty( $cart_item_key ) ) {
				$cart_item = WC()->cart->get_cart_item( $cart_item_key );
				if ( $cart_item ) {
					if ( isset( $cart_item['bopobb_key'] ) ) {
						echo wp_kses_post( '</div>' );
					}
				}
			}

			return;
		}

		function bopobb_order_item_name( $name, $item ) {
			if ( is_order_received_page() ) {
				$product_id      = $item['product_id'];
				$order_item_meta = $item->get_meta_data();
				if ( ! $order_item_meta || ! is_array( $order_item_meta ) ) {
					return $name;
				}
				foreach ( $order_item_meta as $line_item_meta ) {
					$item_meta_data = $line_item_meta->get_data();
					if ( $item_meta_data && isset( $item_meta_data['key'] ) && $item_meta_data['key'] == '_bopobb_product_note'
					     && isset( $item_meta_data['value'] ) && ! empty( $item_meta_data['value'] ) ) {
						$name .= '<div class="bopobb-order-detail-note">' .
						         sprintf( '%s: %s', esc_html__( 'Bundle note', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $item_meta_data['value'] ) ) . '</div>';
					}
				}
			}

			return $name;
		}

		function bopobb_order_again_cart_item_data( $data, $cart_item ) {
			if ( isset( $cart_item['bopobb_ids'] ) ) {
				$data['bopobb_order_again'] = 'yes';
				$data['bopobb_ids']         = $cart_item['bopobb_ids'];
			}

			if ( isset( $cart_item['bopobb_parent_id'] ) ) {
				$data['bopobb_order_again'] = 'yes';
				$data['bopobb_parent_id']   = $cart_item['bopobb_parent_id'];
			}

			return $data;
		}

		function bopobb_cart_loaded_from_session() {
			foreach ( WC()->cart->cart_contents as $cart_item_key => $cart_item ) {
				if ( isset( $cart_item['bopobb_order_again'], $cart_item['bopobb_parent_id'] ) ) {
					WC()->cart->remove_cart_item( $cart_item_key );
				}

				if ( isset( $cart_item['bopobb_order_again'], $cart_item['bopobb_ids'] ) ) {
					$cart_item['data']->build_items( $cart_item['bopobb_ids'] );
					$items = $cart_item['data']->get_items();
					$this->bopobb_add_to_cart_items( $items, $cart_item_key, $cart_item['product_id'], $cart_item['quantity'] );
				}
			}
		}

		function bopobb_ajax_add_order_item_meta( $order_item_id, $order_item, $order ) {
			$quantity = $order_item->get_quantity();

			if ( 'line_item' === $order_item->get_type() ) {
				$product    = $order_item->get_product();
				$product_id = $product->get_id();

				if ( $product && $product->is_type( 'bopobb' ) && ( $items = $product->get_items() ) ) {

					// get bundle info
					$fixed_price    = $product->is_fixed_price();
					$discount_array = $product->get_discount_amount();

					// add the bundle
					$order_id = $order->add_product( $product, $quantity );

					for ( $i = 0; $i < count( $items ); $i ++ ) {
						$_product = wc_get_product( $items[ $i ]['id'] );

						if ( ! $_product || in_array( $_product->get_type(), $this->settings->get_params( 'bopobb_type_exclude' ), true ) ) {
							continue;
						}

						if ( $fixed_price ) {
							$_product->set_price( 0 );
						} elseif ( is_array( $discount_array ) ) {
							$calc_price = self::bopobb_calc_price( $items[ $i ]['id'], $i, $items[ $i ]['qty'], $discount_array );
							$_price     = $calc_price['sale'];

							$_product->set_price( (float) $_price );
						}

						// add bundled products
						$_order_item_id = $order->add_product( $_product, $items[ $i ]['qty'] * $quantity );

						if ( ! $_order_item_id ) {
							continue;
						}

						$_order_items = $order->get_items( 'line_item' );
						$_order_item  = $_order_items[ $_order_item_id ];
						$_order_item->add_meta_data( '_bopobb_parent_id', $product_id, true );
						$_order_item->save();
					}

					// remove the old bundle
					if ( $order_id ) {
						$order->remove_item( $order_item_id );
					}
				}

				$order->save();
			}
		}

		function bopobb_hidden_order_item_meta( $hidden ) {
			return array_merge( $hidden, array(
				'_bopobb_parent_id',
				'_bopobb_ids',
				'_bopobb_price',
				'_bopobb_product_note',
				'bopobb_parent_id',
				'bopobb_ids',
				'bopobb_price'
			) );
		}

		function bopobb_before_order_item_meta( $order_item_id ) {
			if ( $parent_id = wc_get_order_item_meta( $order_item_id, '_bopobb_parent_id', true ) ) {
				echo sprintf( '(%s %s)', esc_html__( 'bundled in', 'bopo-woocommerce-product-bundle-builder' ), esc_html( get_the_title( $parent_id ) ) );
			}
			if ( $product_note = wc_get_order_item_meta( $order_item_id, '_bopobb_product_note', true ) ) {
				echo '<div class="bopobb-order-detail-note">' . sprintf( '%s %s', esc_html__( 'Bundle note:', 'bopo-woocommerce-product-bundle-builder' ), esc_html( $product_note ) ) . '</div>';
			}
		}

		function bopobb_before_order_item_meta_product( $item_id, $item, $product ) {
			if ( $this->settings->get_params( 'bopobb_order_item_price' ) &&
			     $parent_id = wc_get_order_item_meta( $item_id, '_bopobb_parent_id', true ) ) {
				echo '<div class="bopobb-order-detail-note">' . sprintf( '%s %s',
						esc_html__( 'Current price:', 'bopo-woocommerce-product-bundle-builder' ),
						wp_kses_post( wc_price( esc_html( $product->get_price() ) ) ) ) . '</div>';
			}
		}

		function bopobb_cart_shipping_packages( $packages ) {
			if ( ! empty( $packages ) ) {
				foreach ( $packages as $package_key => $package ) {
					if ( ! empty( $package['contents'] ) ) {
						// Shipping single
						foreach ( $package['contents'] as $cart_item_key => $cart_item ) {
							if ( ! empty( $cart_item['bopobb_parent_id'] ) ) {
								$parent_product = wc_get_product( $cart_item['bopobb_parent_id'] );
								if ( $parent_product->get_meta( 'bopobb_shipping_fee', true ) !== 'each' ) {
									unset( $packages[ $package_key ]['contents'][ $cart_item_key ] );
								}
							}
							if ( ! empty( $cart_item['bopobb_ids'] ) ) {
								$base_product = wc_get_product( $cart_item['data']->get_id() );
								if ( $base_product->get_meta( 'bopobb_shipping_fee', true ) === 'each' ) {
									unset( $packages[ $package_key ]['contents'][ $cart_item_key ] );
								}
							}
						}
					}
				}
			}

			return $packages;
		}

		function bopobb_coupon_is_valid_for_product( $valid, $product, $coupon, $cart_item ) {
			if ( ( $this->settings->get_params( 'bopobb_coupon_res' ) === 'both' ) && ( isset( $cart_item['bopobb_parent_id'] ) || isset( $cart_item['bopobb_ids'] ) ) ) {
				// exclude both bundles and bundled products
				return false;
			}

			if ( ( $this->settings->get_params( 'bopobb_coupon_res' ) === 'bundles' ) && isset( $cart_item['bopobb_ids'] ) ) {
				// exclude bundles
				return false;
			}

			if ( ( $this->settings->get_params( 'bopobb_coupon_res' ) === 'bundled' ) && isset( $cart_item['bopobb_parent_id'] ) ) {
				// exclude bundled products
				return false;
			}

			return $valid;
		}

		public function product_bopobb_add_to_cart( $product, $template, $settings ) {
			$product_id = $product->get_id();
			?>
            <form class="vi-wcaio-sb-cart-form bopobb-sticky-atc-wrap"
                  action="<?php echo esc_attr( esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ) ); ?>"
                  method="post" enctype="multipart/form-data" data-product-id="<?php echo esc_attr( $product_id ); ?>">
                <div class="bopobb-sticky-items-wrap">
					<?php
					if ( ! $product || ! $product->is_type( 'bopobb' ) ) {
						return;
					}

					if ( empty( $this->language ) ) {
						$change_title  = $this->settings->get_params( 'bopobb_popup_title' );
						$change_button = $this->settings->get_params( 'bopobb_swap_text' );
					} else {
						$change_title  = $this->settings->get_params( 'bopobb_popup_title_' . $this->language );
						$change_button = $this->settings->get_params( 'bopobb_swap_text_' . $this->language );
					}

					$bundle_id = $product->get_id();

					if ( $items = $product->get_items() ) {

						$items_data  = $items['items'];
						$product_arr = array();
						for ( $i = 0; $i < $items['count']; $i ++ ) {
							$item_can_change = true;
							if ( isset( $items_data[ $i ] ) ) {
								if ( $items_data[ $i ]['bopobb_bpi_set_default'] == 1 ) {
									$item_can_change = $this->bopobb_search_product( 2, 0, $items_data[ $i ] );
								}
							}
							$prd_data             = $this->bopobb_get_item_product( $items_data, $i );
							$bopo_discount_type   = isset( $items_data[ $i ]['bopobb_bpi_discount'] ) ? $items_data[ $i ]['bopobb_bpi_discount'] : '';
							$bopo_discount_number = isset( $items_data[ $i ]['bopobb_bpi_discount_number'] ) ? $items_data[ $i ]['bopobb_bpi_discount_number'] : 0;
							if ( $bopo_discount_type == 1 ) {
								$bopo_discount_number = apply_filters( 'bopobb_convert_currency_price', $bopo_discount_number );
							}
							$bopo_quantity = isset( $items_data[ $i ]['bopobb_bpi_quantity'] ) ? $items_data[ $i ]['bopobb_bpi_quantity'] : 1;
							$img_class     = $item_can_change ? ' bopobb-sticky-item-change' : '';
							$img_class     .= $items_data[ $i ]['bopobb_bpi_set_default'] == 1 ? '' : ' bopobb-icon-plus2';
							$img_title     = '';
							$data_default  = 1;
							if ( empty( $product_arr[ $i ]['bopo_product'] ) ) {
								$img_title    = $change_button;
								$data_default = 0;
							}
							?>
                            <div class="bopobb-sticky-item bopobb-sticky-item-<?php echo esc_attr( $i ); ?>"
                                 data-default="<?php echo esc_attr( $data_default ); ?>"
                                 data-id="<?php echo esc_attr( $prd_data['product_id'] ); ?>">
                                <div class="bopobb-sticky-item-img-wrap bopobb-sticky-item-<?php echo esc_attr( $i );
								echo esc_attr( $img_class ); ?>" data-item="<?php echo esc_attr( $i ); ?>"
                                     data-product="<?php echo esc_attr( $bundle_id ) ?>"
                                     data-id="<?php echo esc_attr( $prd_data['product_id'] ); ?>"
                                     data-price="<?php echo esc_attr( $prd_data['product_price'] ); ?>"
                                     data-discount-type="<?php echo esc_attr( $bopo_discount_type ) ?>"
                                     data-discount-number="<?php echo esc_attr( $bopo_discount_number ) ?>"
                                     data-qty="<?php echo esc_attr( $bopo_quantity ) ?>"
                                     title="<?php echo esc_attr( $img_title ) ?>">
                                    <div class="bopobb-sticky-item-img"
                                         title="<?php echo esc_attr( ! empty( $prd_data['product_title'] ) ? $prd_data['product_title'] : $change_title ) ?>"
										<?php if ( $this->settings->get_params( 'bopobb_link_individual' ) == 1 ) {
											echo esc_attr( ' target=_blank' );
											if ( ! empty( $prd_data['product_id'] ) ) {
												echo esc_attr( ' href=' . get_permalink( $prd_data['product_id'] ) );
											}
										} ?>>
										<?php echo wp_kses_post( $prd_data['product_image'] ); ?>
                                    </div>
                                </div>
                            </div>
							<?php
						}
					} ?> </div>
				<?php
				self::bopobb_add_to_cart_button();
				self::bopobb_shortcode_cart_form( $product, true, $settings, ! empty( $this->language ) ? $this->language : '' ); ?>
            </form>
			<?php
		}

		function vi_wcaio_mini_cart_pd_remove( $value, $cart_item, $cart_item_key ) {
			if ( isset( $cart_item['bopobb_parent_id'] ) ) {
				return '';
			}

			return $value;
		}

		function vi_wcaio_mini_cart_pd_qty( $value, $cart_item_key, $cart_item, $quantity_args ) {
			if ( isset( $cart_item['bopobb_parent_id'] ) ) {
				return '<strong class="product-quantity">' . sprintf( '&times;&nbsp;%s', $cart_item['bopobb_qty'] ) . '</strong>';
			}

			return $value;
		}

		public static function bopobb_add_to_cart_ajax() {
			$notices = WC()->session->get( 'wc_notices', array() );
			if ( ! empty( $notices['error'] ) ) {
				wp_send_json( array( 'error' => true ) );
			}
			if ( ! empty( $notices ) ) {
				unset( $notices['success'] );
				WC()->session->set( 'wc_notices', $notices );
			}
			WC_AJAX::get_refreshed_fragments();
			die();
		}

		public function bopobb_display_add_to_cart_text( $text, $pd_this ) {
			if ( $pd_this->get_type() == 'bopobb' ) {
				if ( empty( $this->language ) ) {
					$atc_title = $this->settings->get_params( 'bopobb_shop_button' );
				} else {
					$atc_title = $this->settings->get_params( 'bopobb_shop_button_' . $this->language );
				}
				$atc_title = ! empty( $atc_title ) ? $atc_title : $text;

				return $atc_title;
			}

			return $text;
		}

		function wp_enqueue_scripts_elementor() {
			$assign_page = $this->settings->get_params( 'bopobb_conditional_tag' );
			if ( ! $this->assign_page( $assign_page ) ) {
				return;
			}
			$suffix = WP_DEBUG ? '' : 'min.';
			wp_enqueue_script( 'woo-bopo-bundle-shortcode-js', VI_WOO_BOPO_BUNDLE_JS . 'shortcode-scripts.' . $suffix . 'js', array( 'jquery' ), VI_WOO_BOPO_BUNDLE_VERSION, false );

			global $_wp_additional_image_sizes;
			$image_size    = isset( $_wp_additional_image_sizes[ $this->settings->get_params( 'bopobb_image_size' ) ] ) ?
				$_wp_additional_image_sizes[ $this->settings->get_params( 'bopobb_image_size' ) ] : array(
					'width'  => 80,
					'height' => 80
				);
			$original_size = [ intval( $image_size['width'] ), intval( $image_size['height'] ) ];
			$image_rate    = 1;
			if ( intval( $original_size[0] ) && intval( $original_size[1] ) ) {
				$image_rate  = floatval( $original_size[1] ) / intval( $original_size[0] );
				$normal_size = intval( $image_rate * 80 );
			} else {
				$normal_size = 80;
			}
			if ( isset( $this->language ) && ! empty( $this->language ) ) {
				$bopobb_alert_products = $this->settings->get_params( 'bopobb_alert_products_' . $this->language );
			} else {
				$bopobb_alert_products = $this->settings->get_params( 'bopobb_alert_products' );
			}
			wp_localize_script( 'woo-bopo-bundle-shortcode-js', 'bopobbShortcodeVars', array(
					'image_rate'   => esc_attr( $image_rate ),
					'image_height' => esc_attr( $normal_size ),
					'alert_empty'  => $bopobb_alert_products,
				)
			);
		}

		public function assign_page( $assign_page ) {
			if ( $assign_page ) {
				if ( stristr( $assign_page, "return" ) === false ) {
					$assign_page = "return (" . $assign_page . ");";
				}
				try {
					$logic_show = eval( $assign_page );// phpcs:ignore Generic.PHP.ForbiddenFunctions.Found
				} catch ( \Error $e ) {
					trigger_error( esc_html( $e->getMessage() ), E_USER_WARNING );

					$logic_show = false;
				} catch ( \Exception $e ) {
					trigger_error( esc_html( $e->getMessage() ), E_USER_WARNING );

					$logic_show = false;
				}
				if ( ! $logic_show ) {
					return false;
				}
			}

			return true;
		}

		function wc_stripe_payment_request_supported_types( $type ) {
			$type[] = 'bopobb';

			return $type;
		}

		function viwcaio_sidebar_cart_product_class( $_attr, $_cart_item_key, $_product ) {
			if ( $_cart_item_key && $_product ) {
				$cart_item = WC()->cart->cart_contents[ $_cart_item_key ];
				if ( $cart_item && isset( $cart_item['bopobb_parent_id'] ) ) {
					$_attr[] = 'bopobb-caio-child-wrap';
				}
			}

			return $_attr;
		}

		function bopobb_export_pdf() {
			check_ajax_referer( 'bopo-nonce', 'nonce' );
			$items_data = isset( $_POST['bundle_item'] ) ? wc_clean( wp_unslash( $_POST['bundle_item'] ) ) : '';

			if ( empty( $items_data ) || ! is_array( $items_data ) ) {
				wp_die();
			}
//			include_once VI_WOO_BOPO_BUNDLE_INCLUDES . 'autoload.php';
			$html = $this->get_pdf_html( $items_data );

			if ( empty( $html ) ) {
				wp_send_json_error( '', 201 );
			}

			try {
				ob_start();
				bopobb_get_template( 'print-style.php' );
				$print_style = ob_get_clean();

				$mpdf = new \Mpdf\Mpdf( [
					'tempDir'  => WP_CONTENT_DIR . '/cache',
					'fontdata' => [
						'dejavusanscondensed' =>
							[
								'R'          => 'DejaVuSansCondensed.ttf',
								'B'          => 'DejaVuSansCondensed-Bold.ttf',
								'I'          => 'DejaVuSansCondensed-Oblique.ttf',
								'BI'         => 'DejaVuSansCondensed-BoldOblique.ttf',
								'useOTL'     => 255,
								'useKashida' => 75,
							]
					]
				] );

				$mpdf->curlAllowUnsafeSslRequests = true;

				$dest = \Mpdf\Output\Destination::DOWNLOAD;

				$mpdf->WriteHTML( $print_style, 1 );
				$mpdf->WriteHTML( $html, 2 );
				$mpdf->Output( 'BopoBundle.pdf', $dest );

			} catch ( \Exception $e ) {
				echo wp_kses_post( $e->getMessage() );
			}

			wp_die();
		}

		public function get_pdf_html( $items ) {
			$html        = '';
			$total_qty   = 0;
			$total_price = 0;

			if ( ! empty( $items ) && is_array( $items ) ) {
				foreach ( $items as $i_key => $i_val ) {

					if ( empty( $i_val ) || ! is_array( $i_val ) ) {
						continue;
					}

					$quantity    = $i_val['quantity'] ? (int) $i_val['quantity'] : 1;
					$total_qty   += $quantity ? $quantity : 0;
					$total_price += $i_val['price'] ? (float) $i_val['price'] : 0;
					$image       = $i_val['image'] ? $i_val['image'] : '';

					$html .= "<tr>
                            <td class='bopobb-print-img' >
                                <img src='{$image}' width='100'>
                            </td>
                            <td class='bopobb-print-title'>
                                <div>{$i_val['title']}</div>
                            </td>
                            <td class='bopobb-print-quantity-col'>{$quantity}</td>
                            <td class='bopobb-print-price-col'>{$i_val['price']}</td>
                            <td class='bopobb-print-subtotal-col'>{$i_val['subtotal']}</td>
                        </tr>";
				}
			}

			if ( $html ) {
				$layouts = [ 'header' => '', 'footer' => '' ];

				$html = "<div id='bopobb-print-frame'>
                        {$layouts['header']}
                        <table>
                            <thead>
                            <tr>
                                <th colspan='2' class='bopobb-print-product-col'>" . esc_html__( 'Product', 'bopo-woocommerce-product-bundle-builder' ) . "</th>
                                <th class='bopobb-print-quantity-col'>" . esc_html__( 'Quantity', 'bopo-woocommerce-product-bundle-builder' ) . "</th>
                                <th class='bopobb-print-price-col'>" . esc_html__( 'Price', 'bopo-woocommerce-product-bundle-builder' ) . "</th>
                                <th class='bopobb-print-subtotal-col'>" . esc_html__( 'Subtotal', 'bopo-woocommerce-product-bundle-builder' ) . "</th>
                            </tr>
                            </thead>
                            <tbody>
                            {$html}
                            </tbody>
                             <tfoot>
                                <tr>
                                    <th colspan='2'>" . esc_html__( 'Total', 'bopo-woocommerce-product-bundle-builder' ) . "</th>
                                    <th>{$total_qty}</th>
                                    <th colspan='2' class='bopobb-print-footer-total'>{$total_price}</th>
                                </tr>
                            </tfoot>
                        </table>
                        {$layouts['footer']}
                    </div>";
			}

			return $html;
		}

		function display_saved_amount_on_checkout() {
			global $woocommerce;
			$cart_discount_total    = $woocommerce->cart->get_cart_discount_total();
			$saved_amount           = 0;
			$discount_amount        = 0;
			$subtotal               = $woocommerce->cart->subtotal;
			$total_discounted_price = 0;
			foreach ( $woocommerce->cart->get_cart() as $cart_item_key => $cart_item ) {
				$product       = $cart_item['data'];
				$regular_price = $product->get_regular_price();
				$sale_price    = $product->get_sale_price();
				if ( $product->get_type() == 'bopobb' ) {
					if ( ! isset( $cart_item['bopobb_key'] ) ) {
						continue;
					}
					$tax_include   = wc_prices_include_tax() ? true : false;
					$regular_price = 0;
					$sale_price    = 0;

					foreach ( $woocommerce->cart->get_cart() as $i_cart_item_key => $i_cart_item ) {
						if ( isset( $i_cart_item['bopobb_parent_key'] ) && isset( $i_cart_item['bopobb_price'] )
						     && $i_cart_item['bopobb_parent_key'] == $cart_item['bopobb_key'] ) {

							$bundle_product = $i_cart_item['data'];
							$item_price     = floatval( $i_cart_item['bopobb_price'] );
							if ( $tax_include ) {
								$base_tax_rates = WC_Tax::get_base_tax_rates( $product->get_tax_class( 'unfiltered' ) );
								$return_tax     = VI_WOO_BOPO_BUNDLE_Helper::bopobb_tax_from_class( $base_tax_rates );
								$item_price     = $item_price + ( $item_price * ( $return_tax / 100 ) );
							}

							$sale_price    += $item_price;
							$regular_price += $bundle_product->get_regular_price() * $i_cart_item['quantity'];
						}
					}

				}
				if ( isset( $cart_item['bopobb_parent_id'] ) ) {
					continue;
				}
				if ( $regular_price && $sale_price && $regular_price > $sale_price ) {
					$saved_amount += ( $regular_price - $sale_price ) * $cart_item['quantity'];

					$total_discounted_price += $sale_price * $cart_item['quantity'];

					if ( $product->get_type() == 'bopobb' ) {
						$cart_discount_total += $saved_amount;
					}
				} else {
					$total_discounted_price += $product->get_price() * $cart_item['quantity'];
				}
			}

			$total_discounted_price -= $cart_discount_total;
			// Verificar si el método de pago seleccionado es "bacs"
			if ( WC()->session->get( 'chosen_payment_method' ) === 'bacs' ) {
				$discount_amount = $total_discounted_price * 0.03;
			}
			$saved_amount = $cart_discount_total + $discount_amount;

			if ( $saved_amount > 0 ) {
				echo '<tr class="order-total">
                <th>' . esc_html__( 'Ahorraste:', 'woocommerce' ) . '</th>
                <td data-title="' . esc_html__( 'Ahorraste:', 'woocommerce' ) . '">
                    <strong>' . wp_kses_post( wc_price( $saved_amount ) ) . '</strong>
                </td>
            </tr>';
			}
		}

		function calculate_discount_item( $price_item, $discount_item, $discount_number ) {
			if ( '' == $discount_item || '' == $discount_number ) {
				return $price_item;
			}
			switch ( $discount_item ) {
				case 0:
					if ( ! $price_item ) {
						return $price_item;
					}
					$return_price = ( floatval( $price_item ) / 100 ) * floatval( $discount_number );
					$return_price = floatval( $price_item ) - floatval( $return_price );
					if ( $return_price > $price_item ) {
						$return_price = $price_item;
					}
					if ( $return_price < 0 ) {
						$return_price = 0;
					}

					return $return_price;
				case 1:
					if ( ! $price_item ) {
						return $price_item;
					}
					$return_price = floatval( $price_item ) - floatval( $discount_number );
					if ( $return_price < 0 ) {
						$return_price = 0;
					}

					return $return_price;
				case 2:
				default:
					return floatval( $discount_number );
			}
		}

		function bopobb_wp_enqueue_scripts( $in_shortcode = false ) {
			$assign_page = $this->settings->get_params( 'bopobb_conditional_tag' );
			//Run in cart aand checkout ! is_cart() && ! is_checkout() && '$assign_page'
			if ( ! $in_shortcode && ! $this->assign_page( $assign_page ) && ! is_cart() && ! is_checkout() ) {
				return;
			}
			$custom_atc = false;
			if ( is_product() ) {
				$_product = wc_get_product();
				if ( $_product && $_product->is_type( 'bopobb' ) ) {
					$theme = wp_get_theme();
					if ( 'Cerato Child' == $theme->name || 'Cerato' == $theme->name ) {
						$custom_atc = true;
					}
				}
			}
			if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
				$default_lang     = apply_filters( 'wpml_default_language', null );
				$current_language = apply_filters( 'wpml_current_language', null );

				if ( $current_language && $current_language !== $default_lang ) {
					$this->language = $current_language;
				}
			} else if ( class_exists( 'Polylang' ) ) {
				$default_lang     = pll_default_language( 'slug' );
				$current_language = pll_current_language( 'slug' );
				if ( $current_language && $current_language !== $default_lang ) {
					$this->language = $current_language;
				}
			}
			if ( empty( $this->language ) ) {
				$title_popup            = $this->settings->get_params( 'bopobb_popup_title' );
				$bopobb_alert_products  = $this->settings->get_params( 'bopobb_alert_products' );
				$bopobb_alert_available = $this->settings->get_params( 'bopobb_alert_available' );
				$bopobb_alert_duplicate = $this->settings->get_params( 'bopobb_alert_duplicate' );
				$bopobb_alert_change    = $this->settings->get_params( 'bopobb_alert_change' );
				$bopobb_alert_max       = $this->settings->get_params( 'bopobb_alert_max' );
				$bopobb_alert_min       = $this->settings->get_params( 'bopobb_alert_min' );
				$bopobb_alert_stock     = $this->settings->get_params( 'bopobb_alert_stock' );
			} else {
				$title_popup            = $this->settings->get_params( 'bopobb_popup_title_' . $this->language );
				$bopobb_alert_products  = $this->settings->get_params( 'bopobb_alert_products_' . $this->language );
				$bopobb_alert_available = $this->settings->get_params( 'bopobb_alert_available_' . $this->language );
				$bopobb_alert_duplicate = $this->settings->get_params( 'bopobb_alert_duplicate_' . $this->language );
				$bopobb_alert_change    = $this->settings->get_params( 'bopobb_alert_change_' . $this->language );
				$bopobb_alert_max       = $this->settings->get_params( 'bopobb_alert_max_' . $this->language );
				$bopobb_alert_min       = $this->settings->get_params( 'bopobb_alert_min_' . $this->language );
				$bopobb_alert_stock     = $this->settings->get_params( 'bopobb_alert_stock_' . $this->language );
			}

			if ( WP_DEBUG ) {
				wp_enqueue_style( 'woo-bopo-bundle-frontend', VI_WOO_BOPO_BUNDLE_CSS . 'bopo-frontend.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
				wp_enqueue_style( 'woo-bopo-bundle-icons', VI_WOO_BOPO_BUNDLE_CSS . 'bopo-icon.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
				wp_enqueue_script( 'woo-bopo-bundle-frontend', VI_WOO_BOPO_BUNDLE_JS . 'bopo-frontend.js', array( 'jquery' ), VI_WOO_BOPO_BUNDLE_VERSION, false );
			} else {
				wp_enqueue_style( 'woo-bopo-bundle-frontend', VI_WOO_BOPO_BUNDLE_CSS . 'bopo-frontend.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
				wp_enqueue_style( 'woo-bopo-bundle-icons', VI_WOO_BOPO_BUNDLE_CSS . 'bopo-icon.min.css', array(), VI_WOO_BOPO_BUNDLE_VERSION );
				wp_enqueue_script( 'woo-bopo-bundle-frontend', VI_WOO_BOPO_BUNDLE_JS . 'bopo-frontend.min.js', array( 'jquery' ), VI_WOO_BOPO_BUNDLE_VERSION, false );
			}

			global $_wp_additional_image_sizes;
			$image_def     = array(
				'width'  => 247,
				'height' => 296,
				'crop'   => 1
			);
			$image_size    = isset( $_wp_additional_image_sizes[ $this->settings->get_params( 'bopobb_image_size' ) ] ) ? $_wp_additional_image_sizes[ $this->settings->get_params( 'bopobb_image_size' ) ] : $image_def;
			$original_size = [
				intval( isset( $image_size['width'] ) ? $image_size['width'] : $image_def['width'] ),
				intval( isset( $image_size['height'] ) ? $image_size['height'] : $image_def['height'] )
			];
			$image_rate    = 1;
			if ( intval( $original_size[0] ) && intval( $original_size[1] ) ) {
				$image_rate  = floatval( $original_size[1] ) / intval( $original_size[0] );
				$normal_size = intval( $image_rate * 80 );
			} else {
				$normal_size = 80;
			}
			$item_col = $this->settings->get_params( 'bopobb_item_column' );
			switch ( $item_col ) {
				case 2:
					$col_width  = 45;
					$span_width = 10;
					$nth_child  = '4n';
					break;
				case 3:
					$col_width  = 28;
					$span_width = 8;
					$nth_child  = '3n';
					break;
				default:
					$col_width  = 20.5;
					$span_width = 6;
					$nth_child  = '8n';
			}

			ob_start();
			bopobb_get_template( 'print-style.php', array(), '', VI_WOO_BOPO_BUNDLE_TEMP_DIR );
			$print_style = ob_get_clean();

			ob_start();
			do_action( 'bopobb_print_bundle_header' );
			$printHeader = ob_get_clean();

			ob_start();
			do_action( 'bopobb_print_bundle_footer' );
			$printFooter = ob_get_clean();

			wp_localize_script( 'woo-bopo-bundle-frontend', 'bopobbVars', array(
					'ajaxurl'                  => admin_url( 'admin-ajax.php' ),
					'wc_ajax_url'              => WC_AJAX::get_endpoint( "%%endpoint%%" ),
					'wc_custom_atc'            => $custom_atc,
					'user_id'                  => md5( 'bopo' . get_current_user_id() ),
					'nonce'                    => wp_create_nonce( 'bopo-nonce' ),
					'vi_swatches'              => class_exists( 'VIWPVS_WOOCOMMERCE_PRODUCT_VARIATIONS_SWATCHES' ) ||
					                              class_exists( 'VI_WOO_PRODUCT_VARIATIONS_SWATCHES' ) ? 1 : 0,
					'bopobb_popup_title'       => esc_attr( $title_popup ),
					'bopobb_link_individual'   => esc_attr( $this->settings->get_params( 'bopobb_link_individual' ) ),
					'bundled_price'            => esc_attr( $this->settings->get_params( 'bopobb_price_by' ) ),
					'hide_price'               => esc_attr( $this->settings->get_params( 'bopobb_hide_price' ) ),
					'view_description'         => esc_attr( $this->settings->get_params( 'bopobb_view_description' ) ),
					'view_full_description'    => esc_attr( $this->settings->get_params( 'bopobb_view_full_description' ) ),
					'short_des_position'       => esc_attr( $this->settings->get_params( 'bopobb_short_des_position' ) ),
					'des_position'             => esc_attr( $this->settings->get_params( 'bopobb_des_position' ) ),
					'allow_duplicate_select'   => esc_attr( $this->settings->get_params( 'bopobb_duplicate_select' ) ),
					'image_rate'               => esc_attr( $image_rate ),
					'image_height'             => esc_attr( $normal_size ),
					'price_format'             => get_woocommerce_price_format(),
					'price_decimals'           => wc_get_price_decimals(),
					'price_thousand_separator' => wc_get_price_thousand_separator(),
					'price_decimal_separator'  => wc_get_price_decimal_separator(),
					'currency_symbol'          => get_woocommerce_currency_symbol(),
					'alert_empty'              => esc_attr( $bopobb_alert_products ),
					'alert_stock'              => esc_attr( $bopobb_alert_available ),
					'alert_duplicate'          => esc_attr( $bopobb_alert_duplicate ),
					'alert_no_item'            => esc_attr( $bopobb_alert_change ),
					'alert_max_item'           => esc_attr( $bopobb_alert_max ) . '[d].',
					'alert_min_item'           => esc_attr( $bopobb_alert_min ) . '[d].',
//					'alert_min_quantity'       => esc_html__( 'Require total item in bundle greater than ', 'bopo-woocommerce-product-bundle-builder' ) . '[d].',
//					'alert_max_quantity'       => esc_html__( 'Require total item in bundle less than ', 'bopo-woocommerce-product-bundle-builder' ) . '[d].',
					'bopobb_alert_stock'       => esc_attr( $bopobb_alert_stock ),
					'printStyle'               => esc_attr( $print_style ),
					'printHeader'              => wp_kses_post( $printHeader ),
					'printFooter'              => wp_kses_post( $printFooter ),
					'popup_load_init'          => esc_attr( $this->settings->get_params( 'bopobb_popup_load_init' ) ),
					'cart_update_notice'       => esc_html__( 'Updated', 'bopo-woocommerce-product-bundle-builder' ) . ' [s].',
					'variation_notice'         => esc_html__( 'This variation is not available in this bundle', 'bopo-woocommerce-product-bundle-builder' ),
					'saved_text'               => '(' . esc_html__( 'saved', 'bopo-woocommerce-product-bundle-builder' ) . ' [d])',
				)
			);

			$css = '';
			$css .= '.bopobb-area .bopobb-popup .bopobb-product .bopobb-product-title,
                    .bopobb-area .bopobb-popup .bopobb-product .bopobb-variation-title,
			        .bopobb-area .bopobb-popup .bopobb-product .bopobb-product-price,
			        .bopobb-area .bopobb-popup .bopobb-product .bopobb-product-price span.woocommerce-Price-amount,
			        .bopobb-area .bopobb-popup .bopobb-product .bopobb-product-price span.woocommerce-Price-amount span.woocommerce-Price-currencySymbol {';
			$css .= 'color:' . esc_attr( $this->settings->get_params( 'bopobb_popup_color' ) ) . ';';
			$css .= '}';
			$css .= '.bopobb-area .bopobb-popup .bopobb-product-list,
			        .bopobb-area .bopobb-popup .bopobb-variation-list {';
			$css .= 'background-color:' . esc_attr( $this->settings->get_params( 'bopobb_popup_background' ) ) . ';';
			$css .= '}';

			$css .= '.bopobb-single-wrap:not(.bopobb-shortcode-wrap) .bopobb-items-top-wrap .bopobb-item-top {';
			$css .= 'width:' . esc_attr( $col_width . '%' ) . ';';
			$css .= '}';
			$css .= '.bopobb-single-wrap:not(.bopobb-shortcode-wrap) .bopobb-items-top-wrap .bopobb-item-img-separate-wrap {';
			$css .= 'width:' . esc_attr( $span_width . '%' ) . ';';
			$css .= '}';
			$css .= '.bopobb-single-wrap:not(.bopobb-shortcode-wrap) .bopobb-items-top-wrap .bopobb-item-img-separate-wrap:nth-child(' . esc_attr( $nth_child ) . ') {';
			$css .= 'display: none;';
			$css .= '}';
			$css .= '.bopobb-single-wrap .bopobb-items-top-wrap .bopobb-item-img-wrap {';
			$css .= 'border-radius:' . esc_attr( $this->settings->get_params( 'bopobb_image_border' ) ) . '%;';
			$css .= '}';
			$css .= '.bopobb-single-wrap .bopobb-items-top-wrap .bopobb-item-img-wrap .bopobb-item-img {';
			$css .= 'border-radius:' . esc_attr( $this->settings->get_params( 'bopobb_image_border' ) ) . '%;';
			$css .= '}';
			$css .= '.bopobb-single-wrap .bopobb-items-bottom-wrap.bopobb-template-2 .bopobb-item-img-wrap {';
			$css .= 'border-radius:' . esc_attr( $this->settings->get_params( 'bopobb_image_border' ) ) . '%;';
			$css .= '}';
			$css .= '.bopobb-single-wrap .bopobb-items-bottom-wrap.bopobb-template-2 .bopobb-item-img-wrap .bopobb-item-img {';
			$css .= 'border-radius:' . esc_attr( $this->settings->get_params( 'bopobb_image_border' ) ) . '%;';
			$css .= '}';

			$css .= '.bopobb-single-wrap:not(.bopobb-shortcode-wrap) .bopobb-items-bottom-wrap.bopobb-template-3 .bopobb-item-product {';
			$css .= 'width:' . esc_attr( $col_width . '%' ) . ';';
			$css .= '}';
			$css .= '.bopobb-single-wrap:not(.bopobb-shortcode-wrap) .bopobb-items-bottom-wrap.bopobb-template-3 .bopobb-item-img-separate-wrap {';
			$css .= 'width:' . esc_attr( $span_width . '%' ) . ';';
			$css .= '}';
			$css .= '.bopobb-single-wrap:not(.bopobb-shortcode-wrap) .bopobb-items-bottom-wrap.bopobb-template-3 .bopobb-item-img-separate-wrap:nth-child(' . esc_attr( $nth_child ) . ') {';
			$css .= 'display: none;';
			$css .= '}';
			$css .= '.bopobb-single-wrap .bopobb-items-bottom-wrap.bopobb-template-3 .bopobb-item-block-wrap .bopobb-item-img-wrap {';
			$css .= 'border-radius:' . esc_attr( $this->settings->get_params( 'bopobb_image_border' ) ) . '%;';
			$css .= '}';

			$css .= wp_kses_post( $this->settings->get_params( 'bopobb_custom_css' ) );

			wp_add_inline_style( 'woo-bopo-bundle-frontend', wp_kses_post( $css ) );
		}
	}
}